# Code guidelines

> For consistency please read and follow these guidelines.

<br />

## Creating files and folders

**Do:**
- lowercase
- dash-dividers
- `.module.js`, `.component.js`, `.jsx.js`, `.style.js`, `.service.js`, `.slice.js`, `.mock.js`, `.state.js` file endings
- descriptive file names

<span style="color: red">**Don't:**</span><br />
- <span style="color: red">UPPERCASE</span><br />
- <span style="color: red">CamelCase</span><br />
- <span style="color: red">Random non-descriptive names</span>

<br />

## Components

Use [function components](https://reactnative.dev/docs/intro-react#your-first-component), not class components.

Example:
```js
const ExampleComponent = () => {
  return (
    ...
  );
}
```

<br />

## Export & Import

> Spending 2 minutes organizing your exports and imports saves a lot of time later when you or someone else reads, refactors or debugs your code!

Use `export default` when exporting a component:
```js
const ExampleComponent = () => {...}

export default ExampleComponent;
```
Place the exports in the bottom of the document.

With `export default` we can import like so:
```js
import ExampleComponent from 'src/views/.../example.component.js';

<ExampleComponent />
```
Use the whole path to the file and include the extension at the end.

Export all variables from a file with `export {}` like so:
```js
const example1 = '...';
const example2 = '...';
const example3 = '...';

export {
  example1,
  example2,
  example3,
}
```
Importing variables like so:
```js
import {
  example1,
  example2,
  example3,
} from 'src/global/constants/example.js';
```

**Stack multiple exports and imports!**<br />
What does this mean?
```js
// Don't do this
import { example1, example2, example3 } from '...';

// Do this
import {
  example1,
  example2,
  example3,
} from '...';
```

<br />

## Props(paramaters)

If you have 1 or 2 props in a component they can be destructured like this:
```js
const ExampleComponent = ({ navigation, data }) => {...}
```
But once you have more props this quickly becomes unreadable.<br />
You can then destructure them within the component like so:
```js
const ExampleComponent = (props) => {

  const {
    navigation,
    data,
    clickHandler,
    ...
  } = props;

}
```
This goes for sending props as well; `props.data.person.name` is a no go!<br />
Destructure the props and even the data if needed.

Sending props is also much more readable when stacked:
```js
<PrevButton
  absolute={true}
  backgroundColor='#00b6cd'
  color='#fff'
  horizontal={true}
  onPress={() => console.log('PrevButton pressed!')}
  position={{
    top: '50%',
    left: '3%',
  }}
/>
```
The alternative would be a long unreadable line that goes off screen:
```js
<PrevButton absolute={true} backgroundColor='#00b6cd' color='#fff' horizontal={true} onPress={() => console.log('PrevButton pressed!')} position={{ top: '50%', left: '3%' }} />
```

<br />

## Variables
> Use descriptive variable names, if a variable name is too long change it.<br />
Difficult to write good variable names? Add a comment..

Using variables in string:
```js
const firstName = 'Ola';
const lastName = 'Nordmann';

// Don't do this
console.log('First name: ' + firstName + ' Last name: ' + lastName);

// Do this
console.log(`First name: ${firstName} Last name: ${lastName}`);
```
