<p style="text-align: right">
  <a
    href="https://developer.mozilla.org/en-US/docs/Web/JavaScript"
    target="_blank"
    rel="noreferrer"
  >
    <img
      src="https://raw.githubusercontent.com/danielcranney/readme-generator/main/public/icons/skills/javascript-colored.svg"
      width="20"
      height="20"
      alt="TypeScript"
    />
  </a>
  <a
    href="https://reactnative.dev/"
    target="_blank"
    rel="noreferrer"
  >
    <img
      src="https://raw.githubusercontent.com/danielcranney/readme-generator/main/public/icons/skills/react-colored.svg"
      width="20"
      height="20"
      alt="TypeScript"
    />
  </a>
</p>

<p style="text-align: center">
  <a
    href="https://adfectus.no"
    target="_blank"
    rel="noreferrer"
  >
    <img
      src="https://kilavik.com/adfectus/adfectus_logo.png"
      width="205"
      height="54"
    />
  </a>
</p>

<p style="text-align: center">
  Adapted health communication for children
<br />

<p style="text-align: center">
  <img src="https://img.shields.io/badge/react--native-0.69.7-blue">
  <img src="https://img.shields.io/badge/expo-46.0.13-blue">
  <img src="https://img.shields.io/badge/node-16.15.1-blue">
  <img src="https://img.shields.io/badge/npm-8.11.0-blue">
</p>

<br />
<br />

- Look through assets folder
- Move all AsyncStorage to `core/async-storage`
- Refactor alerts
- Refactor buttons
- Refactor reducers
- Refactor services(create new services where needed)
- Create environment(no sensitive data in services)
- Refactor views

#### Refactoring checklist
- File placement and file name
- Code splitting
- Static code/components(do we need to change the component/function?)
- Code placement(f.ex: doing HTTP request within a component)
- Code structure(is it readable? f.ex: multi-line imports)

<br />
<br />

## [Guidelines](./CODE-GUIDELINES.md)

> **_Remember to update the [change log](./CHANGELOG.md)!_**

> This branch should be considered the same as main/production branch and treated as such.<br />
This means no pushing/merging directly with this branch. Create a new branch from beta and merge into the new branch.
When the code has been tested create a pull request.<br />

**_Read this file,
[git guidelines](./GIT-GUIDELINES.md)
and the
[code guidelines](./CODE-GUIDELINES.md)
before contributing to this project!_**

This file explains the project structure and some practices to follow.<br />
The code guidelines is more detailed around coding rather than project structure.

<br />
<br />

## Setup

[Expo Documentation](https://docs.expo.dev/get-started/installation/)

### Start dev server

Run `npm install` or `yarn install` then start the project:
```
$ npm start

or

$ yarn start
```

<br />

Clearing expo cache:
```
$ npm run clear

or

$ yarn clear
```

View all scripts in [package.json](./package.json).

<br />

Having trouble running the project?<br />
Check your **[package.json](./package.json)** and make sure you **use the correct versions**.

> Don't update Node, npm, yarn or any project specific packages without consulting the team first.

<br />
<br />

## Project structure

```
src/
|--- assets/
|--- core/
|    |--- notifications/
|    |--- router/
|    |--- store/
|
|--- global/
|    |--- avatar/
|    |--- components/
|    |--- constants/
|    |--- mock-data/
|    |--- reducers/
|    |--- services/
|
|--- views/
```

<br />
<br />

## [Assets](./src/assets/)

> Contains images, svg's, sounds etc.

SVGr file names should end in `.svgr.js`.

<br />
<br />

## [Core](./src/core/)

> Contains fundamental components to the project(notifications, router, store).<br />
Discuss with the team before changing or adding things to the core.

<br />

### Environment

> **_The environment files shall never be shared or pushed to git!_**

The `environment.js` files contains sensitive information like server URL, API keys etc.<br />
These files will never be pushed to git or any other cloud service, so keep a backup locally on your PC.

#### Dev environment vs Prod environment

The `environment.js` filename, the variable names, it's export and import should not be changed even in a dev environment.
Simply change the values of the environment if necessary.<br />
The dev environment should connect you to the test backend and database.<br />
The prod environment is only used in production as it connects us to the prod backend and database.

> Never share your environment with anyone!

Example environment:
```js
// DEVELOPMENT ENVIRONMENT

const environment = {
  production: false,
  url: 'https://dev.api-url.com',
  apikey: '384f8dd0d3f572286443cd7709a90c5f38de099b',
};

export { environment };
```

The environment should be imported and used in `.service.js` files.

<br />

### [Notifications](./src/core/notifications/)

> Don't change anything in the notification folder!

<br />

### [Router](./src/core/router/)

Add main `views/sub-routes` in [router.module.js](./src/core/router/router.module.js).<br />
If a view contains sub-views you should create a new module(check the **_Views_** section).

<br />

### [Store](./src/core/store/)

> Don't change the store configuration!

Create new reducers in [global/reducers](./src/global/reducers/) and add the reducer in [store/reducers.js](./src/core/store/reducers.js).

<br />

#### Clear expo cache

```
$ yarn clear
```

View scripts in [package.json](./package.json)

#### Clear device storage/cache(Android)

```
Settings > Apps > Expo Go > Storage & Cache
```

<br />
<br />

## [Global](./src/global/)

> Contains any reusable component like alerts, buttons, functions, reducers, services etc.

<br />

### [Avatar](./src/global/avatar/)

The users avatar can be imported and used in views.<br />
Example:

```js
import Avatar from 'src/global/avatar/AvatarComponent.js';
import AvatarPos4 from 'src/global/avatar/AvatarPos4Component.js';

<AvatarPos4 mood={5} wheelChair={true} />
<Avatar mood={5} />
```

<br />

### [Components](./src/global/components/)

> Contains anything from buttons to layout.

> If you create a new view/component less than 100 lines it should be considered/discussed if it should be a dynamic global component.

Each component should have an example use case in a comment in the file.<br />
Example:

```js
<PrevButton
  absolute={true}
  backgroundColor='#00b6cd'
  color='#fff'
  horizontal={true}
  onPress={() => console.log('PrevButton pressed!')}
  position={{
    top: '50%',
    left: '3%',
  }}
/>
```

<br />

### [Constants](./src/global/constants/)

> Static variables and functions.<br />
Colors, dimensions, haptics etc..

<br />

### [Mock-Data](./src/global/mock-data/)

> Any information/data that isn't on AWS.

Everything in this folder should be in JSON format.

<br />

### [Reducers](./src/global/reducers/)

Contains all redux store reducers/slices.

> Make reducers dynamic!

<br />

### [Services](./src/global/services/)

> Don't add URL's, API keys or any other secrets in service files as these things belong in environment files which should never be pushed to git!

> All HTTP requests should occur in service files

Check existing services before creating a new one.<br />
Check **`Environment`** for more info.

Creating a service:
```js
// Changing environment variable name to env
import { environment as env } from '/src/core/environment/environment.js';

// Creating an object which will be our service
const ExampleService = {

  // Creating a function within our service
  exampleFunction: (body) => {
    const requestOptions = {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
        'x-api-key': `${env.apikey}`
      },
      body: body,
    }; // requestOptions end

    // Making the HTTP request and handling the response
    fetch(`${env.url}/example`, requestOptions)
      .then(res => {
        if (res.ok) {
          return res.json();
        }

        throw new Error('Something went wrong!');
      }) // .then end
      .then(data => {
        // do something with the data
      }) // .then end
      .catch(err => {
        console.error(err);
      }); // .catch end
  }, // exampleFunction end

}; // ExampleService end

export default ExampleService;
```

> Create comments explaining what's going on and what props/params to send where.

<br />
<br />

## [Views](./src/views/)

> Contains all views/screens in the app.

Each view has it's own folder which contains the files for that view.<br />
Do code splitting for larger components/files as this makes it easier to read and edit the code. If a component is less than 100 lines before code splitting then it could be converted to a global component if necessary.

If you have more than these 4 files you should create sub-folders to prevent cluttering.

Code splitting a large component with multiple views:
- [1] `some-view.module.js`
- [2] `some-view.component.js`
- [3] `some-view.jsx.js`
- [4] `some-view.style.js`

### [1] Module

Add a sub-router/nested router in the `.module.js` file.<br />
An example is the [packing.module.js](./src/views/packing/packing.module.js).

A nested router is a form of code splitting that avoids making the main router too large, and this makes it easier to refactor/debug the code later.

### [2] Component

Create your overall functionality in the `.component.js` file.<br />
Most of the state should be in the component file and not in the child components.

### [3] JSX

Anything being rendered on the screen should be placed in the `.jsx.js` file, and take state/functionality as props from the `.component.js` file.

### [4] Style

Use global styles or components as much as possible, but if needed place styling in the `.style.js` file and import it in the `.jsx.js` file.
