import React  from 'react';
import { StatusBar } from 'expo-status-bar';
import { useFonts } from 'expo-font';

import { NavigationContainer } from '@react-navigation/native';
import { createNativeStackNavigator } from '@react-navigation/native-stack';
import "react-native-url-polyfill/auto";

// redux-persist wrappers
import { PersistGate } from "redux-persist/integration/react";
import { Provider } from 'react-redux';
import { persistStore } from 'redux-persist';

// Store config moved to store.config.js
import { store } from 'src/core/store/store.config.js';
// Main navigation moved to router.module.js
import RouterModule from 'src/core/router/router.module.js';

let persistor = persistStore(store);
const Stack = createNativeStackNavigator();

const App = () => {

  let [fontsLoaded] = useFonts({
    'MyriadPro': require('src/assets/fonts/MyriadPro-Regular.otf'),
    'MyriadPro-Bold': require('src/assets/fonts/MyriadPro-Bold.otf'),
    'MyriadPro-Semibold': require('src/assets/fonts/MyriadPro-Semibold.otf')
  });

  if (!fontsLoaded) {
    return null
  }

  return (
    <Provider store={store}>

      <PersistGate loading={null} persistor={persistor}>
        <NavigationContainer>
          <Stack.Navigator screenOptions={{headerShown: false}}>

            <Stack.Screen name='RouterModule' component={RouterModule} />

          </Stack.Navigator>
        </NavigationContainer>
      </PersistGate>

      <StatusBar style='dark'
        backgroundColor='hsla(0, 0%, 100%, 0)'
      />

      {/* <NetworkState /> */}

    </Provider>
  );
}

export default App;
