import React from "react";
import {
  Pressable,
  StyleSheet,
  View
} from "react-native";
import { useSelector } from "react-redux";

import { selectWalker } from "src/global/reducers/avatar/aidSlice"

import Torso from './body/torso/TorsoComponent'
import Head from './body/head/HeadComponent'
import LeftShoulder from './body/shoulder/LeftShoulderComponent'
import RightShoulder from './body/shoulder/RightShoulderComponent'
import LeftArm from './body/arm/LeftArmComponent'
import RightArm from './body/arm/RightArmcomponent'
import LeftHand from './body/hand/LeftHandComponent'
import RightHand from './body/hand/RightHandComponent'
import LeftThigh from './body/thigh/LeftThighComponent'
import RightThigh from './body/thigh/RightThighComponent'
import LeftLeg from './body/leg/LeftLegComponent'
import RightLeg from './body/leg/RightLegComponent'
import LeftFoot from './body/foot/LeftFootComponent'
import RightFoot from './body/foot/RightFootComponent'
// import SvgAsset3 from "./TestBody";
import Walker from "../avatar/aid/walker/Walker"

const styles = StyleSheet.create({
    container: {
        flex: 1,
        aspectRatio: 4/3,
    },

    torso: {
        position: 'absolute',
        height: '34.2%', 
        width: '34.2%',
        top: '24.95%', 
        left: '32.8%'
    },
    walker: {
        position: 'absolute',
        height: '52%', 
        width: '52%',
        top: '54.95%', 
        left: '23.8%'
    },
    head: {
        position: 'absolute',
        height: '38.9%', 
        width: '38.9%',
        top: '0%',
        left: '30.5%'
    },
    leftShoulder: {
        position: 'absolute',
        height: '32.2%', 
        width: '32.2%',
        top: '24.4%', 
        right: '27.4%'
    },
    rightShoulder: {
        position: 'absolute',
        height: '32.3%', 
        width: '32.3%',
        top: '24.3%', 
        left: '27.32%'
    },
    leftArm: {
        position: 'absolute',
        height: '32.4%', 
        width: '32.4%',
        top: '37.8%', 
        right: '24.6%'
    },
    rightArm: {
        position: 'absolute',
        height: '32.4%', 
        width: '32.4%',
        top: '37.8%', 
        left: '24.7%'
    },
    leftHand: {
        position: 'absolute',
        height: '15.4%', 
        width: '15.4%',
        top: '55.9%', 
        right: '31.3%'
    },
    rightHand: {
        position: 'absolute',
        height: '15.4%', 
        width: '15.4%',
        top: '55.9%', 
        left: '31.3%'
    },
    leftThigh: {
        position: 'absolute',
        height: '51.2%', 
        width: '51.2%',
        top: '44%', 
        right: '20.7%'
    },
    rightThigh: {
        position: 'absolute',
        height: '50.5%', 
        width: '50.5%',
        top: '44%', 
        left: '20.9%'
    },
    leftLeg: {
        position: 'absolute',
        height: '51.3%', 
        width: '51.3%',
        top: '65%', 
        right: '20.1%'
    },
    rightLeg: {
        position: 'absolute',
        height: '51.4%', 
        width: '51.4%',
        top: '65%', 
        left: '19.9%'
    },
    leftFoot: {
        position: 'absolute',
        height: '11.8%', 
        width: '11.8%',
        top: '95.9%', 
        right: '38.85%'
    },
    rightFoot: {
        position: 'absolute',
        height: '11.9%', 
        width: '11.9%',
        top: '95.9%', 
        left: '38.68%'
    },
    leftArmRotate: {
        position: 'absolute',
        height: '32%', 
        width: '32%',
        top: '26.6%', 
        right: '18%', 
        transform: [{rotate: '-100deg'}]
    }, 
    leftHandRotate: {
        position: 'absolute',
        height: '15.6%', 
        width: '15.6%',
        top: '30.2%', 
        right: '18.5%', 
        transform: [{rotate: '-100deg'}]
    },
  });

const AvatarComponent = (props) => {

    const onPressSweater= props.onPressSweater
    const onPressPant = props.onPressPant
    const onPressHead = props.onPressHead
    const onPressFoot = props.onPressFoot

    let showWalker = null
    if(useSelector(selectWalker) || props.walker ){
        showWalker = <Walker style={styles.walker}/>
    }
 
    return (
        
        <View style={styles.container}>
            {showWalker}
            <View style={styles.leftHand}>
         <LeftHand pos={1} />
          </View>
          <View style={styles.rightHand}>
         <RightHand pos={1}/>
          </View>
       
        
          <View style={styles.leftArm}>
            <LeftArm pos={1} clothing={props.clothing}/>
          </View>
          <View style={styles.rightArm}>
            <RightArm pos={1} clothing={props.clothing}/>
          </View>
          <View style={styles.leftShoulder}>
           <LeftShoulder pos={1} clothing={props.clothing}/>
          </View>
          <View style={styles.rightShoulder}>
          <RightShoulder pos={1} clothing={props.clothing}/>
          </View>
         
        
        <View style={styles.rightLeg}>
        <RightLeg pos={1} clothing={props.clothing}/>
        </View>

        <Pressable onPress={onPressPant} style={styles.leftLeg}>
       <LeftLeg pos={1} clothing={props.clothing}/>
       </Pressable>

         <Pressable onPress={onPressPant} style={styles.rightLeg}>
        <RightLeg pos={1} clothing={props.clothing}/>
        </Pressable>

        <Pressable onPress={onPressPant} style={styles.leftThigh}>
            <LeftThigh pos={1} clothing={props.clothing}/>
            </Pressable>
   
        <Pressable onPress={onPressPant} style={styles.rightThigh}>
         <RightThigh pos={1} clothing={props.clothing}/>
        </Pressable>

        <Pressable onPress={onPressFoot} style={styles.leftFoot}>
          <LeftFoot pos={1} clothing={props.clothing}/>
        </Pressable>

        <Pressable onPress={onPressFoot} style={styles.rightFoot}>
            <RightFoot pos={1} clothing={props.clothing}/>
        </Pressable>
       
       
          <View style={styles.torso}>
              <Pressable onPress={onPressSweater}>
              <Torso pos={1} clothing={props.clothing}/>
              </Pressable>
          </View>
        
       
          <View style={styles.head}>
            <Head pos={1} mood={props.mood}/>
            </View>
  
          
       </View>
      );

}
export default AvatarComponent; 
