import React from "react";
import { StyleSheet, View, TouchableOpacity, Pressable } from "react-native";
import { useSelector } from "react-redux";

import Torso from '../../body/torso/TorsoComponent'
import Head from '../../body/head/HeadComponent'
import LeftShoulder from '../../body/shoulder/LeftShoulderComponent'
import RightShoulder from '../../body/shoulder/RightShoulderComponent'
import LeftArm from '../../body/arm/LeftArmComponent'
import RightArm from '../../body/arm/RightArmcomponent'
import LeftHand from '../../body/hand/LeftHandComponent'
import RightHand from '../../body/hand/RightHandComponent'

const styles = StyleSheet.create({
    container: {
        aspectRatio: 4/3,
    },

    torso: {
        position: 'absolute',
        height: '34.2%', 
        width: '34.2%',
        top: '24.95%', 
        left: '32.8%'
    },
    head: {
        position: 'absolute',
        height: '38.9%', 
        width: '38.9%',
        top: '0%',
        left: '30.5%'
    },
    leftShoulder: {
        position: 'absolute',
        height: '32.2%', 
        width: '32.2%',
        top: '24.4%', 
        right: '27.4%'
    },
    leftShoulder3: {
        position: 'absolute',
        height: '32.2%', 
        width: '32.2%',
        top: '12.4%', 
        right: '22.4%', 
        transform: [{rotate: '238deg'}, {rotateY: '180deg'}]
    },
    rightShoulder: {
        position: 'absolute',
        height: '32.3%', 
        width: '32.3%',
        top: '24.3%', 
        left: '27.32%', 
        
    },
    rightShoulder3: {
        position: 'absolute',
        height: '32.3%', 
        width: '32.3%',
        top: '8.3%', 
        left: '25.32%', 
        transform: [{rotate: '158deg'}, {rotateY: '180deg'}]
    },
    leftArm: {
        position: 'absolute',
        height: '32.4%', 
        width: '32.4%',
        top: '37.8%', 
        right: '24.6%'
    },
    rightArm: {
        position: 'absolute',
        height: '32.4%', 
        width: '32.4%',
        top: '37.8%', 
        left: '24.7%'
    },
    leftHand3: {
        position: 'absolute',
        height: '15.4%', 
        width: '15.4%',
        top: '9.2%', 
        right: '11.7%',
        transform: [{rotate: '229deg'}, {rotateY: '180deg'} ]
    },

    leftArm3: {
        position: 'absolute',
        height: '32.4%', 
        width: '32.4%',
        top: '7.2%', 
        left: '57.7%',
        transform: [{rotate: '249deg'}, ]
    },
    leftArm4: {
        position: 'absolute',
        height: '32.4%', 
        width: '32.4%',
        top: '20.8%', 
        left: '38.7%',
        transform: [{rotate: '170deg'}]
    },
    rightArm4: {
        position: 'absolute',
        height: '32.4%', 
        width: '32.4%',
        top: '20.8%', 
        left: '28.7%', 
        transform: [{rotate: '186deg'}]
    },
    rightArm3: {
        position: 'absolute',
        height: '32.4%', 
        width: '32.4%',
        top: '-5.8%', 
        left: '25.7%', 
        transform: [{rotate: '206deg'}]
    },

    leftHand4: {
        position: 'absolute',
        height: '15.4%', 
        width: '15.4%',
        top: '19.1%', 
        right: '44.4%', 
        transform: [{rotate: '206deg'}]
    },
    rightHand4: {
        position: 'absolute',
        height: '15.4%', 
        width: '15.4%',
        top: '19.5%', 
        right: '41.0%', 
        transform: [{rotate: '148deg'}]
    },
    leftHand: {
        position: 'absolute',
        height: '15.4%', 
        width: '15.4%',
        top: '55.9%', 
        right: '31.3%'
    },
    rightHand: {
        position: 'absolute',
        height: '15.4%', 
        width: '15.4%',
        top: '55.9%', 
        left: '31.3%'
    },
    rightHand3: {
        position: 'absolute',
        height: '15.4%', 
        width: '15.4%',
        top: '-4.8%', 
        left: '40.4%', 
        transform: [{rotate: '238deg'}, {rotateY: '180deg'}]
    },
  });

const AvatarComponent = (props) => {
 
    let leftArmStyle = styles.leftArm
    let leftHandStyle = styles.leftHand
    let leftShoulderStyle = styles.leftShoulder

    let rightArmStyle = styles.rightArm
    let rightHandStyle = styles.rightHand
    let rightShoulderStyle = styles.rightShoulder

    let handpos = 1

    switch(props.mood){
        case 4: 
        leftArmStyle = styles.leftArm4
        rightArmStyle = styles.rightArm4
        leftHandStyle = styles.leftHand4
        rightHandStyle = styles.rightHand4
        break; 
        case 5: 
        leftArmStyle = styles.leftArm3
        leftShoulderStyle = styles.leftShoulder3
        leftHandStyle = styles.leftHand3
        break; 
        case 3: 
        leftArmStyle = styles.leftArm3
        leftShoulderStyle = styles.leftShoulder3
        leftHandStyle = styles.leftHand3

        rightArmStyle = styles.rightArm3
        rightHandStyle = styles.rightHand3
        rightShoulderStyle = styles.rightShoulder3
        break; 
    }


    return (
        <View style={styles.container}>
          <View style={leftShoulderStyle}>
           <LeftShoulder pos={1} clothing={props.clothing}/>
          </View>
          <View style={rightShoulderStyle}>
          <RightShoulder pos={1} clothing={props.clothing}/>
          </View>
          <View style={styles.torso}>
              <View >
              <Torso pos={1} clothing={props.clothing}/>
              </View>
          </View>
          <View style={styles.head}>
            <Head pos={1} mood={props.mood}/>
            </View>
            <View style={leftHandStyle}>
         <LeftHand pos={1} />
          </View>
          <View style={rightHandStyle}>
         <RightHand pos={1}/>
          </View>
            <View style={leftArmStyle}>
            <LeftArm pos={1} clothing={props.clothing}/>
          </View>
          <View style={rightArmStyle}>
            <RightArm pos={1} clothing={props.clothing}/>
          </View>
        
       </View>
      );

}
export default AvatarComponent; 