import React from "react";
import { StyleSheet, View } from "react-native";
import { useSelector } from "react-redux";

import {
  selectSkinPrimary, selectSkinDefinition,
} from "src/global/reducers/avatar/skinSlice"

import { selectLeftArmProsthesis, selectLeftArmOrthosis } from "src/global/reducers/avatar/aidSlice"

import ArmProsthesis from "./ProsthesisArm"
import {
  selectTopPrimary,
  selectTopSecondary,
  selectTopTertiary,
  selectTopQuaternary,
  selectTop
} from "src/global/reducers/avatar/topStyleSlice"

import SvgArmSweater from "../../clothing/tops/sweater/Pos1/Arm";
import SvgHoodieLeft from "../../clothing/tops/hoodie/Pos1/LeftArm";
import SvgArm from "./ArmPos1";
import SvgArmPos2 from "./ArmPos2";
import SvgSweaterArmPos2 from "../../clothing/tops/sweater/Pos2/SweaterArmPos2";
import SvgHoodieArmPos2 from "../../clothing/tops/hoodie/Pos2/HoodieArmPos2";

import JacketPos1 from "../../clothing/jackets/outer/Pos1/JacketUnderArmPos1"
import JacketPos3 from "../../clothing/jackets/outer/Pos3/JacketLeftUnderArmPos3"
import WinterJacketPos1 from "../../clothing/jackets/winter/Pos1/WinterJacketUnderArmPos1"
import WinterJacketPos3 from "../../clothing/jackets/winter/Pos3/WinterJacketLeftUnderArmPos3"

import SvgUnderArmOrthosisPos1 from "./ArmOrthosisPos1";


const styles = StyleSheet.create({
  container: {
    height: '60%',
    width: '60%',
    top: '10%',
    left: '20%'
  },
  orthosis: {
    position: 'absolute',
    left: '-0%',
    top: '2%',
    width: '100%',
    height: '100%',
    transform: [{ rotateY: "180deg" }]
  },

  prosthesis: {
    position: 'absolute',
    left: '2%',
    top: '2%',
    width: '95%',
    height: '95%'
  },

  hoodie: {
    position: 'absolute',
    left: '1%',
    top: '0%',
    width: '95%',
    height: '95%'
  },
  jacket: {
    position: 'absolute',
    left: '5.5%',
    top: '-2.5%',
    width: '92%',
    height: '92%'
  },

  jacket3: {
    position: 'absolute',
    left: '2%',
    top: '-7%',
    width: '102%',
    height: '102%',
    transform: [{ rotate: "4deg" }]
  },
  winterjacket3: {
    position: 'absolute',
    left: '3%',
    top: '-6%',
    width: '98%',
    height: '98%',
  },
  prosthesis2: {
    height: '92%',
    width: '92%',
    top: '4%',
    left: '3%',
    transform: [{ rotate: "4deg" }]
  },

  hoodie2: {
    position: 'absolute',
    left: '0.5%',
    top: '-3%',
    width: '98%',
    height: '98%'
  },
  hoodie3: {
    position: 'absolute',
    left: '-1%',
    top: '-6%',
    width: '100%',
    height: '100%'
  },

  sweater: {
    position: 'absolute',
    left: '4.0%',
    top: '-1%',
    width: '92%',
    height: '92%'
  },

  sweater2: {
    position: 'absolute',
    left: '2.5%',
    top: '-1.5%',
    width: '92%',
    height: '92%'
  },
  sweater3: {
    position: 'absolute',
    left: '5%',
    top: '-4%',
    width: '94%',
    height: '94%',
    transform: [{ rotate: "2deg" }]
  },

})

const LeftArmComponent = (props) => {

  const pos = props.pos
  const isProsthesis = useSelector(selectLeftArmProsthesis);
  const isOrthosis = useSelector(selectLeftArmOrthosis);

  const primaryColor = useSelector(selectTopPrimary);
  const secondaryColor = useSelector(selectTopSecondary);
  const tertiaryColor = useSelector(selectTopTertiary);
  const qtrColor = useSelector(selectTopQuaternary)

  let top = useSelector(selectTop);
  switch (props.clothing) {
    case 1:
      top = 6
      break;
    case 2:
      top = 2
      break;
    case 3:
      top = 0
      break;
    case 7:
      top = 5
      break;
  }

  const skin = useSelector(selectSkinPrimary);
  const def = useSelector(selectSkinDefinition);

  let shownTop = null;
  let shownPos = null;

  if (pos == 1) {
    if (isProsthesis) {
      shownPos = <ArmProsthesis style={styles.prosthesis} />
    } else if (isOrthosis) {
      shownPos = <SvgUnderArmOrthosisPos1 style={styles.orthosis} skin={skin} />
    } else {
      shownPos = <SvgArm skin={skin} def={def} />
    }
    switch (top) {
      case 1:
        shownTop = <SvgArmSweater style={styles.sweater}
          primary={primaryColor} secondary={secondaryColor} />
        break;
      case 4:
        shownTop = <SvgHoodieLeft style={styles.hoodie}
          primary={primaryColor} secondary={secondaryColor} tertiary={tertiaryColor} />
        break;
      case 5:
        shownTop = <JacketPos1 style={styles.jacket}
          primary={primaryColor} qtr={qtrColor} secondary={secondaryColor} tertiary={tertiaryColor} />
        break;
      case 6:
        shownTop = <WinterJacketPos1 style={[styles.jacket, { transform: [{ rotateY: "180deg" }] }]}
          primary={primaryColor} secondary={secondaryColor} tertiary={tertiaryColor} />
        break;
    }
  } else if (pos == 2) {
    if (isProsthesis) {
      shownPos = <ArmProsthesis style={styles.prosthesis2} />
    } else {
      shownPos = <SvgArmPos2 skin={skin} def={skin} />
    }
    switch (top) {
      case 1:
        shownTop = <SvgSweaterArmPos2 style={styles.sweater2}
          primary={primaryColor} secondary={secondaryColor} />
        break;
      case 4:
        shownTop = <SvgHoodieArmPos2 style={styles.hoodie2}
          primary={primaryColor} secondary={secondaryColor} extra={primaryColor} tertiary={tertiaryColor} />
        break;
    }
  } else if (pos == 3) {
    shownPos = <SvgArm skin={skin} def={skin} />
    switch (top) {
      case 1:
        shownTop = <SvgArmSweater style={styles.sweater3}
          primary={primaryColor} secondary={secondaryColor} />
        break;
      case 4:
        shownTop = <SvgHoodieLeft style={styles.hoodie3}
          primary={primaryColor} secondary={secondaryColor} tertiary={tertiaryColor} />
        break;
      case 5:
        shownTop = <JacketPos3 style={styles.jacket3}
          primary={primaryColor} qtr={qtrColor} secondary={secondaryColor} tertiary={tertiaryColor} />
        break;
      case 6:
        shownTop = <WinterJacketPos3 style={styles.winterjacket3}
          primary={primaryColor} secondary={secondaryColor} tertiary={tertiaryColor} />
        break;
    }
  }
  return (
    <View style={styles.container}>
      {shownPos}
      {shownTop}
    </View>
  );
}

export default LeftArmComponent;
