import React from "react";
import { StyleSheet, View } from "react-native";
import { useSelector } from "react-redux";

import {
  selectSkinPrimary,
  selectSkinDefinition
} from "src/global/reducers/avatar/skinSlice"

import { selectRightArmProsthesis, selectRightArmOrthosis } from "src/global/reducers/avatar/aidSlice"

import {
  selectTopPrimary,
  selectTopSecondary,
  selectTopTertiary,
  selectTop,
  selectTopQuaternary
} from "src/global/reducers/avatar/topStyleSlice"

import SvgArmSweater from "../../clothing/tops/sweater/Pos1/Arm";
import SvgHoodieRight from "../../clothing/tops/hoodie/Pos1/RightArm";
import SvgArm from "./ArmPos1";
import SvgArmPos2 from "./ArmPos2";
import ArmProsthesis from "./ProsthesisArm"

import SvgHoodieArmPos2 from "../../clothing/tops/hoodie/Pos2/HoodieArmPos2";
import SvgSweaterArmPos2 from "../../clothing/tops/sweater/Pos2/SweaterArmPos2";

import SvgHoodieArmPos3 from "../../clothing/tops/hoodie/Pos3/HoodieRightArmPos3"

import JacketPos1 from "../../clothing/jackets/outer/Pos1/JacketUnderArmPos1"
import JacketPos3 from "../../clothing/jackets/outer/Pos3/JacketRightUnderArmPos3"

import WinterJacketPos1 from "../../clothing/jackets/winter/Pos1/WinterJacketUnderArmPos1"
import WinterJacketPos3 from "../../clothing/jackets/winter/Pos3/WinterJacketRightUnderArmPos3"
import SvgUnderArmOrthosisPos1 from "./ArmOrthosisPos1";

const styles = StyleSheet.create({
  container: {
    height: '60%',
    width: '60%',
    top: '10%',
    left: '20%'
  },
  pos2: {
    transform: [{ rotateY: "180deg" }]
  },

  prosthesis: {
    position: 'absolute',
    left: '2%',
    top: '2%',
    width: '95%',
    height: '95%',
  },


  orthosis: {
    position: 'absolute',
    left: '0.8%',
    top: '2%',
    width: '100%',
    height: '100%',
    transform: [{ rotateY: "180deg" }]
  },

  prosthesis2: {
    position: 'absolute',
    left: '3.5%',
    top: '2%',
    width: '95%',
    height: '95%',
    transform: [{ rotateY: "180deg" }, { rotate: "5deg" }]
  },

  hoodie: {
    position: 'absolute',
    left: '1%',
    top: '0%',
    width: '95%',
    height: '95%'
  },
  jacket: {
    position: 'absolute',
    left: '5.5%',
    top: '-2.5%',
    width: '92%',
    height: '92%'
  },

  hoodie2: {
    position: 'absolute',
    left: '2%',
    top: '0%',
    width: '95%',
    height: '95%'
  },
  hoodie3: {
    position: 'absolute',
    left: '2%',
    top: '-1%',
    width: '95%',
    height: '95%',
    transform: [{ rotateY: "180deg" }, { rotate: "-2deg" }]
  },
  jacket3: {
    position: 'absolute',
    left: '3.3%',
    top: '-2%',
    width: '97%',
    height: '97%',
    transform: [{ rotateY: "180deg" }, { rotate: "-2deg" }]
  },

  sweater: {
    position: 'absolute',
    left: '4%',
    top: '-1%',
    width: '92%',
    height: '92%'
  },

  sweater2: {
    position: 'absolute',
    left: '2.5%',
    top: '-1.5%',
    width: '92%',
    height: '92%'
  },

  sweater3: {
    position: 'absolute',
    left: '5.2%',
    top: '-1%',
    width: '92%',
    height: '92%'
  },
})

const RightArmComponent = (props) => {

  const pos = props.pos
  const isProsthesis = useSelector(selectRightArmProsthesis);
  const isOrthosis = useSelector(selectRightArmOrthosis);

  const primaryColor = useSelector(selectTopPrimary);
  const secondaryColor = useSelector(selectTopSecondary);
  const tertiaryColor = useSelector(selectTopTertiary);
  const qtrColor = useSelector(selectTopQuaternary)

  let top = useSelector(selectTop);
  switch (props.clothing) {
    case 1:
      top = 6
      break;
    case 2:
      top = 2
      break;
    case 3:
      top = 0
      break;
    case 7:
      top = 5
      break;
  }

  const skin = useSelector(selectSkinPrimary);
  const def = useSelector(selectSkinDefinition)

  let shownTop = null;
  let shownPos = null;

  if (pos == 1) {
    if (isProsthesis) {
      shownPos = <ArmProsthesis style={styles.prosthesis} />
    } else if (isOrthosis) {
      shownPos = <SvgUnderArmOrthosisPos1 style={styles.orthosis} skin={skin} />
    } else {
      shownPos = <SvgArm skin={skin} def={def} />
    }
    switch (top) {
      case 1:
        shownTop = <SvgArmSweater style={styles.sweater}
          primary={primaryColor} secondary={secondaryColor} />
        break;
      case 4:
        shownTop = <SvgHoodieRight style={[styles.hoodie, { transform: [{ rotateY: "180deg" }] }]}
          primary={primaryColor} secondary={secondaryColor} tertiary={tertiaryColor} />
        break;
      case 5:
        shownTop = <JacketPos1 style={styles.jacket}
          primary={primaryColor} qtr={qtrColor} secondary={secondaryColor} tertiary={tertiaryColor} />
        break;
      case 6:
        shownTop = <WinterJacketPos1 style={[styles.jacket, { transform: [{ rotateY: "180deg" }] }]}
          primary={primaryColor} secondary={secondaryColor} tertiary={tertiaryColor} />
        break;
    }
  } else if (pos == 2) {
    if (isProsthesis) {
      shownPos = <ArmProsthesis style={styles.prosthesis2} />
    } else {
      shownPos = <SvgArmPos2 style={styles.pos2} skin={skin} def={def} />
    }
    switch (top) {
      case 1:
        shownTop = <SvgSweaterArmPos2 style={styles.sweater2}
          primary={primaryColor} secondary={secondaryColor} />
        break;
      case 4:
        shownTop = <SvgHoodieArmPos2 style={styles.hoodie2}
          primary={primaryColor} extra={secondaryColor} secondary={secondaryColor} tertiary={tertiaryColor} />
        break;
    }
  } else if (pos == 3) {
    shownPos = <SvgArm skin={skin} def={def} />
    switch (top) {
      case 1:
        shownTop = <SvgArmSweater style={styles.sweater3}
          primary={primaryColor} secondary={secondaryColor} />
        break;
      case 4:
        shownTop = <SvgHoodieArmPos3 style={styles.hoodie3}
          primary={primaryColor} extra={secondaryColor} secondary={secondaryColor} tertiary={tertiaryColor} />
        break;
      case 5:
        shownTop = <JacketPos3 style={styles.jacket3}
          primary={primaryColor} qtr={qtrColor} extra={secondaryColor} secondary={secondaryColor} tertiary={tertiaryColor} />
        break;
      case 6:
        shownTop = <WinterJacketPos3 style={styles.jacket3}
          primary={primaryColor} extra={secondaryColor} secondary={secondaryColor} tertiary={tertiaryColor} />
        break;
    }
  }

  return (
    //<View style={[styles.container, {transform: [{rotateY: "180deg"}]}]}>
    <View style={[styles.container, { transform: [{ rotateY: "180deg" }] }]}>
      {shownPos}
      {shownTop}
    </View>
  );
}

export default RightArmComponent;
