import React from "react";
import { StyleSheet, View } from "react-native";
import { useSelector } from "react-redux";

import {
  selectSkinPrimary,
  selectSkinDefinition
} from 'src/global/reducers/avatar/skinSlice'

import SvgFoot from "./Pos1Foot";

import {
  selectShoes,
  selectShoeColorPrimary,
  selectShoeColorSecondary,
  selectShoeColorTertiary,
  selectShoeColorQuaternary
} from 'src/global/reducers/avatar/shoeStyleSlice'

import SvgSneaker from "../../clothing/shoes/sneakers/SneakerPos1";
import SvgBallerina from "../../clothing/shoes/ballerinas/BallerinaPos1";
import SvgFootPos2 from "./Pos2Foot";
import SvgBallerinaPos2 from "../../clothing/shoes/ballerinas/BallerinaPos2";
import SvgSneakerPos2 from "../../clothing/shoes/sneakers/SneakerPos2";
import SvgFootOrtosisPos1 from "./FootOrthosisPos1";


import SkatesPos1 from "../../clothing/shoes/skates/SkatesPos1"
import SkatesPos2 from "../../clothing/shoes/skates/SkatesPos2"

import SkiPos2 from "../../clothing/shoes/ski/SkiBootPos2"
import SkiPos3 from "../../clothing/shoes/ski/SkiBootPos3"

import SlalomPos2 from "../../clothing/shoes/slalom/SlalomBootsPos2"
import SlalomPos3 from "../../clothing/shoes/slalom/SlalomBootsPos3"

import { selectLeftLegOrthosis } from 'src/global/reducers/avatar/aidSlice'

const styles = StyleSheet.create({
  container: {
    height: '60%',
    width: '60%',
    top: '10%',
    left: '20%'
  },
  footPos1: {
    width: '81%',
    height: '81%',
    top: '20.5%',
    left: '9.2%',
    transform: [{ rotateY: "180deg" }]
  },
  shoes: {
    position: 'absolute',
    left: '16,%',
    top: '37,5%',
    width: '68%',
    height: '68%'
  },
  shoes2: {
    position: 'absolute',
    left: '-1%',
    top: '12%',
    width: '104%',
    height: '104%'
  },
  sneakers: {
    position: 'absolute',
    left: '7%',
    top: '24%',
    width: '86%',
    height: '86%'
  },
  sneakers2: {
    position: 'absolute',
    left: '-5%',
    top: '10%',
    width: '106%',
    height: '106%'
  },
  skates: {
    position: 'absolute',
    left: '-35%',
    top: '-26%',
    width: '170%',
    height: '170%',
    transform: [{ rotateY: "180deg" }]
  },
  skates2: {
    position: 'absolute',
    left: '-35%',
    top: '-36%',
    width: '170%',
    height: '170%'
  },
  ski2: {
    position: 'absolute',
    left: '-6%',
    top: '-2%',
    width: '120%',
    height: '120%'
  },
  ski3: {
    position: 'absolute',
    left: '-6%',
    top: '0%',
    width: '110%',
    height: '110%',
    transform: [{ rotate: '-10deg' }]
  },
  slalom2: {
    position: 'absolute',
    left: '-6%',
    top: '-6%',
    width: '120%',
    height: '120%'
  },
  slalom3: {
    position: 'absolute',
    left: '-14%',
    top: '-20%',
    width: '140%',
    height: '140%'
  },
})

const LeftFootComponent = (props) => {

  const pos = props.pos

  const isOrthosis = useSelector(selectLeftLegOrthosis);

  const skin = useSelector(selectSkinPrimary);
  const def = useSelector(selectSkinDefinition);

  const primary = useSelector(selectShoeColorPrimary);
  const secondary = useSelector(selectShoeColorSecondary);
  const tertiary = useSelector(selectShoeColorTertiary);
  const qtr = useSelector(selectShoeColorQuaternary);

  let shoe = useSelector(selectShoes);
  switch (props.clothing) {
    case 1:
      shoe = 5
      break;
    case 2:
      shoe = 1
      break;
    case 3:
      shoe = 0
      break;
    case 4:
      shoe = 3
      break;
    case 6:
      shoe = 4
      break;
  }
  let shownShoes = null;
  let shownPos = null;

  if (pos == 1) {
    if (isOrthosis) {
      shownPos = <SvgFootOrtosisPos1 skin={skin} def={def} />
    } else {
      shownPos = <SvgFoot skin={skin} def={def} style={styles.footPos1} />
    }
    switch (shoe) {
      case 1:
        shownShoes = <SvgSneaker style={styles.sneakers}
          primary={primary} secondary={secondary} tertiary={tertiary} qtr={qtr} />
        break;
      case 2:
        shownShoes = <SvgBallerina style={styles.shoes}
          primary={primary} />
        break;
      case 3:
        shownShoes = <SkatesPos1 style={styles.skates}
          primary={primary} />
        break;
    }
  } else if (pos == 2) {
    shownPos = <SvgFootPos2 skin={skin} />
    switch (shoe) {
      case 1:
        shownShoes = <SvgSneakerPos2 style={styles.sneakers2}
          primary={primary} secondary={secondary} tertiary={tertiary} qtr={qtr} />
        break;
      case 2:
        shownShoes = <SvgBallerinaPos2 style={styles.shoes2}
          primary={primary} />
        break;
      case 3:
        shownShoes = <SkatesPos2 style={styles.skates2}
          primary={primary} />
        break;
      case 4:
        shownShoes = <SkiPos2 style={styles.ski2}
          primary={primary} />
        break;
      case 5:
        shownShoes = <SlalomPos2 style={styles.slalom2}
          primary={primary} />
        break;
    }
  } else if (pos == 3) {
    shownPos = <SvgFootPos2 skin={skin} />
    switch (shoe) {
      case 1:
        shownShoes = <SvgSneakerPos2 style={styles.sneakers2}
          primary={primary} secondary={secondary} tertiary={tertiary} qtr={qtr} />
        break;
      case 2:
        shownShoes = <SvgBallerinaPos2 style={styles.shoes2}
          primary={primary} />
        break;
      case 3:
        shownShoes = <SkatesPos2 style={styles.skates2}
          primary={primary} />
        break;
      case 4:
        shownShoes = <SkiPos3 style={styles.ski3}
          primary={primary} />
        break;
      case 5:
        shownShoes = <SlalomPos3 style={styles.slalom3}
          primary={primary} />
        break;
    }
  }
  return (
    <View style={styles.container}>
      {shownPos}
      {shownShoes}
    </View>
  );
}

export default LeftFootComponent;
