import React, {
    useEffect,
    useState,
} from 'react';
import {
    StyleSheet,
    Text,
    TouchableOpacity,
    View,
} from 'react-native';
import { Audio } from 'expo-av';
import { AntDesign } from '@expo/vector-icons';
import { Sounds } from 'src/assets/sounds/sounds';
import fonts from 'src/assets/fonts/fonts';

function AlertComponent({ type, title, description, sound, previousSound, closeAlert }) {
    const [selectedSound, setSelectedSound] = useState(new Audio.Sound());

    useEffect(() => {
    }, []);

    const closeSound = Sounds.close;

    const [currentSound, setCurrentSound] = useState();

    const SoundPlayer = (name, sound) => {
        if (currentSound == null) {
            console.log("Sound is undefined");
        } else {
            currentSound.sound.unloadAsync().catch(()=>{});
        }

        console.log("Playing: " + name);
        Audio.Sound.createAsync(
            sound,
            {shouldPlay: true}
        ).then((res)=>{
            setCurrentSound(res);
            res.sound.setOnPlaybackStatusUpdate((status)=>{
    
                if(!status.didJustFinish) return;
                console.log('Unloading ' + name);
    
                res.sound.unloadAsync().catch(()=>{});
            });
        }).catch((error)=>{});
    }

    const closeHandler = async () => {
        SoundPlayer('close', closeSound);
        closeAlert();
    }

    return (
        <View style={styles.container}>
            <View style={[styles.card, {
                      backgroundColor: type === 'success'
                                          ? '#ffe5ad'
                                          : type === 'error'
                                              ? '#ffc59f'
                                              : type === 'default'
                                                ? '#b1ebf4'
                                                : '#ffffff'
                  }]}
            >
                <View style={styles.body}>
                    {
                        type === 'success'
                            ? <View style={styles.icons}>
                                <AntDesign name='star' size={36} color='#ffb93e' style={styles.icon} />
                                <AntDesign name='star' size={36} color='#ffb93e' style={styles.icon} />
                                <AntDesign name='star' size={36} color='#ffb93e' style={styles.icon} />
                            </View>
                            : null
                    }
                    <Text style={styles.title}>
                        { title }
                    </Text>
                    <Text style={styles.description}>
                        { description }
                    </Text>
                </View>
                <View style={styles.actions}>
                    <TouchableOpacity style={[styles.button, {
                                          backgroundColor: type === 'success'
                                                              ? '#ffb93e'
                                                              : type === 'error'
                                                                ? '#ff8f59'
                                                                : type === 'default'
                                                                    ? '#00b6cd'
                                                                    : '#000000'
                                      }]}
                                      onPress={() => SoundPlayer(title, sound)}
                    >
                        <Text style={styles.buttonText}>
                            Spill av lyd
                        </Text>
                    </TouchableOpacity>
                    <TouchableOpacity style={[styles.button, {
                                          backgroundColor: type === 'success'
                                                              ? '#ffb93e'
                                                              : type === 'error'
                                                                ? '#ff8f59'
                                                                : type === 'default'
                                                                    ? '#00b6cd'
                                                                    : '#000000'
                                      }]}
                                      onPress={() => closeHandler()}
                    >
                        <Text style={styles.buttonText}>
                            Lukk
                        </Text>
                    </TouchableOpacity>
                </View>
            </View>
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        position: 'absolute',
        alignSelf: 'center',
        justifyContent: 'center',
        resizeMode: 'contain',
        marginTop: 'auto',
        marginBottom: 'auto',
        top: 0, 
        bottom: 0,
        width: '100%',
        height: '100%',
        backgroundColor: 'hsla(0, 0%, 0%, .5)',
    },
    card: {
        position: 'absolute',
        backgroundColor: '#7ddbc9',
        borderColor: 'white',
        width: '50%',
        alignSelf: 'center',
        height: 'auto',
        padding: 20,
        elevation: 5,
        borderRadius: 20,
        borderWidth: 4,
        borderColor: '#ffffff'
    },

    body: {
        flex: 2,
        alignItems: 'center',
        justifyContent: 'center',
    },
    actions: {
        flex: 1,
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'space-evenly'
    },
    icons: {
        flexDirection: 'row',
        marginBottom: 10,
    },
    icon: {
        marginHorizontal: 4,
    },
    title: {
        marginBottom: '3%',
        fontSize: fonts.size.font18,
        fontWeight: 'bold',
        letterSpacing: 1,
        fontFamily: "MyriadPro",
    },
    description: {
        fontSize: fonts.size.font12,
        fontFamily: "MyriadPro",
        marginBottom: '3%'
    },
    button: {
        width: '42%',
        alignItems: 'center',
        paddingVertical: 6,
        paddingHorizontal: 12,
        elevation: 1,
        borderRadius: 12,
    },
    buttonText: {
        fontSize: fonts.size.font12,
        fontWeight: 'bold',
        letterSpacing: 1,
        color: '#ffffff',
        fontFamily: "MyriadPro",
    }
});

export default AlertComponent;
