import React, {
  useEffect,
  useState
} from 'react';
import {
  Pressable,
  StyleSheet,
  Text,
  View,
} from 'react-native';
import { useNetInfo } from '@react-native-community/netinfo';
import { Ionicons } from '@expo/vector-icons';
import { MaterialIcons } from '@expo/vector-icons';
import { MaterialCommunityIcons } from '@expo/vector-icons';

const NetworkState = () => {
  const netInfo = useNetInfo();
  const [userDismissed, setUserDismissed] = useState(false);

  return (
    !netInfo.isInternetReachable && !userDismissed
      ? <View style={styles.wrapper}>
          <View style={styles.msgBox}>
            <NetworkStateHeader />
            <NetworkStateBody netInfo={netInfo} />
            <View style={styles.actions}>
              <Pressable style={styles.dismissBtn}
                        onPress={() => setUserDismissed(true)}
              >
                <Text style={styles.dismissBtnText}>Lukk</Text>
              </Pressable>
            </View>
          </View>
      </View>
      : null
  );
}

const NetworkStateHeader = () => {
  return (
    <View style={styles.header}>
      <Ionicons name='warning-outline' size={32} color='#fff' />
      <Text style={styles.title}>Ingen internettilgang!</Text>
    </View>
  );
}

const NetworkStateBody = ({ netInfo }) => {
  return (
    <View style={styles.body}>
      <Text style={styles.bodyText}>
        Det ser ut til at du ikke har internettilgang.
      </Text>
      <Text style={styles.bodyText}>
        Koble deg til et nettverk for å bruke appen.
      </Text>
      <View style={styles.verticalSpacer}></View>
      {/* {
        netInfo.isWifiEnabled
          ? <View style={styles.header}>
              <MaterialIcons name="wifi" size={24} color="#fff" />
              <Text style={[styles.bodyText, styles.mLeft]}>
                <Text style={styles.bold}>Wifi:</Text> På
              </Text>
          </View>
          : <View style={styles.header}>
              <MaterialIcons name="wifi-off" size={24} color="#fff" />
              <Text style={[styles.bodyText, styles.mLeft]}>
                <Text style={styles.bold}>Wifi:</Text> Av
              </Text>
          </View>
      } */}
      {
        netInfo.isConnected
          ? <View style={[styles.header, styles.mTop]}>
              <MaterialCommunityIcons name="wifi-arrow-up-down" size={24} color="#fff" />
              <Text style={[styles.bodyText, styles.mLeft]}>
                <Text style={styles.bold}>Internett:</Text> Tilkoblet
              </Text>
          </View>
          : <View style={styles.header}>
              <MaterialCommunityIcons name="wifi-remove" size={24} color="#fff" />
              <Text style={[styles.bodyText, styles.mLeft]}>
                <Text style={styles.bold}>Internett:</Text> Frakoblet
              </Text>
          </View>
      }
    </View>
  );
}

const styles = StyleSheet.create({
  mLeft: { marginLeft: 10 },
  mTop: { marginTop: 10 },
  verticalSpacer: { height: 12 },
  bold: { fontWeight: 'bold' },
  wrapper: {
    zIndex: 9,
    elevation: 9,
    position: 'absolute',
    width: '100%',
    height: '100%',
    alignItems: 'center',
    justifyContent: 'center',
    backgroundColor: 'hsla(0, 0%, 0%, .75)'
  },
  msgBox: {
    minWidth: '50%',
    maxWidth: '75%',
    padding: 24,
    backgroundColor: '#C06030',
    borderRadius: 10,
  },

  header: {
    flexDirection: 'row',
    alignItems: 'center',
  },
  title: {
    marginLeft: 10,
    color: '#fff',
    fontSize: 24,
    fontWeight: 'bold',
    letterSpacing: 1
  },

  body: {
    paddingTop: 12,
  },
  bodyText: {
    fontSize: 18,
    color: '#fff',
  },

  actions: {
    flexDirection: 'column',
    alignItems: 'flex-end',
    paddingTop: 12,
  },
  dismissBtn: {
    paddingVertical: 10,
    paddingHorizontal: 20,
    backgroundColor: '#fff',
    borderRadius: 10,
  },
  dismissBtnText: {
    fontSize: 16,
    fontWeight: 'bold',
    letterSpacing: 1,
    color: '#C06030',
  }
});

export default NetworkState;