import React, {
    useEffect,
    useState,
} from "react";
import { StyleSheet, View } from "react-native";
import ClosetTab from 'src/global/components/tabs/ClosetTab';
import { selectShown, selectHideColors, selectFeature, selectShowColors, selectFamilyPicker } from 'src/global/reducers/closet/closetSlice';
import { useSelector } from "react-redux";
import ClosetGrid from 'src/global/components/grids/ClosetGrid';
import ColorDrawer from 'src/global/components/drawers/ColorDrawer';
import * as closet from 'src/global/constants/closetElements';
import FeaturesGrid from 'src/global/components/grids/FacialFeatures';
import FamilyPicker from 'src/global/components/grids/FamilyPicker';
import { Audio } from 'expo-av';

import { Sounds } from 'src/assets/sounds/sounds';

const styles = StyleSheet.create({
    mainContainer: {
        flex: 2,
        height: '100%', 
        backgroundColor: "#B58C70",
        justifyContent: "center",
        borderRadius: 20,
        right: 0, 
        shadowColor: "#000",
        shadowOffset: {
            width: 0,
            height: 10,
        },
        shadowOpacity: 0.37,
        shadowRadius: 7.49,
        elevation: 12,
    }, 
    childContainer: {
        flex: 1,
        flexDirection: 'row-reverse',
    },
    closetGrid: {
        flex: 1,
        width: '100%',
        backgroundColor: "#EDEFE9",
        justifyContent: "center",
        alignItems: 'center',
        borderRadius: 0,
        right: '0%', 
        shadowColor: "#000",
    }, 
    closetTab: {
        shadowOffset: {
            width: 0,
            height: 6,
        },
        shadowOpacity: 0.37,
        shadowRadius: 7.49,
        elevation: 12,
    }
})


const Closet = (props) => {

    const [menuSound, setMenuSound] = useState(new Audio.Sound());
    const [cardSound, setCardSound] = useState(new Audio.Sound());

    useEffect(() => {
        loadSounds();
    }, []);

    const loadSounds = async () => {
        await menuSound.unloadAsync();
        await cardSound.unloadAsync();

        await menuSound.loadAsync(Sounds.change);
        await cardSound.loadAsync(Sounds.picker);

        await menuSound.setVolumeAsync(0.3);
        await cardSound.setVolumeAsync(0.3);
    }

    const playSound = async (selectedSound) => {
        await menuSound.stopAsync();
        await cardSound.stopAsync();

        await selectedSound.playAsync();
    }

    const hideColors = useSelector(selectHideColors);    

    let colorDrawer = null 
    if(hideColors){
        colorDrawer = <ColorDrawer />
    }

    const items = useSelector(selectShown);
    const isFamilyPicker = useSelector(selectFamilyPicker)

    const closetItems = items? items : closet.features

    let closetGrid = <ClosetGrid closetItems={closetItems}
                                 isParent={props.isParent}
                                 sound={cardSound}
                                 playSound={playSound}
                     />
    if(closetItems == closet.features || closetItems == closet.featuresFamily){
        closetGrid = <FeaturesGrid isParent={props.isParent}
                                   sound={cardSound}
                                   playSound={playSound}
                     />
    }
    if(isFamilyPicker){
        closetGrid = <FamilyPicker />
    }

    return (
        <View style={styles.mainContainer}>
            <View style = {styles.childContainer}>
                <View style={styles.closetGrid}> 
                    {closetGrid}
                </View>
                <ClosetTab style={styles.closetTab}
                           isParent={props.isParent}
                           sound={menuSound}
                           playSound={playSound}
                />
            </View>
            {colorDrawer}
        </View>
    );
}

export default Closet; 
