import * as React from 'react';
import { View, SafeAreaView, ScrollView, StyleSheet, Dimensions } from 'react-native';
import ClosetCard from 'src/global/components/cards/ClosetCard';
import SvgEyeColor from 'src/assets/icons/Eye';
import SvgSkinColor from 'src/assets/icons/Skin';
import SvgFeatures from 'src/assets/icons/Features';
import * as closet from 'src/global/constants/closetElements'
import { useSelector } from 'react-redux';
import { selectActiveMember } from 'src/global/reducers/closet/closetSlice';

const win = Dimensions.get('window');

const styles = StyleSheet.create({
    grid: {
        flex: 1, 
        width: '100%',
        height: '100%',
        backgroundColor: '#D5B79E', 
        flexDirection: 'column', 
        alignItems: 'stretch', 
        justifyContent: 'space-around'
    }, 
    icon: {
        width: '26%',
        height: '26%', 
        marginLeft: '-4%', 
        marginRight: '-4%',
        marginTop: '0%'
    }, 
    eye: {
        width: '18%',
        height: '18%', 
        marginLeft: '0%', 
        marginTop: '0%'
    }, 

    scrollView: { 
        width: '100%',
    }, 
    row: {
        flexDirection: 'row',
        alignItems: 'flex-start',
        justifyContent: 'flex-start',
        width: '80%',
        marginTop: '0%', 
        marginRight: '18%', 
    },

    category: {
        flexDirection: 'row', 
        marginTop: '4%', 
        alignItems: 'center',
    },
    column: {
        marginHorizontal: 4,
        //paddingVertical: 10,
        paddingHorizontal: 20,
        // minWidth: 126, 
        minWidth: win.width*0.105,
        // minHeight: 150,
        // maxHeight: 200,
        maxHeight: win.height/4.2,
        alignItems: 'center',
        justifyContent: 'center',
        backgroundColor: '#FEF2E0',
        elevation: 5,
        borderWidth: 2,
        borderColor: "#B58C70",
        borderRadius: 10,   
        marginBottom: 10
    }
})


const FeaturesGrid = (props) => {

    const sound = props.sound;
    const playSound = props.playSound;

    const familyMember = useSelector(selectActiveMember)

    let eyes = closet.eyes
    let skins = closet.skins
    let features = closet.facialFeatures

    if(props.isParent){
     eyes = familyMember == 1? closet.eyesFamily : closet.eyesFamilyTwo
     skins = familyMember == 1? closet.skinsFamily : closet.skinsFamilyTwo
     features = familyMember == 1? closet.facialFeaturesFamily : closet.facialFeaturesFamilyTwo
    }

    return (
        <View style={styles.grid}>

            <View style={styles.category}>
                <SvgEyeColor style={styles.eye}/>  
              <View style={styles.row}>
                {
                    eyes.map((item) => (
                        <View key={item.number}
                            style={styles.column}>
                             <ClosetCard item={item}
                                         sound={sound}
                                         playSound={playSound}
                             /> 
                        </View>
                    ))
                }
                </View>
                </View>

                <View style={styles.category}>
                <SvgSkinColor style={styles.icon} />

                <View style={styles.row}>
                <SafeAreaView style={{width: '100%'}}>
                <ScrollView horizontal={true}>
               
                {
                    skins.map((item) => (
                        <View key={item.number}
                            style={styles.column}>
                             <ClosetCard item={item}
                                         sound={sound}
                                         playSound={playSound}
                             /> 
                        </View>
                    ))
                }
               
                </ScrollView>
                </SafeAreaView>
                </View>

                </View>

                <View style={styles.category}>
                <SvgFeatures style={styles.icon} />
            
              <View style={styles.row}>
                {
                    features.map((item) => (
                        <View key={item.number}
                            style={styles.column}>
                         <ClosetCard item={item}
                                     sound={sound}
                                     playSound={playSound}
                         />
                        </View>
                    ))
                }
                </View>
                </View>
  
        </View>
    )
}
export default FeaturesGrid;
