import React, {
    useEffect,
    useState,
} from "react";
import { Dimensions, StyleSheet, TouchableOpacity, View } from "react-native";
import Clothing from 'src/assets/icons/Clothing';
import Aid from 'src/assets/icons/Aid';
import Accessories from 'src/assets/icons/Accessorize';
import Face from 'src/assets/icons/FacialFeatures';
import Hair from 'src/assets/icons/Hair';
import SvgBathing from 'src/assets/icons/Bathing';
import * as closetElements from 'src/global/constants/closetElements';

import { useDispatch, useSelector } from 'react-redux';
import {
  setShown,
  setColorOptions,
  setShowColors,
  setFamilyPicker,
  setShowSwimWear,
  selectActiveMember
} from 'src/global/reducers/closet/closetSlice';
import SvgFamilyIcon from 'src/assets/icons/FamilyIcon';

const styles = StyleSheet.create({
    container: {
    //   padding: 26,
      padding: '5%',
      justifyContent: 'space-evenly',
      width: "18%",
      shadowOffset: {
        width: 0,
        height: 4,
			},
			shadowOpacity: 0.2,
			shadowRadius: 4,
			borderColor: "#775940",
			borderRightWidth: 3,
    },
    box: {
        height: '15%'
    }
  });

const ClosetTab = (props) => {
    const dispatch = useDispatch()
    const activeMember = useSelector(selectActiveMember)

    const clickHandler = (shown, showSwimWare, colorOptions) => {
        playSound(changeSound);
        dispatch(setShown(shown));
        dispatch(setShowSwimWear(showSwimWare));
        dispatch(setColorOptions(colorOptions));
    }

    const sound = props.sound;
    const playSound = props.playSound;
    
    const vHeight = Dimensions.get('window').height;

    if(props.isParent){
        if(activeMember == 1){
        return (
    <View style={[styles.container, {height: vHeight}]}>
            <TouchableOpacity style={styles.box} onPress={() => ( playSound(sound), dispatch(setShown(closetElements.featuresFamily)), dispatch(setFamilyPicker(true)), dispatch(setShowSwimWear(false)), dispatch(setColorOptions(6)))}>
                <SvgFamilyIcon />
            </TouchableOpacity>
            <TouchableOpacity style={styles.box} onPress={() => ( playSound(sound), dispatch(setShown(closetElements.featuresFamily)), dispatch(setFamilyPicker(false)), dispatch(setShowSwimWear(false)), dispatch(setColorOptions(6)))}>
                <Face />
            </TouchableOpacity>

            <TouchableOpacity style={styles.box} onPress={() => ( playSound(sound), dispatch(setShown(closetElements.hairStylesFamily)), dispatch(setFamilyPicker(false)), dispatch(setShowSwimWear(false)), dispatch(setColorOptions(7)))}>
            <Hair />
            </TouchableOpacity>
            
            <TouchableOpacity style={styles.box} onPress={() => ( playSound(sound), dispatch(setShown(closetElements.clothesFamily)), dispatch(setFamilyPicker(false)), dispatch(setShowSwimWear(false)), dispatch(setColorOptions(8)))}>
            <Clothing />
            </TouchableOpacity>
        
            <TouchableOpacity style={styles.box} onPress={() => ( playSound(sound), dispatch(setShown(closetElements.accessoriesFamily)), dispatch(setFamilyPicker(false)), dispatch(setShowSwimWear(false)), dispatch(setColorOptions(6)))}>
            <Accessories />
            </TouchableOpacity>
        </View>
        );
    } else {
        return (
            <View style={[styles.container, {height: vHeight}]}>
                    <TouchableOpacity style={styles.box} onPress={() => ( playSound(sound), dispatch(setShown(closetElements.featuresFamily)), dispatch(setFamilyPicker(true)), dispatch(setShowSwimWear(false)), dispatch(setColorOptions(6)))}>
                    <SvgFamilyIcon />
                    </TouchableOpacity>
                    <TouchableOpacity style={styles.box} onPress={() => ( playSound(sound), dispatch(setShown(closetElements.featuresFamily)), dispatch(setFamilyPicker(false)), dispatch(setShowSwimWear(false)), dispatch(setColorOptions(6)))}>
                        <Face />
                    </TouchableOpacity>
        
                    <TouchableOpacity style={styles.box} onPress={() => ( playSound(sound), dispatch(setShown(closetElements.hairStylesFamilyTwo)), dispatch(setFamilyPicker(false)), dispatch(setShowSwimWear(false)), dispatch(setColorOptions(11)))}>
                    <Hair />
                    </TouchableOpacity>
                    
                    <TouchableOpacity style={styles.box} onPress={() => ( playSound(sound), dispatch(setShown(closetElements.clothesFamilyTwo)), dispatch(setFamilyPicker(false)), dispatch(setShowSwimWear(false)), dispatch(setColorOptions(12)))}>
                    <Clothing />
                    </TouchableOpacity>
                
                    <TouchableOpacity style={styles.box} onPress={() => ( playSound(sound), dispatch(setShown(closetElements.accessoriesFamilyTwo)), dispatch(setFamilyPicker(false)), dispatch(setShowSwimWear(false)), dispatch(setColorOptions(6)))}>
                    <Accessories />
                    </TouchableOpacity>
                </View>
                );
        }
    } else {
    return(
        <View style={[styles.container, {height: vHeight}]}>
            <TouchableOpacity style={styles.box} onPress={() => ( playSound(sound), dispatch(setShown(closetElements.features)), dispatch(setFamilyPicker(false)), dispatch(setShowSwimWear(false)), dispatch(setColorOptions(6)))}>
                <Face />
            </TouchableOpacity>

            <TouchableOpacity style={styles.box} onPress={() => ( playSound(sound), dispatch(setShown(closetElements.hairStyles)), dispatch(setFamilyPicker(false)), dispatch(setShowSwimWear(false)), dispatch(setColorOptions(1)))}>
            <Hair />
            </TouchableOpacity>
            
            <TouchableOpacity style={styles.box} onPress={() => ( playSound(sound), dispatch(setShown(closetElements.clothes)), dispatch(setFamilyPicker(false)), dispatch(setShowSwimWear(false)), dispatch(setColorOptions(2)))}>
            <Clothing />
            </TouchableOpacity>
        
            <TouchableOpacity style={styles.box} onPress={() => ( playSound(sound), dispatch(setShown(closetElements.accessories)), dispatch(setFamilyPicker(false)), dispatch(setShowSwimWear(false)), dispatch(setColorOptions(5)))}>
            <Accessories />
            </TouchableOpacity>

            <TouchableOpacity style={styles.box} onPress={() => ( playSound(sound), dispatch(setShown(closetElements.aid)), dispatch(setFamilyPicker(false)), dispatch(setShowSwimWear(false)), dispatch(setColorOptions(6)))}>
            <Aid />
            </TouchableOpacity>

            <TouchableOpacity style={styles.box} onPress={() => ( playSound(sound), dispatch(setShown(closetElements.swimWear)), dispatch(setFamilyPicker(false)), dispatch(setShowSwimWear(true)), dispatch(setColorOptions(6)))}>
            <SvgBathing />
            </TouchableOpacity>

        </View>
    );
}
}
export default ClosetTab;
