import { createSlice } from '@reduxjs/toolkit';
import * as hues from 'src/global/constants/hues';
import { startTransition } from 'react';

export const familyMemberSlice = createSlice({
    name: 'familyMember', 
    initialState: {
        eyeColor: hues.BLUE_EYES,
        body: 1,
        bodyColors: {
            primary: hues.LIGHT_SKIN, 
            definition: hues.LIGHT_SKIN_DEF, 
            mouth: hues.LIGHT_SKIN_MOUTH, 
            cheeks: hues.LIGHT_SKIN_CHEEKS, 
            cheek_gradient: hues.LIGHT_SKIN_GR_CHEEKS, 
        },
        bottomStyle: 2,
        bottomColors: {
            bottomPrimaryColor: hues.BROWN_PRIMARY, 
            bottomSecondaryColor:  hues.BROWN_SECONDARY,
            bottomTertiaryColor:  hues.BROWN_TERTIARY,
            bottomQuaternaryColor:  hues.BROWN_QUATERNARY,
        },
        topStyle: 1,
        topColors: {
            topPrimaryColor: hues.BLUE_PRIMARY, 
            topSecondaryColor:  hues.BLUE_SECONDARY,
            topTertiaryColor:  hues.BLUE_TERTIARY,
            topQuaternaryColor:  hues.BLUE_QUATERNARY, 
        },
        shoeStyle: 2, 
        shoeColors: {
            shoePrimaryColor: hues.DARK_GREY_PRIMARY, 
            shoeSecondaryColor: hues.DARK_GREY_SECONDARY, 
            shoeQuaternaryColor: hues.DARK_GREY_QUATERNARY
        }, 
        hairStyle: 11, 
        hairColors: {
            hairPrimary: hues.RED_HAIR,
            hairDef: hues.RED_HAIR_DEF
        }, 
        glasses: false, 
        sunglasses: false, 
        beard: false
    }, 
    reducers: {
        setEyeColorFamily: (state, action) => {
            state.eyeColor = action.payload
        },
        setBody: (state, action) => {
            state.body = action.payload
        }, 
        setBodyColors: (state, action) => {
            switch(action.payload){
                case 1: 
                state.bodyColors.primary = hues.FAIR_SKIN
                state.bodyColors.definition = hues.FAIR_SKIN_DEF
                state.bodyColors.mouth = hues.FAIR_SKIN_MOUTH
                break; 
                case 2: 
                state.bodyColors.primary = hues.LIGHT_SKIN
                state.bodyColors.definition = hues.LIGHT_SKIN_DEF
                state.bodyColors.mouth = hues.LIGHT_SKIN_MOUTH
                break;
                case 3: 
                state.bodyColors.primary = hues.TAN_SKIN
                state.bodyColors.definition = hues.TAN_SKIN_DEF
                state.bodyColors.mouth = hues.TAN_SKIN_MOUTH
                break;
                case 4: 
                state.bodyColors.primary = hues.DEEP_SKIN
                state.bodyColors.definition = hues.DEEP_SKIN_DEF
                state.bodyColors.mouth = hues.DEEP_SKIN_MOUTH
                break;
            }
        }, 
        setBottomStyleFamily: (state, action) => {
            state.bottomStyle = action.payload
        }, 
        setBottomColorsFamily: (state, action) => {
            state.bottomColors = action.payload
        },
        setTopStyleFamily: (state, action) => {
            state.topStyle = action.payload
        }, 
        setTopColorsFamily: (state, action) => {
            state.topColors = action.payload
        }, 
        setShoeStyleFamily: (state, action) => {
            state.shoeStyle = action.payload
        }, 
        setShoeColorsFamily: (state, action) => {
            state.shoeColors = action.payload
        }, 
        setHairStyleFamily: (state, action) => {
            state.hairStyle = action.payload
        }, 
        setHairColorFamily: (state, action) => {
            state.hairColors = action.payload
        }, 
        setBeard: (state, action) => {
            state.beard = !state.beard
        },
        setGlassesStyle: (state, action) => {
            switch(action.payload){
                case 1: 
                state.glasses = !state.glasses
                state.sunglasses = false
                break; 
                case 2: 
                state.sunglasses = !state.sunglasses
                state.glasses = false
                break; 
            }
     }, 
    }
});

export const { setBody, setEyeColorFamily, setBodyColors, setBottomStyleFamily, setBottomColorsFamily, setTopStyleFamily, setTopColorsFamily, setShoeStyleFamily, setShoeColorsFamily, setHairStyleFamily, setHairColorFamily, setBeard, setGlassesStyle } = familyMemberSlice.actions;

export const selectBottom = state => state.familyMember.bottomStyle; 
export const selectBottomColors = state => state.familyMember.bottomColors;
export const selectSkin = state => state.familyMember.skin;
export const selectBody = state => state.familyMember.body;
export const selectTop = state => state.familyMember.topStyle;
export const selectTopColors = state => state.familyMember.topColors;
export const selectShoes = state => state.familyMember.shoeStyle; 
export const selectShoeColors = state => state.familyMember.shoeColors;
export const selectBodyColors = state => state.familyMember.bodyColors;
export const selectHair = state => state.familyMember.hairStyle;
export const selectHairColors = state => state.familyMember.hairColors;
export const selectGlasses = state => state.familyMember.glasses; 
export const selectSunGlasses = state => state.familyMember.sunglasses;
export const selectEyeColor = state => state.familyMember.eyeColor;
export const selectBeard = state => state.familyMember.beard;

export default familyMemberSlice.reducer;
