import { createSlice } from '@reduxjs/toolkit';
import * as hues from 'src/global/constants/hueHandler';

export const closetSlice = createSlice({
    name: 'closet', 
    initialState: {
       shown: null,
       colorOptions: hues.hairColors,
       showColors: false, 
       showSave: true, 
       isFeatures: false, 
       colorMargin: '0%',
       hideColors: true, 
       isSwimWear: false, 
       isFamilyPicker: false,
       activeMember: 0
    }, 
    reducers: {
        setShown: (state, action) => {
               state.shown = action.payload;
        },
        setHideColors: (state, action) => {
                state.hideColors = !state.hideColors
        },
        setFamilyPicker: (state, action) => {
                state.isFamilyPicker = action.payload
        },
        setActiveMember: (state, action) => {
            state.activeMember = action.payload
        },
        setColorOptions: (state, action) => {
                switch(action.payload){
                    case 1: 
                    state.colorOptions = hues.hairColors
                    state.hideColors = true
                    break; 
                    case 2: 
                    state.colorOptions = hues.topColors
                    state.hideColors = true
                    break; 
                    case 3: 
                    state.colorOptions = hues.bottomColors
                    state.hideColors = true
                    break; 
                    case 4: 
                    state.colorOptions = hues.shoeColors
                    state.hideColors = true
                    break; 
                    case 5: 
                    state.colorOptions = hues.headWearColors
                    state.hideColors = true
                    break;
                    case 6: 
                    state.hideColors = false
                    break;
                    case 7: 
                    state.colorOptions = hues.hairColorsFamily
                    state.hideColors = true
                    break; 
                    case 8: 
                    state.colorOptions = hues.topColorsFamily 
                    state.hideColors = true
                    break; 
                    case 9: 
                    state.colorOptions = hues.shoeColorsFamily
                    state.hideColors = true
                    break; 
                    case 10: 
                    state.colorOptions = hues.bottomColorsFamily
                    state.hideColors = true
                    break; 
                    case 11: 
                    state.colorOptions = hues.hairColorsFamilyTwo
                    state.hideColors = true
                    break; 
                    case 12: 
                    state.colorOptions = hues.topColorsFamilyTwo
                    state.hideColors = true
                    break; 
                    case 13: 
                    state.colorOptions = hues.shoeColorsFamilyTwo
                    state.hideColors = true
                    break; 
                    case 14: 
                    state.colorOptions = hues.bottomColorsFamilyTwo
                    state.hideColors = true
                    break; 
                }
        }, 
        setShowColors: (state, action) => {
            state.showColors = !state.showColors
            if(action.payload) {
                state.colorMargin = '0%'
            } else {
                state.colorMargin = '-13%'
            }
        }, 
        setShowSave: (state, action) => {
            state.showSave = action.payload;
        },
        setFeature: (state, action) => {
            state.isFeatures = action.payload;
        }, 
        setColorMargin: (state, action) => {
     
        }, 
        setShowSwimWear: (state, action) => {
            state.isSwimWear = action.payload;
        }
    }
});

export const { setShowSwimWear, setFamilyPicker, setActiveMember,
    setHideColors, setColorMargin, setFeature, setShown, setColorOptions, setShowColors, setShowSave } = closetSlice.actions;

export const selectFeature = state => state.closet.isFeatures;
export const selectShown = state => state.closet.shown;
export const selectColorOption = state => state.closet.colorOptions;
export const selectShowColors = state => state.closet.showColors;
export const selectShowSave = state => state.closet.showSave;
export const selectColorMargin = state => state.closet.colorMargin;
export const selectHideColors = state => state.closet.hideColors;
export const selectShowSwimWear = state => state.closet.isSwimWear;
export const selectFamilyPicker = state => state.closet.isFamilyPicker;
export const selectActiveMember = state => state.closet.activeMember;

export default closetSlice.reducer;
