import { createSlice } from '@reduxjs/toolkit';

import { PuzzleMock } from 'src/global/mock-data/puzzle.mock.js';

const puzzleSlice = createSlice({
  name: 'puzzle',
  initialState: {
    puzzle: PuzzleMock,
  },
  reducers: {

    // all functions takes in puzzle piece id
    // ex: clickedToggle(puzzlePiece.name)
    // call same function with same id to toggle

    enable: (state, action) => {
      let selectedPuzzlePiece = state.puzzle.find((piece) => piece.name === action.payload);

      selectedPuzzlePiece.state.disabled = false;
      state.puzzle = state.puzzle;
    },

    disable: (state, action) => {
      let selectedPuzzlePiece = state.puzzle.find((piece) => piece.name === action.payload);

      selectedPuzzlePiece.state.disabled = true;
      state.puzzle = state.puzzle;
    },

    unlock: (state, action) => {
      let selectedPuzzlePiece = state.puzzle.find((piece) => piece.name === action.payload);

      console.log(action.payload);
      console.log(selectedPuzzlePiece);

      selectedPuzzlePiece.state.locked = false;
      state.puzzle = state.puzzle;
    },

    lock: (state, action) => {
      let selectedPuzzlePiece = state.puzzle.find((piece) => piece.name === action.payload);

      selectedPuzzlePiece.state.locked = true;
      state.puzzle = state.puzzle;
    },

    clicked: (state, action) => {
      let selectedPuzzlePiece = state.puzzle.find((piece) => piece.name === action.payload);

      selectedPuzzlePiece.state.clicked = true;
      state.puzzle = state.puzzle;
    },

    unclicked: (state, action) => {
      let selectedPuzzlePiece = state.puzzle.find((piece) => piece.name === action.payload);

      selectedPuzzlePiece.state.clicked = false;
      state.puzzle = state.puzzle;
    },

  },
});

export const {
  enable,
  disable,
  unlock,
  lock,
  clicked,
  unclicked,
} = puzzleSlice.actions;

export default puzzleSlice.reducer;
