import React, {
  useEffect,
  useState,
} from 'react';
import {
  Dimensions,
  ImageBackground,
  Pressable,
  StyleSheet,
  Text,
  View,
} from 'react-native';
import { Audio } from 'expo-av';

import pool from 'src/assets/images/activityImages/basseng.jpg'
import gym from 'src/assets/images/activityImages/Gymsal.jpg'
import alpint from 'src/assets/images/activityImages/Alpint.jpg'
import horse from 'src/assets/images/activityImages/horseImage.jpg'
import kano from 'src/assets/images/activityImages/canoeImage.jpg'
import skates from 'src/assets/images/activityImages/Skates.jpg'
import bicycle from 'src/assets/images/activityImages/cycleImage.jpg'
import hike from 'src/assets/images/activityImages/hikeImage.jpg'
import climbing from 'src/assets/images/activityImages/climbingImage.jpg'
import outdoorWinter from 'src/assets/images/activityImages/outdoorWinter.jpg'
import outdoor from 'src/assets/images/activityImages/outdoorWinter.jpg'
import screen from 'src/assets/images/activityImages/screenImage.jpg'
import playOutside from 'src/assets/images/activityImages/playOutsideImage.jpg'
import skiing from 'src/assets/images/activityImages/langrennImage.jpg'
import hikeWinter from 'src/assets/images/activityImages/hikeWinterImage.jpg'

import fonts from 'src/assets/fonts/fonts';
import haptics from 'src/global/constants/haptics';
import * as colorPalette from 'src/global/constants/colorPalette';
import BackButton from 'src/global/components/buttons/BackButton';

import { useDispatch, useSelector } from 'react-redux';

import background from 'src/assets/images/howToBackgrounds/summerBackground.jpg';
import WinterBackground from 'src/assets/images/backgrounds/BackgroundActiveYouWinter.jpg';

import {
  unlock,
  clicked,
} from 'src/global/reducers/puzzle/puzzle.slice.js';

import Lion from 'src/assets/images/LionWondering.js';
import {
  postUser,
  postUserData,
} from 'src/global/services/UserService';

import { Ionicons } from '@expo/vector-icons';

import AvatarHead from 'src/global/avatar/body/head/HeadComponentActiveYou';

import AvatarView from 'src/views/active-you/ActiveYouAvatarPlacement';

import { Sounds } from 'src/assets/sounds/sounds';
import {
  setActivities,
  selectActivities,
  setPlayOutside,
  setMoveMusic,
  selectMoveMusic,
  selectPlayOutside,
  setScreen,
  selectScreen,
  selectOutdoor,
  setOutdoor,
  selectClimbing,
  setClimbing,
  selectPool,
  selectHike,
  selectAlpin,
  selectCanoe,
  selectGym,
  selectHorse,
  selectCycle,
  selectSkates,
  setAlpin,
  setHike,
  setCanoe,
  setCycle,
  setGym,
  setHorse,
  setPool,
  setSkates,
  selectSkiing,
  setSkiing,
} from 'src/global/reducers/active-you/activeYouSlice';


// Check for internet connection
import NetworkState from 'src/global/components/alerts/network.state';

function ActiveYou({ navigation }) {

  const win = Dimensions.get('window');
  const ratio = win.width / win.height;

  const [isTablet, setIsTablet] = useState(false);

  const [currentSound, setCurrentSound] = useState()

  const SoundPlayer = (name, sound) => {
    if (currentSound == null) {
      console.log('Sound is undefined');
    } else {
      currentSound.sound.unloadAsync().catch(() => { });
    }

    console.log('Playing: ' + name);
    Audio.Sound.createAsync(
      sound,
      { shouldPlay: true }
    ).then((res) => {
      setCurrentSound(res);
      res.sound.setOnPlaybackStatusUpdate((status) => {

        if (!status.didJustFinish) return;
        console.log('Unloading ' + name);

        res.sound.unloadAsync().catch(() => { });
      });
    }).catch((error) => { });
  }

  function isTabletBasedOnRatio(ratio) {
    if (ratio > 1.6) {
      { console.log('Is Phone') }
      setIsTablet(false);
    } else {
      { console.log('Is Tablet') }
      setIsTablet(true);
    }
  }


  const dispatch = useDispatch()

  const activityTracker = useSelector(selectActivities);

  const voice = Sounds.female.hanna;

  const poolSound = voice.swimmingpool;
  const gymSound = voice.gym;
  const alpinSound = voice.alpine;
  const horseSound = voice.riding;
  const canoeSound = voice.wateractivities;
  const skatesSound = voice.skates;
  const bicycleSound = voice.cycling;
  const hikingSound = voice.hiking;
  const climbingSound = voice.climbing;
  const outdoorSound = voice.outdoor_life;
  const screenSound = voice.gaming_workout;
  const playOutsideSound = voice.play_outside;
  const musicSound = voice.movement_to_music;
  const skiingSound = voice.skiing;

  const successSound = Sounds.success;
  const navBwdSound = Sounds.navigation_backward;


  const alpinMood = useSelector(selectAlpin);
  const horseMood = useSelector(selectHorse);
  const cycleMood = useSelector(selectCycle);
  const skatesMood = useSelector(selectSkates);
  const gymMood = useSelector(selectGym);
  const poolMood = useSelector(selectPool);
  const canoeMood = useSelector(selectCanoe);
  const hikeMood = useSelector(selectHike);
  const climbingMood = useSelector(selectClimbing);
  const outdoorMood = useSelector(selectOutdoor);
  const screenMood = useSelector(selectScreen);
  const playMood = useSelector(selectPlayOutside);
  const musicMood = useSelector(selectMoveMusic);
  const skiingMood = useSelector(selectSkiing);

  const activityList1 = [
    { activity: 'pool', activityImage: pool, sound: poolSound, rating: poolMood },
    { activity: 'gym', activityImage: gym, sound: gymSound, rating: gymMood },
    { activity: 'hike', activityImage: hikeWinter, sound: hikingSound, rating: hikeMood },
    { activity: 'horse', activityImage: horse, sound: horseSound, rating: horseMood },
    { activity: 'canoe', activityImage: kano, sound: canoeSound, rating: canoeMood },
    { activity: 'climbing', activityImage: climbing, sound: climbingSound, rating: climbingMood },
    { activity: 'bicycle', activityImage: bicycle, sound: bicycleSound, rating: cycleMood },
    { activity: 'outdoor', activityImage: outdoorWinter, sound: outdoorSound, rating: outdoorMood },
    { activity: 'screen', activityImage: screen, sound: screenSound, rating: screenMood },
    { activity: 'playOutside', activityImage: playOutside, sound: playOutsideSound, rating: playMood },
    { activity: 'musicMove', activityImage: gym, sound: musicSound, rating: musicMood },
    { activity: 'alpine', activityImage: alpint, sound: alpinSound, rating: alpinMood },
    { activity: 'skates', activityImage: skates, sound: skatesSound, rating: skatesMood },
    { activity: 'skiing', activityImage: skiing, sound: skiingSound, rating: skatesMood }
  ]

  let activityList = {
    activityRatings: {
      alpin: alpinMood,
      horse: horseMood,
      cycle: cycleMood,
      skates: skatesMood,
      gym: gymMood,
      pool: poolMood,
      hike: hikeMood,
      canoe: canoeMood,
      climbing: climbingMood,
      outdoor: outdoorMood,
      screen: screenMood,
      playOutside: playMood,
      musicMove: musicMood,
      skiing: skiingMood
    }
  }

  const [moodSelect, setMoodSelect] = useState(activityList1[activityTracker].rating);

  const moodSelection = (mood) => {
    if (moodSelect != mood) {
      haptics.buttonHaptics();
      setMoodSelect(mood);
    }
  }

  const TextArray = [
    'Hva synes du om å bade i basseng?',
    'Liker du å trene på treningsrom eller i sal?',
    'Liker du å være på tur?',
    'Liker du å ri på hest?',
    'Liker du å drive med vannaktivitet ute?',
    'Liker du å klatre?',
    'Hva synes du om å sykle?',
    'Hva synes du om å drive friluftsliv?',
    'Hva synes du om å bruke spill til trening?',
    'Hva synes du om å leke ute?',
    'Liker du å bevege deg til musikk?',
    'Hva synes du om å kjøre alpint, snowboard eller sitski?',
    'Liker du å drive med aktitivet på is?',
    'Liker du å stå på langrenn?'
  ];


  useEffect(() => {
    console.log('TEST1: ' + activityList1[activityTracker].activity)
    console.log('TEST2: ' + activityList1[activityTracker].sound)

    SoundPlayer(activityList1[activityTracker].activity, activityList1[activityTracker].sound);

    isTabletBasedOnRatio(ratio);

    console.log('height: ' + win.height)
    console.log('width: ' + win.width)
  }, []);


  const backToMenu = () => {
    haptics.buttonHaptics();

    SoundPlayer('navBack', navBwdSound)
    putActivity()
    setMoodSelect(moodSelect);

    postUser(activityList)
    navigation.popToTop();

  }

  const preActivity = () => {
    haptics.buttonHaptics();
    putActivityReverse()
    return (dispatch(setActivities(activityTracker - 1)))
  }

  const putActivity = () => {
    console.log('putActivity called')
    switch (activityTracker) {
      case 0:
        dispatch(setPool(moodSelect))
        setMoodSelect(gymMood)
        break;
      case 1:
        dispatch(setGym(moodSelect))
        setMoodSelect(hikeMood)
        break;
      case 2:
        dispatch(setHike(moodSelect))
        setMoodSelect(horseMood)
        break;
      case 3:
        dispatch(setHorse(moodSelect))
        setMoodSelect(canoeMood)
        break;
      case 4:
        dispatch(setCanoe(moodSelect))
        setMoodSelect(climbingMood)
        break;
      case 5:
        dispatch(setClimbing(moodSelect))
        setMoodSelect(cycleMood)
        break;
      case 6:
        dispatch(setCycle(moodSelect))
        setMoodSelect(outdoorMood)
        break;
      case 7:
        dispatch(setOutdoor(moodSelect))
        setMoodSelect(screenMood)
        break;
      case 8:
        dispatch(setScreen(moodSelect))
        setMoodSelect(playMood)
        break;
      case 9:
        dispatch(setPlayOutside(moodSelect))
        setMoodSelect(musicMood)
        break;
      case 10:
        dispatch(setMoveMusic(moodSelect))
        setMoodSelect(alpinMood)
        break;
      case 11:
        dispatch(setAlpin(moodSelect))
        setMoodSelect(skatesMood)
        break;
      case 12:
        dispatch(setSkates(moodSelect))
        setMoodSelect(skiingMood)
        break;
      case 13:
        dispatch(setSkiing(moodSelect))

    }
  }


  const putActivityReverse = () => {
    switch (activityTracker) {
      case 0:
        dispatch(setPool(moodSelect))
        break;
      case 1:
        dispatch(setGym(moodSelect))
        setMoodSelect(poolMood)
        break;
      case 2:
        dispatch(setHike(moodSelect))
        setMoodSelect(gymMood)
        break;
      case 3:
        dispatch(setHorse(moodSelect))
        setMoodSelect(hikeMood)
        break;
      case 4:
        dispatch(setCanoe(moodSelect))
        setMoodSelect(horseMood)
        break;
      case 5:
        dispatch(setClimbing(moodSelect))
        setMoodSelect(canoeMood)
        break;
      case 6:
        dispatch(setCycle(moodSelect))
        setMoodSelect(climbingMood)
        break;
      case 7:
        dispatch(setOutdoor(moodSelect))
        setMoodSelect(cycleMood)
        break;
      case 8:
        dispatch(setScreen(moodSelect))
        setMoodSelect(outdoorMood)
        break;
      case 9:
        dispatch(setPlayOutside(moodSelect))
        setMoodSelect(screenMood)
        break;
      case 10:
        dispatch(setMoveMusic(moodSelect))
        setMoodSelect(playMood)
        break;
      case 11:
        dispatch(setAlpin(moodSelect))
        setMoodSelect(musicMood)
        break;
      case 12:
        dispatch(setSkates(moodSelect))
        setMoodSelect(alpinMood)
        break;
      case 13:
        dispatch(setSkiing(moodSelect))

    }
  }

  const nextActivity = async () => {
    putActivity()
    if (activityTracker == activityList1.length - 1) {
      haptics.successHaptic();
      SoundPlayer('SuccessSound', successSound);
      dispatch(setMoveMusic(moodSelect));
      dispatch(clicked('PuzzleThree'));
      dispatch(unlock('PuzzleFour'));
      dispatch(unlock('PuzzleFive'));
      dispatch(unlock('PuzzleSix'));

      postUser(activityList)

      dispatch(setActivities(0))

      console.log('Active You Finisehd')
      return (navigation.popToTop())
    } else {
      console.log('Next Activity')
      haptics.buttonHaptics();
      SoundPlayer(activityList1[activityTracker + 1].activity, activityList1[activityTracker + 1].sound);
      // stopPreviousSound(soundArray[activityTracker])
      // playSound(soundArray[activityTracker+1])

      return (dispatch(setActivities(activityTracker + 1)))
    }
  }

  return (
    <ImageBackground source={WinterBackground} style={styles.container}>

      <View style={styles.LeftContainer}>
        <View style={styles.backButtonContainer}>
          <BackButton buttonColor={colorPalette.TURQUOISE_SURF} onPress={() => backToMenu()} />
        </View>

        <View style={styles.infoTextContainer}>
          <Text style={styles.infoText}> {TextArray[activityTracker]} </Text>
        </View>
        <Lion style={styles.pet} />
      </View>

      <View style={styles.childContainer} >
        <View style={styles.pictureFrame}>
          {moodSelect != 0 ? (<Pressable style={isTablet ? styles.activityButtonNextTablet : styles.activityButtonNext} onPress={() => nextActivity()}>
            <Ionicons name='chevron-forward-sharp' style={styles.activityButtonIcon} />
          </Pressable>) : null}
          {activityTracker != 0 ? (<Pressable style={isTablet ? styles.activityButtonBackTablet : styles.activityButtonBack} onPress={() => preActivity()}>
            <Ionicons name='chevron-back-sharp' style={styles.activityButtonIcon} />
          </Pressable>) : null}
          <ImageBackground source={activityList1[activityTracker].activityImage} style={styles.activityImage}>
            <AvatarView activityID={activityTracker} mood={moodSelect} />
          </ImageBackground>
        </View>
        {/*  */}
        <View style={styles.facesRow}>
          <Pressable style={[moodSelect == 1 ? styles.avatarFaceGroupSelected : styles.avatarFaceGroup, { borderColor: '#F096A0' }]}
            onPress={() => moodSelection(1)}>
            <View style={styles.faceView}>
              <Text style={[moodSelect == 1 ? styles.avatarTextSelected : styles.avatarText]}>IKKE GØY</Text>
              <View style={[moodSelect == 1 ? styles.avatarMoodSelected : styles.avatarMood]}>
                <AvatarHead pos={1} mood={mood = 2} />
              </View>
            </View>
          </Pressable>
          {/*  */}
          <Pressable style={[moodSelect == 2 ? styles.avatarFaceGroupSelected : styles.avatarFaceGroup, { borderColor: '#F09565' }]}
            onPress={() => moodSelection(2)}>
            <View style={styles.faceView}>
              <Text style={[moodSelect == 2 ? styles.avatarTextSelected : styles.avatarText]}>SKUMMELT</Text>
              <View style={[moodSelect == 2 ? styles.avatarMoodSelected : styles.avatarMood]}>
                <AvatarHead pos={1} mood={mood = 4} />
              </View>
            </View>
          </Pressable>
          {/*  */}
          <Pressable style={[moodSelect == 5 ? styles.avatarFaceGroupSelected : styles.avatarFaceGroup, { borderColor: '#F4BC57' }]}
            onPress={() => moodSelection(5)}>
            <View style={styles.faceView}>
              <Text style={[moodSelect == 5 ? styles.avatarTextSelected : styles.avatarText]}>VET IKKE</Text>
              <View style={[moodSelect == 5 ? styles.avatarMoodSelected : styles.avatarMood]}>
                <AvatarHead pos={1} mood={mood = 8} />
              </View>
            </View>
          </Pressable>
          {/*  */}
          <Pressable style={[moodSelect == 3 ? styles.avatarFaceGroupSelected : styles.avatarFaceGroup, { borderColor: '#90CCBD' }]}
            onPress={() => moodSelection(3)}>
            <View style={styles.faceView}>
              <Text style={[moodSelect == 3 ? styles.avatarTextSelected : styles.avatarText]}>LITT GØY</Text>
              <View style={[moodSelect == 3 ? styles.avatarMoodSelected : styles.avatarMood]}>
                <AvatarHead pos={1} mood={mood = 5} />
              </View>
            </View>
          </Pressable>
          {/*  */}
          <Pressable style={[moodSelect == 4 ? styles.avatarFaceGroupSelected : styles.avatarFaceGroup, { borderColor: '#94BE4E' }]}
            onPress={() => moodSelection(4)}>
            <View style={styles.faceView}>
              <Text style={[moodSelect == 4 ? styles.avatarTextSelected : styles.avatarText]}>VELDIG GØY</Text>
              <View style={[moodSelect == 4 ? styles.avatarMoodSelected : styles.avatarMood]}>
                <AvatarHead pos={1} mood={mood = 3} />
              </View>
            </View>
          </Pressable>
        </View>
      </View>

      {/*
              Check for network connection
              If no connection show error
// 
              NB: Place at the end of a component!
            */}
      <NetworkState />

    </ImageBackground>

  );
}

const win = Dimensions.get('window');
const ratio = win.height / win.width;

const styles = StyleSheet.create({
  container: {
    flex: 1,
    flexDirection: 'row',
    backgroundColor: '#FFFFFF'
  },
  childContainer: {
    flex: 3,
    flexDirection: 'column',
    marginRight: '1%',
    maxWidth: win.width * 0.8,
  },
  LeftContainer: {
    flex: 1,
    // width:  win.width*0.25,
    // maxWidth: win.width*0.25,
    flexDirection: 'column',
    justifyContent: 'center',
  },
  pet: {
    flex: 2.5,
    maxWidth: win.width * 0.2,
    height: '70%',
    left: '10%',
    resizeMode: 'contain',
  },
  pictureFrame: {
    flex: 2,
    width: '100%',
    maxWidth: win.width * 0.8,
    minHeight: 100,
    flexDirection: 'column',
    paddingTop: '1%',
    paddingRight: '1%',
    marginTop: '1%',
    borderBottomLeftRadius: 30,
  },
  activityImage: {
    flex: 1,
    resizeMode: 'stretch',
    borderColor: '#FFFFFF',
    borderWidth: win.width / 250,
    borderRadius: 10,
    shadowColor: 'black',
    shadowOffset: {
      width: 1,
      height: 3,
    },
    shadowOpacity: 0.5,
    shadowRadius: 4,
    overflow: 'hidden'
  },
  facesRow: {
    flex: 1,
    width: '100%',
    flexDirection: 'row',
    justifyContent: 'space-evenly',
    alignItems: 'center',
    marginBottom: '3%',
    marginTop: '3%'
  },
  avatarFaceGroup: {
    flex: 1,
    backgroundColor: '#FFFFFF',
    borderTopRightRadius: 25,
    borderRadius: 20,
    marginRight: win.height * 0.01,
    marginLeft: win.height * 0.01,
    height: win.height * 0.23,
    maxHeight: win.height * 0.23,
    maxWidth: win.height * 0.23,
    paddingTop: '1%',
    borderWidth: win.width / 200,
    alignItems: 'center',
    overflow: 'hidden'
  },
  avatarFaceGroupSelected: {
    flex: 1,
    backgroundColor: '#FFFFFF',
    borderTopRightRadius: 25,
    borderRadius: 20,
    minHeight: 10,
    height: win.height * 0.25,
    maxHeight: win.height * 0.25,
    maxWidth: win.height * 0.25,
    paddingTop: '1%',
    overflow: 'hidden',
    borderWidth: win.width / 200,
    alignItems: 'center',
    overflow: 'visible',
    shadowColor: '#171717',
    shadowOffset: {
      width: 1,
      height: 1,
    },
    shadowOpacity: 0.9,
    shadowRadius: 7,

  },
  avatarFaceGroup1: {
    flex: 1,
    backgroundColor: '#FFF3DF',
    borderTopRightRadius: 35,
    borderTopLeftRadius: 35,
    marginRight: 20,
    paddingTop: '0%',
    shadowColor: 'black',
    shadowOffset: {
      width: 3,
      height: 3,
    },
    shadowOpacity: 0.5,
    shadowRadius: 5,
  },
  avatarFace: {
    height: '80%',
    width: '80%',
    alignSelf: 'center',
  },
  avatarText: {
    marginTop: win.height * 0.005,
    marginBottom: win.width / 1000,
    textAlign: 'center',
    fontSize: win.width / 60,
    fontFamily: 'MyriadPro',
  },
  avatarTextSelected: {
    marginTop: win.height * 0.01,
    marginBottom: win.width / 1000,
    textAlign: 'center',
    fontSize: win.width / 52,
    fontFamily: 'MyriadPro',
  },
  backText: {
    fontSize: win.height / 30,
    fontFamily: 'MyriadPro',
    color: '#232021'
  },
  infoTextContainer: {
    flex: 3,
    justifyContent: 'center',
    alignSelf: 'center',
    marginLeft: '3%',
    width: '80%',
    maxWidth: '80%'

  },
  infoText: {
    textAlign: 'center',
    fontSize: fonts.size.font14,
    backgroundColor: 'white',
    padding: win.width / 65,
    borderRadius: 30,
    fontFamily: 'MyriadPro',
    overflow: 'hidden'
  },
  activityButtonNext: {
    position: 'absolute',
    zIndex: 1,
    bottom: '80%',
    right: '1%',
    padding: 10,
    borderRadius: 100,
    backgroundColor: '#FFFFFF',
    shadowColor: 'black',
    shadowOffset: {
      width: 3,
      height: 3,
    },
    shadowOpacity: 0.5,
    shadowRadius: 5,
  },
  activityButtonNextTablet: {
    position: 'absolute',
    zIndex: 1,
    bottom: '50%',
    right: '1%',
    padding: 10,
    borderRadius: 100,
    backgroundColor: '#FFFFFF',
    shadowColor: 'black',
    shadowOffset: {
      width: 3,
      height: 3,
    },
    shadowOpacity: 0.5,
    shadowRadius: 5,
  },
  activityButtonBack: {
    position: 'absolute',
    zIndex: 1,
    bottom: '80%',
    padding: 10,
    borderRadius: 100,
    backgroundColor: '#FFFFFF',
    shadowColor: 'black',
    shadowOffset: {
      width: 3,
      height: 3,
    },
    shadowOpacity: 0.5,
    shadowRadius: 5,
  },
  activityButtonBackTablet: {
    position: 'absolute',
    zIndex: 1,
    bottom: '50%',
    padding: 10,
    borderRadius: 100,
    backgroundColor: '#FFFFFF',
    shadowColor: 'black',
    shadowOffset: {
      width: 3,
      height: 3,
    },
    shadowOpacity: 0.5,
    shadowRadius: 5,
  },
  activityButtonText: {
    fontSize: 25,
    fontWeight: 'bold',
    fontFamily: 'MyriadPro',
  },
  activityButtonIcon: {
    fontSize: win.width / 30,
    color: colorPalette.TURQUOISE_SURF,
  },
  avatarMood: {
    aspectRatio: 4 / 3,
    width: win.height * 0.17,
    top: win.height * 0.01,
  },
  avatarMoodSelected: {
    aspectRatio: 4 / 3,
    width: win.height * 0.19,
    top: win.height * 0.01,
  },
  faceView: {
    flex: 1,
    height: '100%',
    width: '100%',
    alignItems: 'center',
    overflow: 'hidden',
    marginBottom: '3%',
  },
  backButtonContainer: {
    flex: 1
  }

})


export default ActiveYou;
