import React, { useEffect, useState } from 'react';
import {
  Dimensions,
  ImageBackground,
  Pressable,
  StyleSheet,
  Text,
  View,
} from 'react-native';
import Avatar from 'src/global/avatar/AvatarComponent';
import AvatarPos4 from 'src/global/avatar/AvatarPos4Component';
import Closet from 'src/global/components/containers/Closet';
import { useSelector } from 'react-redux';

import { selectWheelChair } from 'src/global/reducers/avatar/aidSlice';
import { selectShowSwimWear } from 'src/global/reducers/closet/closetSlice';

import * as closetElements from 'src/global/constants/closetElements';

// import room from 'src/assets/images/Room2.jpg'
import room from 'src/assets/images/Room.png';

import { useDispatch } from 'react-redux';
import {
  setShown,
  setColorOptions,
  setShowColors,
  setShowSwimWear,
} from 'src/global/reducers/closet/closetSlice';

import {
  unlock,
  clicked,
} from 'src/global/reducers/puzzle/puzzle.slice.js';

import { Audio } from 'expo-av';
import { Sounds } from 'src/assets/sounds/sounds';

import BackButton from 'src/global/components/buttons/BackButton';
import * as colorPalette from 'src/global/constants/colorPalette';
import haptics from 'src/global/constants/haptics';

// import { useOrientation } from '../useOrientation';

import AsyncStorage from '@react-native-async-storage/async-storage';
import metrics from 'src/global/constants/metrics';
import fonts from 'src/assets/fonts/fonts';

let width = Dimensions.get('window').width;
const win = Dimensions.get('window');
const ratio = win.width / 1640;

const styles = StyleSheet.create({
  mainContainer: {
    flex: 1,
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
  },
  avatarContainer: {
    height: win.height * 0.75,
    justifyContent: 'center',
    alignSelf: 'center',
    bottom: '15%',
  },

  background: {
    flex: 1,
    width: '80%',
    height: null,
    resizeMode: 'stretch',
  },
  closetStyle: {
    flex: 2,
  },
  backgroundImage: {
    flex: 1,
    justifyContent: 'flex-end',
    alignSelf: 'center',
    height: win.height,
    bottom: '3%',
  },
  leftContainer: {
    flex: 1,
  },
  rightContainer: {
    flex: 1.5,
    maxWidth: win.width * 0.55,
  },
  doorSignButton: {
    position: 'absolute',
    bottom: metrics.screenWidth/40,
    left: metrics.screenWidth/20,
    paddingVertical: metrics.screenHeight/150,
    paddingHorizontal: metrics.screenWidth/40,
    borderWidth: metrics.screenWidth/200,
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    borderRadius: metrics.width/75,
    borderColor: '#232021',
    padding: metrics.width/1000,
    paddingRight: metrics.width/75,
    backgroundColor: colorPalette.CORNSILK
  },
  doorSignButtonText: {
    fontSize: fonts.size.font14,
    fontWeight: 'bold',
    color: '#232021',
  },
});

const AvatarBuilder = ({ navigation }) => {

  const dispatch = useDispatch();
  // const orientation = useOrientation();
  
  const [currentSound, setCurrentSound] = useState()

    const SoundPlayer = (name, sound) => {
        if (currentSound == null) {
            console.log('Sound is undefined');
        } else {
            currentSound.sound.unloadAsync().catch(()=>{});
        }

        console.log('Playing: ' + name);
        Audio.Sound.createAsync(
            sound,
            {shouldPlay: true}
        ).then((res)=>{
            setCurrentSound(res);
            res.sound.setOnPlaybackStatusUpdate((status)=>{
    
                if(!status.didJustFinish) return;
                console.log('Unloading ' + name);
    
                res.sound.unloadAsync().catch(()=>{});
            });
        }).catch((error)=>{});
    }

  useEffect(() => {
    dispatch(clicked('PuzzleOne'));
    dispatch(unlock('PuzzleTwo'));
    dispatch(unlock('PuzzleThree'));
  }, []);

  const doorSignCheck = async () => {
    const doorSignInit = await AsyncStorage.getItem('@door_sign_init');

    if (!doorSignInit) {
      await AsyncStorage.setItem(
        '@door_sign_init',
        JSON.stringify('completed')
      );
      navigation.navigate('DoorSign');
    } else {
      navigation.popToTop();
    }
  };

  const navBwdSound = Sounds.navigation_backward;

  const onPressSweater = () => (
    dispatch(setShown(closetElements.clothes)),
    dispatch(setShowSwimWear(false)),
    dispatch(setColorOptions(2))
  );
  const onPressPant = () => (
    dispatch(setShown(closetElements.clothes)),
    dispatch(setShowSwimWear(false)),
    dispatch(setColorOptions(3))
  );
  const onPressHead = () => (
    dispatch(setShown(closetElements.hairStyles)),
    dispatch(setShowSwimWear(false)),
    dispatch(setColorOptions(1))
  );
  const onPressFoot = () => (
    dispatch(setShown(closetElements.clothes)),
    dispatch(setShowSwimWear(false)),
    dispatch(setColorOptions(4))
  );

  const isSwimWear = useSelector(selectShowSwimWear);

  const backToMenu = () => {
    haptics.buttonHaptics();
    SoundPlayer('navBwdSound',navBwdSound);
    // dispatch(setPuzzleOne(true));
    // dispatch(setPuzzleColorOverlayGroup1('none'));
    // navigation.popToTop();

    doorSignCheck();
  };

  let clothingNr = isSwimWear ? 3 : 0;

  let shownAvatar = (
    <Avatar
      mood={5}
      clothing={clothingNr}
      onPressFoot={onPressFoot}
      onPressSweater={onPressSweater}
      onPressPant={onPressPant}
      onPressHead={onPressHead}
    />
  );
  if (useSelector(selectWheelChair)) {
    shownAvatar = (
      <AvatarPos4 mood={5} clothing={clothingNr} wheelChair={true} />
    );
  }

  return (
    <View style={styles.mainContainer}>
      <View style={styles.leftContainer}>
        <ImageBackground source={room} style={styles.backgroundImage}>
          <View style={styles.avatarContainer}>{shownAvatar}</View>
        </ImageBackground>
      </View>

      <View style={styles.rightContainer}>
        <Closet />
      </View>

      <BackButton buttonColor={colorPalette.CORNSILK} onPress={() => backToMenu()}/>

      {/* Door-sign */}
      {/*
        TODO: Fix styling
    */}
      <Pressable
        style={styles.doorSignButton}
        onPress={() => navigation.navigate('DoorSign')}
      >
        <Text style={styles.doorSignButtonText}>Lag dørskilt</Text>
      </Pressable>
    </View>
  );
};
export default AvatarBuilder;
