import React, {
  useState,
} from 'react';
import {
  Dimensions,
  Pressable,
  StyleSheet,
  Text,
  View,
} from 'react-native';
import { Ionicons} from '@expo/vector-icons';

import DoorSignCapture from './doorsign.capture';
import DoorSignEditor from './editor/doorsign.editor';

import BackButton from 'src/global/components/buttons/BackButton';
import * as colorPalette from 'src/global/constants/colorPalette';
import {Sounds} from 'src/assets/sounds/sounds';
import { Audio } from "expo-av";

let width = Dimensions.get('window').width;

const DoorSign = ({ navigation }) => {

  const [currentSound, setCurrentSound] = useState()

    const SoundPlayer = (name, sound) => {
        if (currentSound == null) {
            console.log("Sound is undefined");
        } else {
            currentSound.sound.unloadAsync().catch(()=>{});
        }

        console.log("Playing: " + name);
        Audio.Sound.createAsync(
            sound,
            {shouldPlay: true}
        ).then((res)=>{
            setCurrentSound(res);
            res.sound.setOnPlaybackStatusUpdate((status)=>{
    
                if(!status.didJustFinish) return;
                console.log('Unloading ' + name);
    
                res.sound.unloadAsync().catch(()=>{});
            });
        }).catch((error)=>{});
    }

  const cameraShutter = Sounds.cameraShutter;

  const [capturing, setCapturing] = useState(false);

  const [fontStyle, setFontStyle] = useState({
    color: '#000000',
    fontSize: 50,
    transform: [
      { rotateZ: '0deg' }
    ],
  });

  const [backgroundStyle, setBackgroundStyle] = useState({
    color: {
      one: '#00B6CD',
      two: '#FF8F59',
    },
    gradient: false,
  });

  const backgroundColors = [
    '#00B6CD',
    '#FF8F59',
    '#FF90A0',
    '#00C1B3',
    '#FFB93E',
    '#A5DCA3',
    '#A6AAD4'
  ];
  const fontColors = [
    '#000000',
    '#FFFFFF',
  ];

  return (
    <View style={styles.wrapper}>
      <DoorSignCapture fontStyle={fontStyle}
                       backgroundStyle={backgroundStyle}
                       capturing={capturing}
                       setCapturing={setCapturing}
      />
      <DoorSignEditor fontStyle={fontStyle}
                      setFontStyle={setFontStyle}
                      backgroundStyle={backgroundStyle}
                      setBackgroundStyle={setBackgroundStyle}
                      backgroundColors={backgroundColors}
                      fontColors={fontColors}
                      capturing={capturing}
                      setCapturing={setCapturing}
      />
      
      {!capturing
        ?  <BackButton buttonColor={colorPalette.CORNSILK} onPress={() => navigation.goBack()}/> 
        : null}
    </View>
  );
}

const styles = StyleSheet.create({
  wrapper: {
    flex: 1,
    flexDirection: 'row',
  },
  backButton: {
    position: 'absolute',
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    backgroundColor: '#FFF3DF',
    borderRadius: 12,
    left: 8,
    top: 20,
    padding: 6,
    paddingRight: 20,
  },
  backButtonIcon: {
    color: "#673E31",
    fontSize: width/50,
  },
  backText: {
    fontSize: width/50,
    fontFamily: "MyriadPro", 
    color: "#673E31"
  }
});

export default DoorSign;
