import React, {
  useEffect,
  useRef,
  useState
} from 'react';
import {
  Animated,
  StyleSheet,
  View
} from 'react-native';
import * as FileSystem from 'expo-file-system';
import { LinearGradient } from 'expo-linear-gradient';

import ViewShot from 'react-native-view-shot';
import DoorSignAvatar from './doorsign.avatar';
import DoorSignName from './doorsign.name';

import { Audio } from 'expo-av';
import {Sounds} from 'src/assets/sounds/sounds';

import {postPhoto} from 'src/global/services/UserService'

const DoorSignCapture = ({ fontStyle, backgroundStyle, capturing, setCapturing }) => {
  const viewShotRef = useRef();
  const cameraAnimation = useRef(new Animated.Value(0)).current;
  let cameraEffectBackground = cameraAnimation.interpolate({
    inputRange: [0, 1, 100],
    outputRange: [0.0000000001, 1, 0.0000000001],
  });

  const [currentSound, setCurrentSound] = useState()

    const SoundPlayer = (name, sound) => {
        if (currentSound == null) {
            console.log('Sound is undefined');
        } else {
            currentSound.sound.unloadAsync().catch(()=>{});
        }

        console.log('Playing: ' + name);
        Audio.Sound.createAsync(
            sound,
            {shouldPlay: true}
        ).then((res)=>{
            setCurrentSound(res);
            res.sound.setOnPlaybackStatusUpdate((status)=>{
    
                if(!status.didJustFinish) return;
                console.log('Unloading ' + name);
    
                res.sound.unloadAsync().catch(()=>{});
            });
        }).catch((error)=>{});
    }

  const cameraShutter = Sounds.camerashutter;

  useEffect(() => {
    
    if (capturing) {
      
      setTimeout(() => captureAnimation(), 1000);
    }
  }, [capturing]);

  const captureAnimation = () => {
    SoundPlayer('CameraShutter', cameraShutter);
    Animated.timing(cameraAnimation, {
      toValue: 100,
      duration: 1000,
      useNativeDriver: true,
    }).start(() => {
      captureAvatar();
      resetAnimation();
      setCapturing(false);
    });
  }

  const resetAnimation = () => {
    Animated.timing(cameraAnimation, {
      toValue: 0,
      duration: 0,
      useNativeDriver: true,
    }).start();
  }

  const captureAvatar = () => {
    viewShotRef.current.capture()
      .then(uri => {
        console.log(`My avatar uri: ${uri}`);
        convertToBase64(uri);
      });
  }

  const convertToBase64 = async (uri) => {
    const base64String = await FileSystem.readAsStringAsync(
      uri,
      { encoding: FileSystem.EncodingType.Base64 }
    );
    postPhoto(base64String);
    //upload(base64String);
  }

  const upload = (base64String) => {
    let data = {
      method: 'POST',
      credentials: 'same-origin',
      mode: 'same-origin',
      body: JSON.stringify({
        image: `data:image/png;base64,${base64String}`
      }),
      headers: {
        'Accept': 'application/json',
        'Content-Type': 'application/json'
      }
    };

    fetch(`http://192.168.52.174:3000/image/new/upload`, data)
      .then(res => res.json())
      .then(data => console.log(data.id));
  }

  return (
    <>
      <ViewShot style={styles.captureContainer}
                options={{
                  fileName: 'adfectusAvatar',
                  format: 'jpg',
                  quality: 0.9,
                }}
                ref={viewShotRef}
      >
        {
          backgroundStyle.gradient
            ? <LinearGradient style={styles.signWrapper}
                            colors={[
                              backgroundStyle.color.one,
                              backgroundStyle.color.two
                            ]}
                            start={{ x: 0.7, y: 0 }}
            >

              <View style={styles.nameWrapper}>
                <DoorSignName fontStyle={fontStyle} />
              </View>
              
              <View style={styles.avatarWrapper}>
                <DoorSignAvatar />
              </View>

            </LinearGradient>
          : <View style={[
            styles.signWrapper,
            {
              backgroundColor: backgroundStyle.color.one,
            }
          ]}
          >

            <View style={styles.nameWrapper}>
              <DoorSignName fontStyle={fontStyle} />
            </View>
            
            <View style={styles.avatarWrapper}>
              <DoorSignAvatar />
            </View>

          </View>
        }
      </ViewShot>
      <Animated.View style={[styles.cameraEffect, {
        opacity: cameraEffectBackground,
      }]}>
      </Animated.View>
    </>
  );
}

const styles = StyleSheet.create({
  captureContainer: {
    flex: 2,
    // borderWidth: 2,
    // borderColor: 'red',
  },
  signWrapper: {
    flex: 1,
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    // backgroundColor: '#00bfff',
    // borderWidth: 2,
    // borderColor: 'green'
  },
  nameWrapper: {
    height: '100%',
    paddingLeft: 50,
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
  },
  avatarWrapper: {
    height: '100%',
    paddingVertical: 75,
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
    // borderWidth: 2,
    // borderColor: 'yellow'
  },
  cameraEffect: {
    width: '100%',
    height: '100%',
    position: 'absolute',
    backgroundColor: '#FFFFFF',
  }
});

export default DoorSignCapture;
