import React from "react";
import {
  Dimensions,
  Pressable,
  SafeAreaView,
  ScrollView,
  StyleSheet,
  Text,
  View,
} from "react-native";

const BackgroundColorEditor = ({
  label,
  backgroundStyle,
  setBackgroundStyle,
  colors,
}) => {
  const selectColor = (color) => {
    setBackgroundStyle({
      ...backgroundStyle,
      color: {
        ...backgroundStyle.color,
        one: color,
      },
    });

    console.log(backgroundStyle);
  };

  return (
    <View style={styles.wrapper}>
      {/* Label */}
      <Text style={styles.label}>{label}</Text>

      {/* Actions */}
      <SafeAreaView>
        <ScrollView horizontal={true} style={styles.actions}>
          {colors.map((color) =>
            renderColorButton(selectColor, color, backgroundStyle)
          )}
        </ScrollView>
      </SafeAreaView>
    </View>
  );
};

const renderColorButton = (selectColor, color, backgroundStyle) => {
  const screen = Dimensions.get("window");

  return (
    <Pressable
      key={color}
      onPress={() => selectColor(color)}
      style={[
        styles.colorButton,
        {
          width: screen.width / 20,
          height: screen.width / 20,
          backgroundColor: color,
          borderWidth: color === backgroundStyle.color.one ? 2 : 0,
          borderColor: "#000000",
        },
      ]}
    ></Pressable>
  );
};

const styles = StyleSheet.create({
  wrapper: {
    width: "100%",
    marginBottom: 10,
    padding: 10,
    backgroundColor: "#DBF9FF",
    borderRadius: 10,
  },
  label: {
    fontSize: 16,
  },
  actions: {
    marginTop: 10,
    flexDirection: "row",
  },
  colorButton: {
    // width: 50,
    // height: 50,
    marginVertical: 10,
    marginHorizontal: 6,
    borderRadius: 50,
  },
});

export default BackgroundColorEditor;
