import React, { useState } from "react";
import {
  Dimensions,
  Pressable,
  SafeAreaView,
  ScrollView,
  StyleSheet,
  Text,
  View,
} from "react-native";
import FontSizeEditor from "./font-size.editor";
import FontColorEditor from "./font-color.editor";
import BackgroundColorEditor from "./background-color.editor";
import FontTransformEditor from "./font-transform.editor";
import { MaterialIcons } from "@expo/vector-icons";

const DoorSignEditor = ({
  fontStyle,
  setFontStyle,
  backgroundStyle,
  setBackgroundStyle,
  backgroundColors,
  fontColors,
  capturing,
  setCapturing,
}) => {
  const screen = Dimensions.get("window");

  const [preview, setPreview] = useState(false);

  const save = () => {
    setCapturing(true);
  };

  const previewMode = (value) => {
    setPreview(value);
  };

  if (capturing) return null;

  if (preview) {
    return (
      <Pressable
        onPress={() => previewMode(false)}
        style={{
          position: "absolute",
          bottom: 6,
          right: 4,
          paddingVertical: 10,
          paddingHorizontal: 18,
          backgroundColor: "#fff",
          borderRadius: 10,
          elevation: 3,
        }}
      >
        <Text
          style={{
            fontSize: 16,
          }}
        >
          Avslutt forhåndsvisning
        </Text>
      </Pressable>
    );
  }

  return (
    <View style={styles.wrapper}>
      <SafeAreaView style={styles.container}>
        <ScrollView>
          <Text style={[styles.editorTitle, { fontSize: screen.width / 30 }]}>
            Lag ditt dørskilt
          </Text>

          <BackgroundColorEditor
            label="Bakgrunnsfarge"
            backgroundStyle={backgroundStyle}
            setBackgroundStyle={setBackgroundStyle}
            colors={backgroundColors}
          />

          <FontSizeEditor
            label="Skrift størrelse"
            fontStyle={fontStyle}
            setFontStyle={setFontStyle}
            min={49}
            max={167}
          />

          <FontTransformEditor
            label="Skrift rotasjon"
            fontStyle={fontStyle}
            setFontStyle={setFontStyle}
            min={-19}
            max={19}
          />

          <FontColorEditor
            label="Skrift farge"
            fontStyle={fontStyle}
            setFontStyle={setFontStyle}
            colors={fontColors}
            backgroundStyle={backgroundStyle}
          />
        </ScrollView>
      </SafeAreaView>
      <View style={styles.saveBtnWrapper}>
        <Pressable
          onPress={() => previewMode(true)}
          style={[styles.saveBtn, styles.previewBtn]}
        >
          <MaterialIcons
            name="pageview"
            size={screen.width / 20}
            color="#fff"
          />
        </Pressable>
        <View style={{ width: 10 }}></View>
        <Pressable onPress={() => save()} style={styles.saveBtn}>
          <MaterialIcons name="save" size={screen.width / 20} color="#fff" />
        </Pressable>
      </View>
    </View>
  );
};

const styles = StyleSheet.create({
  wrapper: {
    flex: 1,
    flexDirection: "column",
    backgroundColor: "#FFF",
    elevation: 5,
  },
  container: {
    flex: 1,
    paddingHorizontal: 10,
    paddingTop: 10,
  },
  editorTitle: {
    margin: 10,
    // fontSize: 36,
    fontWeight: "bold",
    alignSelf: "center",
  },
  saveBtnWrapper: {
    flexDirection: "row",
    padding: 10,
    borderTopWidth: 2,
    borderColor: "hsl(0, 0%, 96%)",
  },
  saveBtn: {
    flex: 1,
    padding: 10,
    alignItems: "center",
    backgroundColor: "#00B6CD",
    borderRadius: 10,
  },
  saveBtnText: {
    color: "#FFFFFF",
    // fontSize: 20,
    fontWeight: "bold",
    letterSpacing: 1.5,
  },
  previewBtn: {
    backgroundColor: "#00C1B3",
  },
});

export default DoorSignEditor;
