import { Dimensions, Pressable, StyleSheet, Text, View } from "react-native";
import { MaterialCommunityIcons } from "@expo/vector-icons";

const FontSizeEditor = ({ label, fontStyle, setFontStyle, min, max }) => {
  const screen = Dimensions.get("window");

  const minus = () => {
    if (fontStyle.fontSize >= min) {
      setFontStyle({
        ...fontStyle,
        fontSize: fontStyle.fontSize - 2,
      });
    }
  };

  const plus = () => {
    if (fontStyle.fontSize <= max) {
      setFontStyle({
        ...fontStyle,
        fontSize: fontStyle.fontSize + 2,
      });
    }
  };

  return (
    <View style={styles.wrapper}>
      {/* Label */}
      <Text style={styles.label}>{label}</Text>

      {/* Actions */}
      <View style={styles.actions}>
        {/* Minus button */}
        <Pressable onPress={() => minus()} style={styles.button}>
          <MaterialCommunityIcons
            name="minus"
            size={screen.width / 32}
            color="#000"
          />
        </Pressable>

        {/* Value */}
        <View style={styles.value}>
          <Text style={[styles.valueText, { fontSize: screen.width / 40 }]}>
            {fontStyle.fontSize}
          </Text>
        </View>

        {/* Plus button */}
        <Pressable onPress={() => plus()} style={styles.button}>
          <MaterialCommunityIcons
            name="plus"
            size={screen.width / 32}
            color="#000"
          />
        </Pressable>
      </View>
    </View>
  );
};

const styles = StyleSheet.create({
  wrapper: {
    width: "100%",
    marginBottom: 10,
    padding: 10,
    backgroundColor: "#DBF9FF",
    borderRadius: 10,
  },
  label: {
    fontSize: 16,
  },
  actions: {
    marginTop: 10,
    flexDirection: "row",
    borderWidth: 1,
    borderColor: "#B1EBF4",
    borderRadius: 10,
    overflow: "hidden",
  },
  button: {
    paddingVertical: 8,
    paddingHorizontal: 18,
    backgroundColor: "#B1EBF4",
  },
  value: {
    flex: 1,
    alignItems: "center",
    justifyContent: "center",
  },
});

export default FontSizeEditor;
