import React, {
  useEffect,
  useState
} from 'react';
import {
  Dimensions,
  ImageBackground,
  StyleSheet,
  View,
} from 'react-native';
import Closet from 'src/global/components/containers/Closet';
import { useSelector } from 'react-redux';

import { selectShowSwimWear } from 'src/global/reducers/closet/closetSlice';

import * as closetElements from 'src/global/constants/closetElements';

import room from 'src/assets/images/Room3.png';

import { useDispatch } from 'react-redux';
import {
  setShown,
  setFamilyPicker,
  setColorOptions,
  setShowColors,
  setShowSwimWear
} from 'src/global/reducers/closet/closetSlice';
import SvgMan from 'src/global/avatar/ManAvatar';
import FamilyBodyComponent from 'src/global/avatar/body/adult/FamilyBody';

import { Audio } from 'expo-av';
import { Sounds } from 'src/assets/sounds/sounds';
import BackButton from 'src/global/components/buttons/BackButton';
import * as colorPalette from 'src/global/constants/colorPalette';
import haptics from 'src/global/constants/haptics';

import {
  clicked,
} from 'src/global/reducers/puzzle/puzzle.slice.js';

let width = Dimensions.get('window').width;
const win = Dimensions.get('window');

const styles = StyleSheet.create({
  mainContainer: {
    flex: 1,
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',

  },
  avatarContainer: {
    height: win.height * 0.75,
    justifyContent: 'center',
    alignSelf: 'center',
    bottom: '15%',

  },
  background: {
    flex: 1,
    width: '80%',
    height: null,
    resizeMode: 'stretch'
  },
  closetStyle: {
    flex: 2,
  },
  backgroundImage: {
    flex: 1,
    justifyContent: 'flex-end',
    alignSelf: 'center',
    width: '100%'
  },
  leftContainer: {
    flex: 1,
  },
  rightContainer: {
    flex: 1.5,
    maxWidth: win.width * 0.55
  },
})

const FamilyBuilder = ({ navigation }) => {

  useEffect(() => {
    dispatch(clicked('PuzzleTwo'));
    dispatch(setFamilyPicker(true));
    dispatch(setColorOptions(6));
  }, []);

  const [currentSound, setCurrentSound] = useState()

  const SoundPlayer = (name, sound) => {
    if (currentSound == null) {
      console.log('Sound is undefined');
    } else {
      currentSound.sound.unloadAsync().catch(() => { });
    }

    console.log('Playing: ' + name);
    Audio.Sound.createAsync(
      sound,
      { shouldPlay: true }
    ).then((res) => {
      setCurrentSound(res);
      res.sound.setOnPlaybackStatusUpdate((status) => {

        if (!status.didJustFinish) return;
        console.log('Unloading ' + name);

        res.sound.unloadAsync().catch(() => { });
      });
    }).catch((error) => { });
  }

  const navBwdSound = Sounds.navigation_backward;

  const dispatch = useDispatch()
  const onPressSweater = () => (dispatch(setShown(closetElements.clothes)), dispatch(setShowSwimWear(false)), dispatch(setColorOptions(2)))
  const onPressPant = () => (dispatch(setShown(closetElements.clothes)), dispatch(setShowSwimWear(false)), dispatch(setColorOptions(3)))
  const onPressHead = () => (dispatch(setShown(closetElements.hairStyles)), dispatch(setShowSwimWear(false)), dispatch(setColorOptions(1)))
  const onPressFoot = () => (dispatch(setShown(closetElements.clothes)), dispatch(setShowSwimWear(false)), dispatch(setColorOptions(4)))

  const isSwimWear = useSelector(selectShowSwimWear);

  const backToMenu = () => {
    haptics.buttonHaptics();
    SoundPlayer('navBwdSound', navBwdSound);
    dispatch(setShown(closetElements.features));
    dispatch(setFamilyPicker(false));
    navigation.popToTop();
  }

  let clothingNr = isSwimWear ? 3 : 0;

  let shownAvatar = <SvgMan style={{
    position: 'absolute',
    height: '84%',
    left: '8%',
    bottom: '4%',
    width: '84%',
  }}
  />


  return (
    <View style={styles.mainContainer}>

      <View style={styles.leftContainer}>

        <ImageBackground source={room} style={styles.backgroundImage}>

          <View style={styles.avatarContainer}>
            <FamilyBodyComponent />
          </View>

        </ImageBackground >

      </View>

      <View style={styles.rightContainer}>
        <Closet isParent={true} />
      </View>
      <BackButton buttonColor={colorPalette.CORNSILK} onPress={() => backToMenu()} />
    </View>
  );
}
export default FamilyBuilder; 
