import React, {
    useEffect,
    useRef,
} from 'react';
import {
    Animated,
    StyleSheet,
    View,
} from 'react-native';

function AnimatedBackground() {
    useEffect(() => {
        animateCircles();
    }, []);

    const redCircleDiameter = useRef(new Animated.Value(300)).current;
    const redCircleCenterXY = useRef(new Animated.Value(-150)).current;

    const blueCircleDiameter = useRef(new Animated.Value(50)).current;
    const blueCircleCenterXY = useRef(new Animated.Value(-25)).current;

    const greenCircleDiameter = useRef(new Animated.Value(500)).current;
    const greenCircleCenterXY = useRef(new Animated.Value(-250)).current;

    const purpleCircleDiameter = useRef(new Animated.Value(40)).current;

    const animateCircles = () => {
        Animated.sequence([
            Animated.parallel([

                // RED CIRCLE
                Animated.timing(redCircleDiameter, {
                    toValue: 150,
                    duration: 30000,
                    useNativeDriver: false,
                }),
                Animated.timing(redCircleCenterXY, {
                    toValue: -75,
                    duration: 30000,
                    useNativeDriver: false,
                }),

                // BLUE CIRCLE
                Animated.timing(blueCircleDiameter, {
                    toValue: 120,
                    duration: 20000,
                    useNativeDriver: false,
                }),
                Animated.timing(blueCircleCenterXY, {
                    toValue: -60,
                    duration: 20000,
                    useNativeDriver: false,
                }),

                // GREEN CIRCLE
                Animated.timing(greenCircleDiameter, {
                    toValue: 350,
                    duration: 25000,
                    useNativeDriver: false,
                }),
                Animated.timing(greenCircleCenterXY, {
                    toValue: -175,
                    duration: 25000,
                    useNativeDriver: false,
                }),

                // PURPLE CIRCLE
                Animated.timing(purpleCircleDiameter, {
                    toValue: 300,
                    duration: 45000,
                    useNativeDriver: false,
                }),

            ]),
            Animated.parallel([

                // RED CIRCLE
                Animated.timing(redCircleDiameter, {
                    toValue: 300,
                    duration: 30000,
                    useNativeDriver: false,
                }),
                Animated.timing(redCircleCenterXY, {
                    toValue: -150,
                    duration: 30000,
                    useNativeDriver: false,
                }),

                // BLUE CIRCLE
                Animated.timing(blueCircleDiameter, {
                    toValue: 50,
                    duration: 20000,
                    useNativeDriver: false,
                }),
                Animated.timing(blueCircleCenterXY, {
                    toValue: -25,
                    duration: 20000,
                    useNativeDriver: false,
                }),

                // GREEN CIRCLE
                Animated.timing(greenCircleDiameter, {
                    toValue: 500,
                    duration: 25000,
                    useNativeDriver: false,
                }),
                Animated.timing(greenCircleCenterXY, {
                    toValue: -250,
                    duration: 25000,
                    useNativeDriver: false,
                }),

                // PURPLE CIRCLE
                Animated.timing(purpleCircleDiameter, {
                    toValue: 80,
                    duration: 45000,
                    useNativeDriver: false,
                }),

            ]),
        ]).start();
    }
    return (
        <View style={{
            width: '100%',
            height: '100%',
        }}>

            <Animated.View style={[styles.redCircle, {
                                width: redCircleDiameter,
                                height: redCircleDiameter,
                                transform: [
                                    { translateX: redCircleCenterXY },
                                    { translateY: redCircleCenterXY },
                                ],
                            }]}
            ></Animated.View>

            <Animated.View style={[styles.blueCircle, {
                                width: blueCircleDiameter,
                                height: blueCircleDiameter,
                                transform: [
                                    { translateX: blueCircleCenterXY },
                                    { translateY: blueCircleCenterXY },
                                ],
                            }]}
            ></Animated.View>

            <Animated.View style={[styles.greenCircle, {
                                width: greenCircleDiameter,
                                height: greenCircleDiameter,
                                transform: [
                                    { translateX: greenCircleCenterXY },
                                    { translateY: greenCircleCenterXY },
                                ],
                            }]}
            ></Animated.View>

            <Animated.View style={[styles.purpleCircle, {
                                width: purpleCircleDiameter,
                                height: 40,
                                transform: [
                                    { translateX: -20 },
                                    { translateY: -20 },
                                ],
                            }]}
            ></Animated.View>

        </View>
    );
}

const styles = StyleSheet.create({
    redCircle: {
        position: 'absolute',
        top: '10%',
        left: '35%',
        backgroundColor: 'hsla(349, 74%, 75%, 1)',
        borderRadius: 999,
    },
    blueCircle: {
        position: 'absolute',
        top: '40%',
        left: '5%',
        backgroundColor: 'hsla(191, 57%, 56%, 1)',
        borderRadius: 999,
    },
    greenCircle: {
        position: 'absolute',
        top: '85%',
        left: '95%',
        backgroundColor: 'hsla(170, 53%, 61%, 1)',
        borderRadius: 999,
    },
    purpleCircle: {
        position: 'absolute',
        top: '90%',
        left: '20%',
        backgroundColor: 'hsla(235, 35%, 75%, 1)',
        borderRadius: 999,
    },
});

export default AnimatedBackground;