import React, {
    useEffect,
    useRef,
    useState,
} from 'react';
import {
    Animated,
    Image,
    Pressable,
    StyleSheet,
    Text,
    View,
} from 'react-native';
import {
    useDispatch,
    useSelector,
} from 'react-redux';
import { Ionicons } from '@expo/vector-icons';
import { Audio } from 'expo-av';

import { Sounds } from 'src/assets/sounds/sounds';

import { completeModule } from 'src/global/reducers/how-to/how-to.slice';
import AnimatedBackground from './AnimatedBackground';

import SvgCloset from 'src/assets/objects/static/closet';
import SvgPingPong from 'src/assets/objects/static/PingPong';
import SvgSuitcase from 'src/assets/objects/static/Suitcase';
import SvgBackLyingCyclePos3 from 'src/global/avatar/aid/Pos3/BackLyingCyclePos3';
import SvgBonFire from 'src/global/avatar/aid/accessories/BonFireNormal';
import SvgCycle2 from 'src/global/avatar/aid/Pos3/Cycle2pos3';

const HowTo = ({ route, navigation }) => {
    const { howTo } = useSelector((state) => state.howTo);
    const dispatch = useDispatch();
    const { data } = route.params;

    const [screen, setScreen] = useState(null);
    const [index, setIndex] = useState(0);

    const [canContinue, setCanContinue] = useState(false);

    useEffect(() => {
        loadSounds();
        setScreen(data.screens[index]);
    }, []);

    const nextScreen = async () => {
        // playSound(navFwdSound);
        // stopSounds();

        if (canContinue) {
            if ((index + 1) >= data.screens.length) {
                dispatch(completeModule(data.name));
                navigation.navigate(data.name);
            } else {
                let i = index + 1;
                setScreen(data.screens[i]);
                setIndex(i);
            }
        }
    }

    const prevScreen = async () => {
        // playSound(navBwdSound);
        // stopSounds();
        
        if (canContinue) {
            if (index <= 0) {
                navigation.goBack();
            } else {
                let i = index - 1;
                setScreen(data.screens[i]);
                setIndex(i);
            }
        }
    }

    // Sounds
    const voice = Sounds.female.hanna;

    const [navFwdSound, setNavFwdSound] = useState(new Audio.Sound());
    const [navBwdSound, setNavBwdSound] = useState(new Audio.Sound());
    // Active you
    const [activeYouSound, setActiveYouSound] = useState(new Audio.Sound());
    // Avatar builder
    const [avatarBuilderSound, setAvatarBuilderSound] = useState(new Audio.Sound());
    // Family builder
    const [familyBuilderSound, setFamilyBuilderSound] = useState(new Audio.Sound());
    // Packingmodule
    const [packageModuleSound, setPackageModuleSound] = useState(new Audio.Sound());
    // Info
    const [infoModuleSound, setInfoModuleSound] = useState(new Audio.Sound());
    // Virtual
    const [tourModuleSound, setTourModuleSound] = useState(new Audio.Sound());

    const loadSounds = async () => {
        await navFwdSound.unloadAsync();
        await navBwdSound.unloadAsync();
        await activeYouSound.unloadAsync();
        await avatarBuilderSound.unloadAsync();
        await familyBuilderSound.unloadAsync();
        await packageModuleSound.unloadAsync();
        await infoModuleSound.unloadAsync();
        await tourModuleSound.unloadAsync();

        await navFwdSound.loadAsync(Sounds.navigation_forward);
        await navBwdSound.loadAsync(Sounds.navigation_backward);
        await activeYouSound.loadAsync(voice.activeyou_howto);
        await avatarBuilderSound.loadAsync(voice.avatarbuilder_howto);
        await familyBuilderSound.loadAsync(voice.familybuilder_howto);
        await packageModuleSound.loadAsync(voice.packagemodule_howto);
        await infoModuleSound.loadAsync(voice.infomodule_howto);
        await tourModuleSound.loadAsync(voice.tourmodule_howto);

        introRecording();
    }

    const introRecording = async () => {
        switch (data.name) {
            case 'FamilyBuilder':
                playIntroRecording(familyBuilderSound);
                break;

            case 'AvatarBuilder':
                playIntroRecording(avatarBuilderSound);
                break;

            case 'ActiveYou':
                playIntroRecording(activeYouSound);
                break;

            case 'PackageModule':
                playIntroRecording(packageModuleSound);
                break;

            case 'VirtualTour':
                playIntroRecording(tourModuleSound);
                break;

            case 'Info':
                playIntroRecording(infoModuleSound);
                break;

            default: break;
        }
    }

    const playIntroRecording = async (selectedSound) => {
        await selectedSound.playAsync();
        selectedSound.setOnPlaybackStatusUpdate(status => {
            if (status.didJustFinish) {
                setCanContinue(true);
            }
        });
    }

    const playSound = async (selectedSound) => {
        await navFwdSound.stopAsync();
        await navBwdSound.stopAsync();
        await activeYouSound.stopAsync();
        await avatarBuilderSound.stopAsync();
        await familyBuilderSound.stopAsync();
        await packageModuleSound.stopAsync();
        await infoModuleSound.stopAsync();
        await tourModuleSound.stopAsync();

        await selectedSound.playAsync();
    }

    const stopSounds = async () => {
        await navFwdSound.stopAsync();
        await navBwdSound.stopAsync();
        await activeYouSound.stopAsync();
        await avatarBuilderSound.stopAsync();
        await familyBuilderSound.stopAsync();
        await packageModuleSound.stopAsync();
        await infoModuleSound.stopAsync();
        await tourModuleSound.stopAsync();
    }

    return (
        <View style={styles.container}>
            <AnimatedBackground />
            {
                screen
                    ? <Screen data={data}
                              screen={screen}
                              nextScreen={nextScreen}
                              prevScreen={prevScreen}
                              canContinue={canContinue}
                    />
                    : null
            }
        </View>
    );
}

const Screen = ({ data, screen, nextScreen, prevScreen, canContinue }) => {
    const AnimatedPressable = Animated.createAnimatedComponent(Pressable);

    useEffect(() => {
        if (canContinue) {
            animateButton(1);
        }
    }, [canContinue]);

    const buttonAnimation = useRef(new Animated.Value(0.25)).current;
    const animateButton = (value) => {
        Animated.timing(buttonAnimation, {
            toValue: value,
            duration: 250,
            useNativeDriver: false,
        }).start();
    }

    let howToImage = null
    switch(data.name){
        case 'AvatarBuilder': 
        howToImage = <SvgCloset /> 
        break; 
        case 'FamilyBuilder': 
        howToImage = <SvgCloset /> 
        break; 
        case 'ActiveYou': 
        howToImage = <SvgPingPong />
        break; 
        case 'PackageModule': 
        howToImage = <SvgSuitcase />
        break; 
        case 'Info': 
        howToImage = <SvgBonFire />
        break; 
        case 'VirtualTour': 
        howToImage = <SvgCycle2 />
        break;
    }
    return (
        <View style={styles.content}>
            <AnimatedPressable onPress={() => prevScreen()}
                               style={[styles.button, {
                                   opacity: buttonAnimation
                               }]}
            >
                {
                    screen.id === 0
                        ? <Ionicons name='ios-close' size={30} color='hsl(0, 0%, 100%)' />
                        : <Ionicons name='ios-chevron-back' size={30} color='hsl(0, 0%, 100%)' />
                }
            </AnimatedPressable>
            <View style={{flex: 1, paddingHorizontal: 30}}>
                <View style={styles.pageTop}>
                    <View style={styles.image}>
                        {
                            // Temorary matterport how to screen
                            data.name === 'VirtualTour' && screen.id === 1
                                ? <Image source={ require('src/assets/images/matterport-icons-preview.png') } style={{ width: 250, height: 200, borderRadius: 10, borderWidth: 1, borderColor: '#333' }} />
                                : howToImage
                        }
                    </View>
                    <Text style={styles.title}>
                        { screen.title }
                    </Text>
                    <Text style={styles.subTitle}>
                        { screen.subTitle }
                    </Text>
                </View>
                <View style={styles.pageBody}>
                    {
                        screen.paragraphs.map((paragraph) => (
                            <Text key={paragraph}
                                style={styles.paragraph}
                            >
                                { paragraph }
                            </Text>
                        ))
                    }
                    <View style={{height: 30}}></View>
                    {
                        screen.hints.map((hint) => (
                            <View key={hint} style={styles.hintBox}>
                                <Text style={styles.hintText}>
                                    { hint }
                                </Text>
                            </View>
                        ))
                    }
                </View>
            </View>
            <AnimatedPressable onPress={() => nextScreen()}
                               style={[styles.button, {
                                   opacity: buttonAnimation
                               }]}
            >
                {
                    (screen.id + 1) >= data.screens.length
                        ? <Ionicons name='ios-checkmark' size={30} color='hsl(0, 0%, 100%)' />
                        : <Ionicons name='ios-chevron-forward' size={30} color='hsl(0, 0%, 100%)' />
                }
            </AnimatedPressable>
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
        alignItems: 'center',
        justifyContent: 'center',
    },
    content: {
        position: 'absolute',
        top: 0,
        left: 0,
        width: '100%',
        height: '100%',
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'space-between',
        elevation: 10,
    },
    pageTop: {
        width: '100%',
        paddingTop: 50,
        alignItems: 'center',
        justifyContent: 'center',
    },
    pageBody: {
        width: '100%',
        paddingVertical: 30,
        alignItems: 'center',
        justifyContent: 'center',
    },

    image: {
        width: 250,
        height: 250
    },
    title: {
        fontSize: 50,
        letterSpacing: 1,
        fontFamily: "MyriadPro",
    },
    subTitle: {
        fontSize: 24,
        letterSpacing: 0.85,
        color: 'hsl(0, 0%, 50%)',
        fontFamily: "MyriadPro",
    },
    paragraph: {
        marginVertical: 5,
        textAlign: 'center',
        fontSize: 16,
        fontFamily: "MyriadPro",
    },
    hintBox: {
        marginVertical: 6,
        paddingVertical: 4,
        paddingHorizontal: 12,
        backgroundColor: 'hsl(40, 93%, 51%)',
        borderRadius: 4
    },
    hintText: {
        color: 'hsl(0, 0%, 100%)'
    },

    button: {
        width: 80,
        height: 80,
        margin: 15,
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'center',
        backgroundColor: 'hsl(0, 0%, 20%)',
        elevation: 5,
        borderRadius: 100,
    },
    buttonText: {
        fontSize: 16,
        fontFamily: "MyriadPro",
    },
});

export default HowTo;
