import React, {
    useEffect,
    useRef,
    useState,
} from 'react';
import {
    Animated,
    Pressable,
    StyleSheet,
    Text,
    View,
    ImageBackground,
    Dimensions 
} from 'react-native';
import {
    useDispatch,
    useSelector,
} from 'react-redux';
import { Ionicons } from '@expo/vector-icons';
import { Audio } from 'expo-av';

import { Sounds } from 'src/assets/sounds/sounds';
import haptics from 'src/global/constants/haptics';

import { completeModule } from 'src/global/reducers/how-to/how-to.slice';

import AvatarBackground from 'src/assets/images/howToBackgrounds/AvatarHowToBackground.jpg'
import ActiveYouBackground from 'src/assets/images/howToBackgrounds/summerBackground.jpg'
import HowToVirtualTourBackground from 'src/assets/images/howToBackgrounds/HowToVirtualTourBackground.png'
import HowToPackingModuleBackground from 'src/assets/images/howToBackgrounds/HowToPackingModuleBackground.png'
import HowToInformationBackground from 'src/assets/images/howToBackgrounds/HowToInformationBackground.png'
import HowToMealPlannerBackground from 'src/assets/images/howToBackgrounds/HowToMealPlannerModuleBackground.jpg'

import SvgClosetFilled from 'src/assets/objects/static/ClosetFilled';
import SvgBicycle  from 'src/assets/objects/dynamic/Bicycle';
import SvgCanoe from 'src/assets/objects/dynamic/Canoe';
import SvgBasketball from 'src/global/avatar/aid/accessories/BasketBall';
import SvgVirtualTourIcon  from 'src/assets/icons/VirtualTourIcon';
import SvgVirtualTourIcon2  from 'src/assets/icons/VirtualTourIcon2';
import SvgSuitcaseWithItems from 'src/assets/objects/static/SuitcaseWithItems';
import SvgInformationIcon from 'src/assets/icons/InformationIcon';

import LionWondering from 'src/assets/images/LionWondering.js';
import LionHappy from 'src/assets/images/Lion';
import LionThumpsUp from 'src/assets/images/LionThumpsUp';

function HowTo({ route, navigation }) {
    // const { howTo } = useSelector((state) => state.howTo);
    const dispatch = useDispatch();
    const { data } = route.params;

    const [screen, setScreen] = useState(null);
    const [index, setIndex] = useState(0);

    const [canContinue, setCanContinue] = useState(true);

    useEffect(() => {
        introRecording();
        setScreen(data.screens[index]);
        // setHowToBackground(data.screens[index]);
    }, []);

    const [currentSound, setCurrentSound] = useState()

    const SoundPlayer = (name, sound) => {
        if (currentSound == null) {
            console.log("Sound is undefined");
        } else {
            currentSound.sound.unloadAsync().catch(()=>{});
        }

        console.log("Playing: " + name);
        Audio.Sound.createAsync(
            sound,
            {shouldPlay: true}
        ).then((res)=>{
            setCurrentSound(res);
            res.sound.setOnPlaybackStatusUpdate((status)=>{
    
                if(!status.didJustFinish) return;
                console.log('Unloading ' + name);
    
                res.sound.unloadAsync().catch(()=>{});
            });
        }).catch((error)=>{});
    }

    const nextScreen = async () => {
        haptics.buttonHaptics();
        SoundPlayer('navFwdSound', navFwdSound);

        if (canContinue) {
            if ((index + 1) >= data.screens.length) {
                dispatch(completeModule(data.name));
                navigation.navigate(data.name);
            } else {
                let i = index + 1;
                setScreen(data.screens[i]);
                setIndex(i);
            }
        }
    }

    const prevScreen = async () => {
        haptics.buttonHaptics();
        SoundPlayer('navBwdSound', navBwdSound);
        
        if (canContinue) {
            if (index <= 0) {
                navigation.goBack();
            } else {
                let i = index - 1;
                setScreen(data.screens[i]);
                setIndex(i);
            }
        }
    }

    // Sounds
    const voice = Sounds.female.hanna;

    const navFwdSound = Sounds.navigation_forward;
    const navBwdSound = Sounds.navigation_backward;

    // Active you
    const activeYouSound = voice.activeyou_howto;
    // Avatar builder
    const avatarBuilderSound = voice.avatarbuilder_howto;
    // Family builder
    const familyBuilderSound = voice.familybuilder_howto;
    // Packingmodule
    const packageModuleSound = voice.packagemodule_howto;
    // Info
    const infoModuleSound = voice.infomodule_howto;
    // Virtual
    const tourModuleSound = voice.tourmodule_howto;


    const introRecording = async () => {
        switch (data.name) {
            case 'FamilyBuilder':
                SoundPlayer('familyBuildeSound', familyBuilderSound);
                break;

            case 'AvatarBuilder':
                SoundPlayer('avatarBuilderSound', avatarBuilderSound);
                break;

            case 'ActiveYou':
                SoundPlayer('activeYouSound', activeYouSound);
                break;

            case 'PackageModule':
                SoundPlayer('packageModuleSound', packageModuleSound);
                break;

            case 'VirtualTour':
                SoundPlayer('tourModuleSound', tourModuleSound);
                break;

            case 'Info':
                SoundPlayer('infoModuleSound', infoModuleSound);
                break;

            default: break;
        }
    }



    return (
        // <ImageBackground source={howToBackground} style={styles.background}>
        <View style={styles.container}>
            {
                screen
                    ? <Screen data={data}
                              screen={screen}
                              nextScreen={nextScreen}
                              prevScreen={prevScreen}
                              canContinue={canContinue}
                            //   howToColor={howToColor}
                            //   lion={lion}
                    />
                    : null
            }
        </View>
        // </ImageBackground>
    );
}

const Screen = ({ data, screen, nextScreen, prevScreen, canContinue}) => {
    const AnimatedPressable = Animated.createAnimatedComponent(Pressable);

    const [howToBackground, setHowToBackground] = useState(null)
    const [howToColor, setHowToColor] = useState(null)
    const [lion, setLion] = useState(null) 
    const [howToImage, setHowToImage] = useState(null)
    const [howToImage2, setHowToImage2] = useState(null)
    const [howToImage3, setHowToImage3] = useState(null)

    useEffect(() => {
        howToContent(data);
        if (canContinue) {
            animateButton(1);
        }
    }, [canContinue]);

    const buttonAnimation = useRef(new Animated.Value(0.25)).current;
    const animateButton = (value) => {
        Animated.timing(buttonAnimation, {
            toValue: value,
            duration: 250,
            useNativeDriver: false,
        }).start();
    }

    // let howToImage = null
    // let howToImage2 = null
    // let howToImage3 = null

    const howToContent = (data) => {
        console.log("TEST: " + data.name)
        switch(data.name){
            case 'AvatarBuilder': 
            setHowToImage(<SvgClosetFilled style={styles.imageCloset}/>) 
            setHowToBackground(AvatarBackground)
            setHowToColor('#FFB93E')
            setLion(LionHappy)
            break; 
            case 'FamilyBuilder': 
            setHowToImage(<SvgClosetFilled style={styles.imageCloset}/>); 
            setHowToBackground(AvatarBackground)
            setHowToColor('#FFB93E')
            setLion(LionHappy)
            break; 
            case 'ActiveYou': 
            setHowToImage(<SvgCanoe style={styles.imageActiveYou}/>)
            setHowToImage2(<SvgBicycle style={styles.image2}/>)
            setHowToImage3(<SvgBasketball style={styles.image3}/>)
            setHowToBackground(ActiveYouBackground)
            setHowToColor('#87C036')
            setLion(LionThumpsUp)
            break; 
            case 'PackageModule': 
            setHowToImage(<SvgSuitcaseWithItems style={styles.imagePackage}/>)
            setHowToBackground(HowToPackingModuleBackground)
            setHowToColor('#88BFD6')
            setLion(LionWondering)
            break; 
            case 'Info': 
            setHowToImage(<SvgInformationIcon style={styles.imageInformation}/>)
            setHowToBackground(HowToInformationBackground)
            setHowToColor('#87C036')
            setLion(LionWondering)
            break; 
            case 'VirtualTour': 
            setHowToImage(<SvgVirtualTourIcon style={styles.virtualTourIcon}/>)
            setHowToImage2(<SvgVirtualTourIcon2 style={styles.virtualTourIcon2} />)
            setHowToBackground(HowToVirtualTourBackground)
            setHowToColor('#B67BBD')
            setLion(LionWondering)
            break;
            case 'MealPlanner': 
            setHowToImage(<SvgVirtualTourIcon style={styles.virtualTourIcon}/>)
            setHowToImage2(<SvgVirtualTourIcon2 style={styles.virtualTourIcon2} />)
            setHowToBackground(HowToMealPlannerBackground)
            setHowToColor('#B67BBD')
            setLion(LionHappy)
            break;
        }
    
    }

    return (
        // <View style = {styles.container}>
            <ImageBackground source={howToBackground} style={styles.background}>
            <View style = {styles.header} backgroundColor={howToColor}>
                <Text  
                
                style={styles.title}>
                    { screen.title }

                </Text>
                <Text style={styles.subTitle}>
                        { screen.subTitle }
                </Text>
            </View>

            <View style = {styles.content}>

                <AnimatedPressable onPress={() => prevScreen()}
                               style={[styles.button, {
                                //    opacity: buttonAnimation
                               }]}>
                    {
                    screen.id === 0
                        ? <Ionicons name='ios-close' size={30} color='hsl(0, 0%, 100%)' />
                        : <Ionicons name='ios-chevron-back' size={30} color='hsl(0, 0%, 100%)' />
                    }
                </AnimatedPressable>

                <View style={styles.imageContainer}>
                    {
                        howToImage
                        
                    }
                </View>

                <View style={styles.pet}>
                {lion}
                </View>

                <View style = {styles.infoTextContainer}>
                {
                        <Text
                            style={styles.infoText}
                        >
                            { screen.paragraphs[0]}
                            {"\n"} 
                            {"\n"} 
                            {screen.paragraphs[1]}
                        </Text>
                    }       
                </View>  

                {howToImage2}
                {howToImage3}

                <AnimatedPressable onPress={() => nextScreen()}
                               style={[styles.button, {
                                //    opacity: buttonAnimation
                               }]}>
                {
                    (screen.id + 1) >= data.screens.length
                        ? <Ionicons name='ios-checkmark' size={30} color='hsl(0, 0%, 100%)' />
                        : <Ionicons name='ios-chevron-forward' size={30} color='hsl(0, 0%, 100%)' />
                }
                </AnimatedPressable>   

            </View>
        {/* </View> */}
            </ImageBackground>

    );
}

let width = Dimensions.get('window').width;
const win = Dimensions.get('window');
// const ratio = win.width/540;

const styles = StyleSheet.create({
    container: {
        flex: 1,
        flexDirection: 'column',
    },
    background: {
        flex: 1,
        width: '100%',
        height: '100%'
    },
    header: {
        flex: 2,
        alignItems: 'center',
        justifyContent: 'center',
        width: '100%',
        height: '20%',
        borderBottomColor: 'white',
        borderBottomWidth: 10
    },
    content: {
        flex: 7,   
        flexDirection: 'row',
    },
    pet: {
        flex: 1,
        marginTop: 'auto',
        height: '60%',
        right: 15,
        resizeMode: 'contain' ,
    },
    title: {
        // fontSize: 50,
        fontSize: win.height/15,
        letterSpacing: 1,
        marginBottom: 15,
        fontFamily: "MyriadPro-Bold",
        fontWeight: 'bold'
    },
    subTitle: {
        // fontSize: 24,
        fontSize: win.height/25,
        letterSpacing: 0.85,
        fontFamily: "MyriadPro",
    },
    infoTextContainer: {
        flex: 1,
        flexDirection: 'row',
        justifyContent: 'center',
        alignSelf: 'center',
        zIndex: 10,
    },     
    infoText: {
        textAlign: 'center',
        fontSize: win.height/25,
        // fontSize: 27,
        backgroundColor: 'white',
        padding: '5%',
        borderRadius: 30,
        fontFamily: "MyriadPro",
        overflow: 'hidden',
        width: '100%',
        maxHeight: '100%',
        // bottom: 100,
        // bottom: '25%',
        alignSelf: 'center'
   },
    imageContainer: {
        flex: 1,
        height: '50%',
        alignSelf: 'center',
    },
    imageCloset: {
        height: '110%',
        width: '110%',
        // bottom: 40,
        bottom: '15%',
        right: 20,
    },
    imageActiveYou: {
        height: '50%',
        width: '120%',
        bottom: 40,
        right: 50,
    },
    image2: {
        position: 'absolute',
        height: '40%',
        width: '40%',
        right: 0,
        bottom: -25
    },
    image3: {
        position: 'absolute',
        height: '20%',
        width: '20%',
        left: 130,
        bottom: 100
    },
    button: {
        width: 80,
        height: 80,
        margin: 15,
        bottom: '5%',
        flexDirection: 'row',
        alignItems: 'center',
        alignSelf: 'center',
        justifyContent: 'center',
        backgroundColor: 'hsl(0, 0%, 20%)',
        elevation: 5,
        borderRadius: 100,
    },
    virtualTourIcon: {
        height: '80%',
        right: '5%',

    },
    virtualTourIcon2: {
        position: 'absolute',
        height: '90%',
        width: '90%',
        left: '5%',
        top: 30,
        zIndex: -1,
        transform: [
            { scaleY: -1 },
            // {scaleX: -1 }
          ]
    },
    imagePackage: {
        height: '100%',
        width: '100%',
        bottom: 40,
        right: 15,
    },
    imageInformation: {
        height: '120%',
        width: '120%',
        bottom: 40,
        right: 40,
    },



    pageTop: {
        width: '100%',
        paddingTop: 50,
        alignItems: 'center',
        justifyContent: 'center',
    },
    pageBody: {
        width: '100%',
        paddingVertical: 30,
        alignItems: 'center',
        justifyContent: 'center',
    },
    paragraph: {
        marginVertical: 5,
        textAlign: 'center',
        fontSize: 16,
        fontFamily: "MyriadPro",
    },
    hintBox: {
        marginVertical: 6,
        paddingVertical: 4,
        paddingHorizontal: 12,
        backgroundColor: 'hsl(40, 93%, 51%)',
        borderRadius: 4
    },
    hintText: {
        color: 'hsl(0, 0%, 100%)'
    },
});

export default HowTo;
