import React, {
  useEffect,
  useState
} from 'react';
import {
  StyleSheet,
  View,
} from 'react-native';
import { WebView } from 'react-native-webview';

import { useDispatch } from 'react-redux';
import {
  clicked,
} from 'src/global/reducers/puzzle/puzzle.slice.js';

import { Audio } from 'expo-av';
import { Sounds } from 'src/assets/sounds/sounds';
import BackButton from 'src/global/components/buttons/BackButton.js';
import * as colorPalette from 'src/global/constants/colorPalette.js';
import haptics from 'src/global/constants/haptics';

const Info = ({ navigation }) => {

  useEffect(() => {
    dispatch(clicked('PuzzleFive'));
  }, []);

  const [currentSound, setCurrentSound] = useState()

  const SoundPlayer = (name, sound) => {
    if (currentSound == null) {
      console.log("Sound is undefined");
    } else {
      currentSound.sound.unloadAsync().catch(() => { });
    }

    console.log("Playing: " + name);
    Audio.Sound.createAsync(
      sound,
      { shouldPlay: true }
    ).then((res) => {
      setCurrentSound(res);
      res.sound.setOnPlaybackStatusUpdate((status) => {

        if (!status.didJustFinish) return;
        console.log('Unloading ' + name);

        res.sound.unloadAsync().catch(() => { });
      });
    }).catch((error) => { });
  }

  const navBwdSound = Sounds.navigation_backward;

  const dispatch = useDispatch()

  const backToMenu = () => {
    haptics.buttonHaptics();
    // this.myWebView.stopLoading();
    SoundPlayer('navBwdSound', navBwdSound);
    navigation.popToTop();
  }

  return (
    <View style={styles.container}>

      <WebView
        // FIX ME: Commented out "this.myWebView"
        // ref={webview => {
        //   this.myWebView = webview;
        // }}
        // source={{uri: 'https://app.infoskjermen.no/go/bhssvelkommen'}}
        // source={{uri: 'https://vimeo.com/240142844'}}
        source={{ uri: 'https://player.vimeo.com/video/240142844?h=2cae7089ab' }}
        style={{ flex: 1 }}
      />

      <BackButton buttonColor={colorPalette.PEARL_AQUA} onPress={() => backToMenu()} />

    </View>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    //backgroundColor: '#F9D1B3'
  },
  pet: {
    height: '40%',
    width: '40%',
    zIndex: 2,
    bottom: 8,
    position: 'absolute',
    left: -50,
  },
});

export default Info;
