import React, {
  useEffect,
  useRef,
  useState,
} from 'react'
import {
  View,
  Animated,
  Image,
  ImageBackground,
  Pressable,
  StyleSheet,
  ActivityIndicator
} from 'react-native';

import AlertComponent from 'src/global/components/alerts/alert.gdrp';
import { Audio } from 'expo-av';

import { Sounds } from 'src/assets/sounds/sounds';

import AsyncStorage from '@react-native-async-storage/async-storage';

import background from 'src/assets/images/backgrounds/BackgroundPuzzle.jpg'
import playbutton from 'src/assets/images/Play.png'
import logo from 'src/assets/images/logo.jpg'

function Intro({ navigation }) {

  const [currentSound, setCurrentSound] = useState()

  const SoundPlayer = (name, sound) => {

    if (currentSound == null) {
      console.log("Sound is undefined");
    } else {
      currentSound.sound.unloadAsync().catch(() => { });
    }

    console.log("Playing: " + name);
    Audio.Sound.createAsync(
      sound,
      { shouldPlay: true }
    ).then((res) => {
      setCurrentSound(res);
      res.sound.setOnPlaybackStatusUpdate((status) => {

        if (!status.didJustFinish) return;
        console.log('Unloading ' + name);

        res.sound.unloadAsync().catch(() => { });
      });
    }).catch((error) => { });
  }

  const [isLoading, setIsLoading] = useState(false);
  const [alert, setAlert] = useState(null);

  const closeAlert = () => {
    navigation.replace('UserInput');
    setAlert(null);
  }


  // Clear AsyncStorage
  clearAll = async () => {
    try {
      await AsyncStorage.clear()
    } catch (e) {
      // clear error
    }

    console.log('Done.')
  }

  // Use React Native's Animated component to create a new Animated Pressable component
  const AnimatedPressable = Animated.createAnimatedComponent(Pressable);

  // User can't click next until canContinue is true
  const [canContinue, setCanContinue] = useState(true);

  const voice = Sounds.female.hanna;

  const navFwdSound = Sounds.navigation_backward;
  const welcomeSound = voice.welcome_intro;

  useEffect(() => {
    SoundPlayer("WelcomeSound", welcomeSound)
  }, []);


  const start = async () => {
    navigation.replace('PuzzleMain');
  }

  const checkAsync = async () => {
    SoundPlayer("nawFwdSound", navFwdSound);
    setIsLoading(true)
    let isFirst = true;
    if (canContinue) {
      try {
        const value = await AsyncStorage.getItem('user');
        if (value !== null) {
          // playSound(navFwdSound);
          navigation.replace('PuzzleMain');
          console.log(value)
        } else {
          // playSound(navFwdSound);
          setAlert({
            type: 'default',
            title: '',
            description: 'GDPR',
            display: true,
          });
        }
      } catch (error) {
        console.log("error retrieving data")
        setIsLoading(false)
      }
    }
  };

  const clickAnimation = useRef(new Animated.Value(1)).current;


  return (
    <View style={styles.background}>
      {/* <SafeAreaView style={styles.container}> */}
      <ImageBackground source={background} style={styles.background}>
        <View style={styles.container}>
          {/* <ScrollView contentContainerStyle={styles.container}
                        refreshControl={
                            <RefreshControl refreshing={refreshing}
                                            onRefresh={updateApp}
                                            progressViewOffset={50}
                            />
                        }
            > */}
          <Animated.View style={[styles.fadingContainer, {
            opacity: clickAnimation
          }]}>

            <Image source={logo} style={styles.logo} />
            <AnimatedPressable onPress={() => canContinue ? checkAsync() : null}
              style={[styles.playbutton, {
                // opacity: buttonAnimation
              }]}
            >
              <Image source={playbutton} style={styles.playbutton} />
            </AnimatedPressable>
            {isLoading && <ActivityIndicator style={styles.loader} color="black" size="large" />}
          </Animated.View>

          {
            alert && alert.display
              ? <AlertComponent
                //   type={alert.type}
                //   title={alert.title}
                //   description={alert.description}
                //   sound={alert.sound}
                closeAlert={closeAlert}
              />
              : null
          }

          {/* </ScrollView> */}
        </View>
      </ImageBackground>
      {/* </SafeAreaView> */}
    </View>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
  },
  logo: {
    flex: 1,
    alignSelf: 'center',
    width: '80%',
    height: '50%',
    paddingTop: '10%',

    // NB: shadow only works for iOS - Need new specific shadow for Android...
    shadowColor: '#171717',
    shadowRadius: 2,
    shadowOpacity: 0.4,
  },

  background: {
    flex: 1,
    justifyContent: "center",
    alignSelf: 'center',
    width: '100%'

  },
  animation: {
    width: 500,
    position: 'absolute',
    bottom: 0,
    right: '6%'
  },
  playbutton: {
    flex: 0.7,
    resizeMode: 'contain',
    alignSelf: 'center',
    justifyContent: 'center',
    bottom: '10%',

    // NB: shadow only works for iOS - Need new specific shadow for Android...
    shadowColor: '#171717',
    shadowRadius: 2,
    shadowOpacity: 0.2,
  },
  fadingContainer: {
    flex: 1,
    flexDirection: 'column',
    justifyContent: 'center'
  },
  loader: {
    position: 'absolute',
    alignSelf: 'center',


  }
})

export default Intro;
