import React, { useState } from "react";
import {
    StyleSheet,
    View,
    Text,
    Pressable,
    FlatList,
    ScrollView,
} from "react-native";
import { GestureHandlerRootView } from "react-native-gesture-handler";
import { DraxProvider, DraxView, DraxScrollView } from "react-native-drax";
import { Categories } from "./categories.mock";

const FoodMenu = () => {

    const [currentCategory, setCurrentCategory] = useState(null);
    const [chosenItems, setChosenItems] = useState(null);

    const setActiveMenu = (category) => {
        setCurrentCategory(category);
    }

    const addItems = (item) => {
        setChosenItems((prevChosenItems) => {
            if (Array.isArray(prevChosenItems)) {
                return [...prevChosenItems, item.name];
            } else {
                return [item.name];
            }
        });
    }

    return (
        <View style={styles.container}>
            <View style={styles.categories_container}>
                {
                    Categories.map((category) => (
                    <Pressable 
                        key={category.id}
                        onPress={() => setActiveMenu(category.items)} 
                        style={styles.categories_content}
                    >
                        <Text>{category.name}</Text>
                    </Pressable>
                    ))
                }
                {/* <DraxView 
                    style={styles.categories_content}
                    onReceiveDragDrop={({dragged: {payload}}) => {
                        console.log(payload);
                        let item = payload.name; 
                        addItems(payload)
                        console.log(`lengde ${chosenItems?.length}`);
                    }}
                    >
                    <Text>{chosenItems ? chosenItems.slice(-1) : null}</Text>
                </DraxView> */}
            </View>
            <View style={styles.items_container}>
                {
                    currentCategory 
                    ? <SubCategories currentCategory={currentCategory} />
                    : null
                }
            </View>
        </View>
    );
}

const SubCategories = (props) => {
    const { currentCategory } = props;

    return (
        <DraxScrollView 
            contentContainerStyle={styles.scroll_container}
            nestedScrollEnabled={false}
            >
            {
                currentCategory.map(item => (
                    <DraxView
                        key={item.id}
                        payload={item}
                        style={styles.items_content}
                        longPressDelay={150}
                    >
                        <Text>{item.name}</Text>
                    </DraxView>
                ))
            }
        </DraxScrollView>
    );
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
        flexDirection: "row",
        borderTopLeftRadius: 25,
        borderBottomLeftRadius: 25,
        backgroundColor: "#f2f2f2", // light gray
    },

    categories_container: {
        flex: 1,
        margin: 4,
        marginTop: 8,
        marginBottom: 8,
    },
    
    categories_content: {
        flex: 1,
        alignItems: "center",
        justifyContent: "center",
        backgroundColor: "#ffffff", // white
        borderRadius: 10,
        margin: 4,
    },

    items_container: {
        flex: 2,
        borderLeftWidth: 1,
        margin: 4,
        padd: 8,
        marginBottom: 8,
        // height: 320,
        overflow: "hidden",
    },

    scroll_container: {
        flexGrow: 1,
    },

    items_content: {
        flex: 1,
        alignItems: "center",
        margin: 4,
        padding: 15,
        borderRadius: 10,
        backgroundColor: "#ffffff", // white
    }
});

export default FoodMenu;