import React, {useState} from "react";
import { 
    StyleSheet, 
    SafeAreaView,
    StatusBar,
    View, 
    Text, 
} from "react-native";

import { GestureHandlerRootView } from "react-native-gesture-handler";
import { DraxProvider, DraxView} from "react-native-drax";
import FoodMenu from "src/views/meal-plan/food-menu.js";

const MealCreator = () => {
    const [chosenItems, setChosenItems] = useState(null);

    const addItems = (item) => {
        setChosenItems((prevChosenItems) => {
            if (Array.isArray(prevChosenItems)) {
                return [...prevChosenItems, item.name];
            } else {
                return [item.name];
            }
        });
    }

    return (
        <GestureHandlerRootView style={styles.container}>
            <DraxProvider style={styles.drax_container}>
                <View style={styles.leftPadding}>
                    <DraxView style={styles.leftReceiver}
                        onReceiveDragDrop={({dragged: {payload}}) => {
                            let item = payload.name; 
                            addItems(payload)
                        }}
                        borderWidth={1}
                        >
                        <Text>hei</Text>
                        <Text>{chosenItems ? chosenItems.slice(-1) : "null"}</Text>
                    </DraxView>
                </View>
                <View style={styles.foodMenuContainer}>
                    <FoodMenu />
                </View>
            </DraxProvider>
        </GestureHandlerRootView>
    );
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
        paddingTop: Platform.OS === 'android' ? StatusBar.currentHeight: 0,
        backgroundColor: "#ffffff", // white
    },
    drax_container: {
        flex: 1,
        flexDirection: 'row',
    },
    leftPadding: {
        flex: 2,
    },
    foodMenuContainer: {
        flex: 1,
    }
});

export default MealCreator;