import React, { useEffect, useState } from 'react';
import { 
    View, 
    Image, 
    StyleSheet,
    StatusBar,
    Text
} from 'react-native';

import {setMeal} from 'src/global/reducers/meal/meal.slice.js';
import { useDispatch } from 'react-redux';

import { useNavigation } from '@react-navigation/native';
import { GestureHandlerRootView } from "react-native-gesture-handler";
import { DraxProvider, DraxView } from 'react-native-drax';

import * as colorPalette from 'src/global/constants/colorPalette.js';
import AvatarPos4 from 'src/global/avatar/AvatarPos4Component.js';
import MealDropzone from 'src/views/meal-planner/mealModule/mealDropzone.component.js';
import FoodMenu from 'src/views/meal-planner/mealModule/food-menu.component.js';
import AvatarBackButton from 'src/global/components/AvatarBackButton.component.js';

function MealPlanner({ route, navigation }) {
    const dispatch = useDispatch();

    const { selectedMealRedux, planId, dayIndex, mealIndex } = route.params;

    const [mealObject, setMealObject] = useState(selectedMealRedux);
    const [chosenItems, setChosenItems] = useState(selectedMealRedux.foods);

    const addItems = (item) => {
        if (chosenItems.some(i => i.id === item.id)) return; // no duplicates

        setChosenItems( () => {
            return (
                chosenItems
                ? [...chosenItems, item]
                : [item]
            )
        })
    };

    useEffect(() => {
        saveMealToStore(chosenItems);
    }, [chosenItems]);

    const saveMealToStore = (foodArray) => {
        const updatedMealObject = { 
            ...mealObject, 
            foods: foodArray 
        };
        setMealObject(updatedMealObject);
        
        const payload = {
            meal: updatedMealObject,
            planId: planId,
            dayIndex: dayIndex,
            mealIndex: mealIndex
        };
        dispatch(setMeal(payload));
    };

    return (
        <GestureHandlerRootView style={styles.container}>
            <DraxProvider style={styles.screen}>
                <View style={styles.left}>
                    <AvatarBackButton navigation={navigation}/>
                </View>
                <DraxView 
                    style={styles.left_dropzone}
                    onReceiveDragDrop={({dragged: {payload}}) => {
                        addItems(payload)
                    }}
                    // onReceiveDragExit={({dragged: {payload}}) => {
                    //     // removeItems(payload)
                    //     console.log("Dragged item exited");
                    // }}

                    // // doesnt work
                    // onDragExit={({dragged: {payload}}) => {
                    //     // removeItems(payload)
                    //     console.log("Dragged item exited agian");
                    // }}
                >
                    <MealDropzone 
                        items={chosenItems} 
                    />
                </DraxView>
                <View style={styles.foodMenuContainer}>
                    <FoodMenu />
                </View>
            </DraxProvider>
        </GestureHandlerRootView>
    )
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
        paddingTop: Platform.OS === 'android' ? StatusBar.currentHeight: 0,
        // backgroundColor: "#ffffff", // white
        backgroundColor: colorPalette.LIGHT_CYAN,
    },
    screen: {
        flex: 1,
        flexDirection: 'row'
    },

    left: {
        flex: 1,
    },

    left_dropzone: {
        flex: 2,
        flexDirection: 'row', 
        backgroundColor: colorPalette.PASTEL_ORANGE,
        borderRadius: 10,
        marginRight: 8,
    },

    // Side menu (including categories)
    right_side_menu: {
        flex: 1,
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'flex-start'
    },

    dropzone_background: {
        backgroundColor: colorPalette.TIFFANY_BLUE
    },

    dropzone_image: {
        resizeMode: 'contain',
        margin: 30
    },

    foodMenuContainer: {
        flex: 1,
    }
})

export default MealPlanner;