import React, {useEffect} from 'react';
import { 
  Text, 
  View, 
  StyleSheet, 
  ScrollView, 
  StatusBar
} from 'react-native'
import AsyncStorage from '@react-native-async-storage/async-storage';
import { createNativeStackNavigator } from '@react-navigation/native-stack';

import BackButton from 'src/global/components/buttons/BackButton';
import * as colorPalette from 'src/global/constants/colorPalette';
import metrics from 'src/global/constants/metrics';
import fonts from 'src/assets/fonts/fonts';
import { TouchableOpacity } from 'react-native-gesture-handler';
import Avatar from 'src/global/avatar/AvatarComponent.js';
import AvatarPos2 from 'src/global/avatar/AvatarPos2Component.js';
import AvatarPos4 from 'src/global/avatar/AvatarPos4Component.js';
import AvatarBackButton from 'src/global/components/AvatarBackButton.component.js';

import Planview from 'src/views/meal-planner/mealModule/planview.component';
import Dailyview from 'src/views/meal-planner/mealModule/dailyview.component';

import Meal from 'src/global/mock-data/meal.mock.js';
import MealCard from 'src/views/meal-planner/mealModule/mealCard.component.js';

function MealModule({ navigation }) {
  /*
    * This useEffect resests the entire redux state for the app. 
    * ONLY USE DURING DEVELOPMENT
    */
  useEffect(() => {
    AsyncStorage.clear()
  }, []);

  /*  
  The screen is devided into three parts: 
  Left(Backbutton, Avatar) 
  Middle(Dailyview, lion) occupies 2/4 of the screen
  Right(Planview)
  */
  return (
    <View style={styles.screen}>
      
      <View style={styles.left}>
        <BackButton buttonColor={colorPalette.SALMON_PINK}/>
        
        <View style={styles.avatarContainer}>
          <AvatarPos4 mood={5} wheelChair={true}/>
        </View>
        {/* <AvatarBackButton navigation={navigation}/> */}
      </View>

        <View style={styles.middle}>
          <Dailyview/>
        </View>

      <View style={styles.right}>
        <Planview />
      </View>
    </View>
  )
}

const styles = StyleSheet.create({
  
  screen: {
    flex: 1,
    width: '100%',
    flexDirection: 'row',
    paddingTop: Platform.OS === 'android' ? StatusBar.currentHeight : 0,
    backgroundColor: colorPalette.LIGHT_CYAN,
  },
  
  avatarContainer: {
    position: 'absolute',
    height: '70%', 
    width: '60%',
    alignItems: 'center',
    bottom: '5%',
    left: '15%',
  },
  
  left: {
    flex: 1,
  },

  middle: {
    flex: 2,
    flexDirection: 'column',
    alignContent: 'center',
    height: '100%',
  },

  right: {
    flex: 1
  },

  text: { // ikke i bruk
    flex: 1,
    flexDirection:'column',
    top: 5,
    margin: 5,
    marginLeft: 10,
    marginRight: 10,
    padding: 10,
    fontSize: fonts.size.font16,
    fontFamily: "MyriadPro",
    color: '#000000',
    backgroundColor: colorPalette.DEEP_PEACH,
    borderRadius: 5,

    // this makes borderradius visible, check react-native docs
    overflow: 'hidden',
  }
})

export default MealModule;