import React, { useEffect, useState } from 'react'
import { 
  ScrollView, 
  Text, 
  View,
  Pressable,
  StyleSheet
} from 'react-native'

import { useNavigation } from '@react-navigation/native';
import  { useSelector } from 'react-redux';

import * as colorPalette from 'src/global/constants/colorPalette';
import metrics from 'src/global/constants/metrics';
import fonts from 'src/assets/fonts/fonts';

import MealCard from './mealCard.component';
import Meal from 'src/global/mock-data/meal.mock.js';
import MealCardNew from './mealCardNew.component';

function Dailyview() {
  const navigation = useNavigation();
  
  const reduxMockData = useSelector(state => state.meal);
  const reduxMockDataPlans = reduxMockData.plans;

  // get indexes for adding new meal
  // const lastPlan = reduxMockDataPlans.slice(-1)[0];
  // const lastDay = lastPlan.days.slice(-1)[0];
  // const lastPlanIndex = reduxMockDataPlans.length - 1;
  // const lastDayIndex = lastPlan.days.length - 1;
  // const lastMealIndex = lastDay.meals.length - 1;

  return (
    <View style={styles.main}>
      <Text style={styles.title}>I dag</Text>
      <ScrollView style={styles.scrollview}>
        {
          reduxMockDataPlans.map(( plan, planIndex ) => {
            return plan.days.map(( day, dayIndex ) => {
              return day.meals.map(( meal, mealIndex ) => {
                // setMealIndexGlobal(mealIndex);
                return (
                  <Pressable 
                    key={mealIndex}
                    onPress={() => {
                      navigation.navigate('MealBuilder', {
                        selectedMealRedux: meal,
                        planId: plan.id,
                        dayIndex: dayIndex,
                        mealIndex: mealIndex,
                      });
                    }}>
                    <MealCard
                      key={mealIndex}
                      meal={meal}
                    />
                  </Pressable>
                )
              })
            })
          })
        }
        {/* <MealCardNew
          lastPlanIndex={lastPlanIndex}
          lastDayIndex={lastDayIndex}
          lastMealIndex={lastMealIndex}
        /> */}
      </ScrollView>
    </View>
  )
}

const styles = StyleSheet.create({
  main: {
      flex: 1,
      marginBottom: metrics.width / 50,
  },

  title: {
    fontSize: fonts.size.font20,
    fontWeight: 'strong',
    top: 20,
    bottom: 20,
    fontFamily: "MyriadPro",
    color: '#000000'
  },

  scrollview : {
    backgroundColor: colorPalette.PASTEL_ORANGE,
    // height: '70%', // på ios // på android
    // som under her blir width brukt for å definere høyde
    // flex: 1,
    padding: 10,
    marginTop: 20,
    marginRight: 8,
    borderRadius: 10,
    // padding: metrics.width / 75,
    // marginTop: metrics.width / 40,
    // marginBottom: metrics.width / 40,
    // marginRight: metrics.width / 100,
    // borderTopLeftRadius: metrics.width / 75,
    // borderTopRightRadius: metrics.width / 75,
  },
})

export default Dailyview;