import React, { useState } from "react";
import {
    StyleSheet,
    View,
    Text,
    Pressable,
    ScrollView,
    Image
} from "react-native";

import { GestureHandlerRootView } from "react-native-gesture-handler";
import { DraxProvider, DraxView, DraxScrollView } from "react-native-drax";

import * as colorPalette from "src/global/constants/colorPalette";
import Categories from "src/global/mock-data/categories.mock";
import metrics from "src/global/constants/metrics";

const FoodMenu = () => {

    const [currentCategory, setCurrentCategory] = useState(null);
    const [chosenItems, setChosenItems] = useState(null);

    const setActiveMenu = (category) => {
        setCurrentCategory(category);
    }

    const addItems = (item) => {
        setChosenItems((prevChosenItems) => {
            if (Array.isArray(prevChosenItems)) {
                return [...prevChosenItems, item.name];
            } else {
                return [item.name];
            }
        });
    }

    return (
        <View style={styles.container}>
            <View style={styles.categories_container}>
                {
                    Categories.map((category) => (
                    <Pressable 
                        key={category.id}
                        onPress={() => setActiveMenu(category.items)} 
                        style={styles.categories_content}
                    >
                        <Image source={category.icon} style={styles.categoryImage}/>
                        <Text>{category.name}</Text>
                    </Pressable>
                    ))
                }
            </View>
            <View style={styles.items_container}>
                {
                    currentCategory 
                    ? <SubCategories currentCategory={currentCategory} />
                    : null
                }
            </View>
        </View>
    );
}

const SubCategories = (props) => {
    const { currentCategory } = props;

    return (
        <DraxScrollView 
            Style={styles.scroll_container}
            nestedScrollEnabled={false}
            >
            {
                currentCategory.map(item => (
                    <DraxView
                        key={item.id}
                        payload={item}
                        style={styles.items_content}
                        longPressDelay={150}
                    >
                        <Image source={item.icon} style={styles.foodImage} />
                        <Text>{item.name}</Text>
                    </DraxView>
                ))
            }
        </DraxScrollView>
    );
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
        flexDirection: "row",
        borderTopLeftRadius: 25,
        borderBottomLeftRadius: 25,
        // backgroundColor: "#f2f2f2", // light gray
        backgroundColor: colorPalette.ATOMIC_TANGERINE,
    },

    categories_container: {
        flex: 1,
        margin: 4,
        marginTop: 8,
        marginBottom: 8,
    },
    
    categories_content: {
        flex: 1,
        alignItems: "center",
        justifyContent: "center",
        backgroundColor: "#ffffff", // white
        borderRadius: 10,
        margin: 4,
        marginRight: 0
    },

    items_container: {
        flex: 2,
        borderLeftWidth: 1,
        margin: 4,
        overflow: "hidden",
    },

    scroll_container: {
        flexGrow: 1,
    },

    items_content: {
        flex: 1,
        alignItems: "center",
        margin: 4,
        padding: 15,
        borderRadius: 10,
        backgroundColor: "#ffffff", // white
    },

    foodImage: {
        height: 80,
        resizeMode: "contain",
    },

    categoryImage: {
        height: 40,
        resizeMode: "contain",
    }

});

export default FoodMenu;