import {
    Text,
    Image,
    View,
    StyleSheet
} from 'react-native';
import React from 'react';

import metrics from 'src/global/constants/metrics';
import * as colorPalette from 'src/global/constants/colorPalette';
import Categories from 'src/global/mock-data/categories.mock.js';
import foodItems from 'src/global/mock-data/all_items.js';

export default function MealCard(props) {
    const { meal } = props;

    const foods = meal.foods.filter(food => food.type === 'Mat');
    const drink = meal.foods.find(food => food.type === 'Drikke');
    const fruitSnacksOther = meal.foods.find(food => food.type === 'Snacks' 
                                || food.type === 'Frukt' || food.type === 'Annet');

    const imageMainPngArray = foods?.map(food => foodItems.find(item => item.id === food?.id)?.icon);
    const imageDrinkPng = foodItems.find(item => item.id === drink?.id)?.icon;
    const imageSnacksPng = foodItems.find(item => item.id === fruitSnacksOther?.id)?.icon;
    
    return (
        <View style={styles.cardContainer}>
            <View style={styles.titleContainer}>
                <Text style={styles.title}>{meal.type}</Text>
            </View>
            <View style={styles.contentContainer}>
                <View style={styles.contentsLeft}>
                    {
                        imageMainPngArray.length > 0 
                        ? imageMainPngArray.map((foodImage, index) => (
                            <Image 
                            key={index}
                            source={foodImage} 
                            style={imageMainPngArray.length === 1 ? styles.main : styles.drink} 
                            resizeMode="contain" />
                        ))
                        : <Image 
                            source={require('src/assets/images/meal-planner/plate-empty.png')} 
                            style={styles.main} 
                            resizeMode="contain" />
                    }
                </View>
                <View style={styles.contentsRight}>
                    {
                        imageDrinkPng
                        ? <Image source={imageDrinkPng} style={styles.drink} resizeMode="contain" />
                        : <Image source={require('src/assets/images/meal-planner/glass-empty.png')}
                             style={styles.drink} resizeMode="contain" />
                    }
                    {
                        imageSnacksPng
                        ? <Image source={imageSnacksPng} style={styles.snacks} resizeMode="contain" />
                        : <Image source={require('src/assets/images/meal-planner/apple-empty.png')}
                            style={styles.snacks} resizeMode="contain" />
                    }
                </View>
            </View>
        </View> 
    )

}

const styles = StyleSheet.create({

    cardContainer: {
        flex: 1,
        flexDirection: 'column',
        width: '100%',
        backgroundColor: colorPalette.CORNSILK,
        alignSelf: 'center',
        borderRadius: metrics.width / 75,
        justifyContent: 'center',
        shadowColor: '#000',
        shadowOffset: {
            width: 0,
            height: 2
        },
        shadowOpacity: 0.35,
        shadowRadius: 3.84,
        elevation: 5,
        marginBottom: '3%',
    },

    titleContainer: {
        borderBottomWidth: 1,
        borderBottomColor: 'grey',
    },

    contentContainer: {
        flex: 1,
        flexDirection: 'row',
        height: 200,
        alignItems: 'center',
        justifyContent: 'space-between',
        paddingHorizontal: '10%',
    },

    contentsLeft: {
        flex: 1.5,
    },

    contentsRight: {
        flex: 1,
        flexDirection: 'column',
        justifyContent: 'flex-end',
        alignItems: 'flex-end',
    },

    title: {
        fontSize: 20,
        alignSelf: 'center',
        padding: 10,
    },

    main: {
        width: '100%',
        height: '70%',
        alignItems: 'flex-end',
    },

    drink: {
        width: '100%',
        height: '50%',
        alignItems: 'flex-start',
    },

    snacks: {
        width: '100%',
        height: '40%',
        alignItems: 'flex-start',
    }


})