import {
    Text,
    Image,
    View,
    StyleSheet,
    Pressable,
} from 'react-native';
import React from 'react';
import { useNavigation } from '@react-navigation/native';
import { useDispatch } from 'react-redux';
import {createMeal} from 'src/global/reducers/meal/meal.slice.js';

import metrics from 'src/global/constants/metrics';
import * as colorPalette from 'src/global/constants/colorPalette';
import Categories from 'src/global/mock-data/categories.mock.js';
import foodItems from 'src/global/mock-data/all_items.js';

export default function MealCard(props) {
    const dispatch = useDispatch();
    const navigation = useNavigation();
    const { lastPlanIndex, lastDayIndex, lastMealIndex } = props;
    
    const mealTypes = ['Frokost', 'Lunsj', 'Middag', 'Kveldsmat'];
    const times = ['08:00', '12:00', '16:00', '20:00'];

    const newMeal = {
        createdAt: new Date().toISOString(),
        times: times[(lastMealIndex + 1) % times.length],
        type: mealTypes[(lastMealIndex + 1) % mealTypes.length],
        foods: [],
    };
    
    const mealIndex = (lastMealIndex + 1) % 4;
    const getDayIndex = (lastDay) => {
        if (mealIndex === 0) { // new day
            return (lastDay + 1) % 7;
        }
        else {
            return lastDay;
        }
    };
    const dayIndex = getDayIndex(lastDayIndex);
    
    return (
        <View style={styles.cardContainer}>
            <Pressable 
                onPress={() => {
                    // const payload = {
                    //     meal = newMeal,
                    //     planId = lastPlanIndex,
                    //     dayIndex = dayIndex,
                    //     mealIndex = mealIndex,
                    // };
                    // dispatch(createMeal(payload));
                    navigation.navigate('MealBuilder', {
                    selectedMealRedux: {newMeal},
                    planId: {lastPlanIndex},
                    dayIndex: {dayIndex},
                    mealIndex: {mealIndex},
                    });
                }}
            >
                <View style={styles.titleContainer}>
                    <Text style={styles.title}>{newMeal.type}</Text>
                </View>
                <View style={styles.contentContainer}>
                    <View style={styles.contentsLeft}>
                        <Image 
                            source={require('src/assets/images/meal-planner/plate-empty.png')} 
                            style={styles.main} 
                            resizeMode="contain" 
                        />
                    </View>
                    <View style={styles.contentsRight}>
                        <Image source={require('src/assets/images/meal-planner/glass-empty.png')}
                                style={styles.drink} resizeMode="contain" 
                        />
                        <Image source={require('src/assets/images/meal-planner/apple-empty.png')}
                                style={styles.snacks} resizeMode="contain" 
                        />
                    </View>
                </View>
            </Pressable>
        </View> 
    )
}

const styles = StyleSheet.create({

    cardContainer: {
        flex: 1,
        flexDirection: 'column',
        width: '100%',
        backgroundColor: colorPalette.CORNSILK,
        alignSelf: 'center',
        borderRadius: metrics.width / 75,
        justifyContent: 'center',
        shadowColor: '#000',
        shadowOffset: {
            width: 0,
            height: 2
        },
        shadowOpacity: 0.35,
        shadowRadius: 3.84,
        elevation: 5,
        marginBottom: '3%',
    },

    titleContainer: {
        borderBottomWidth: 1,
        borderBottomColor: 'grey',
    },

    contentContainer: {
        flex: 1,
        flexDirection: 'row',
        height: 200,
        alignItems: 'center',
        justifyContent: 'space-between',
        paddingHorizontal: '10%',
    },

    contentsLeft: {
        flex: 1.5,
    },

    contentsRight: {
        flex: 1,
        flexDirection: 'column',
        justifyContent: 'flex-end',
        alignItems: 'flex-end',
    },

    title: {
        fontSize: 20,
        alignSelf: 'center',
        padding: 10,
    },

    main: {
        width: '100%',
        height: '70%',
        alignItems: 'flex-end',
    },

    drink: {
        width: '100%',
        height: '50%',
        alignItems: 'flex-start',
    },

    snacks: {
        width: '100%',
        height: '40%',
        alignItems: 'flex-start',
    }


})