import React, { useEffect, useState } from 'react';
import {
    Image,
    View,
    StyleSheet,
    Text,
    FlatList,
} from "react-native";

import { DraxView } from "react-native-drax";

import * as colorPalette from 'src/global/constants/colorPalette';
import foodItems from 'src/global/mock-data/all_items.js';

const MealDropzone = (props) => {
    const items = props.items;

    const [activePlate, setActivePlate] = useState(null);
    const [activeDrink, setActiveDrink] = useState(null);
    const [activeOther, setActiveOther] = useState(null);

    useEffect(() => {
        const newActivePlate = [];
        items?.forEach(element => {
            if (element.type === 'Mat') {
                newActivePlate.push(element);
            }
            else if (element.type === 'Drikke') {
                setActiveDrink(element);
            }
            else {
                if (element.id !== ''){
                    setActiveOther(element);
                }
            }
        });
        setActivePlate( () => {
            return newActivePlate.length > 0 ? newActivePlate : null;
        })
    }, [items]);

    return (
        <View style={styles.container}>
            <View style={styles.left_container}>
                {
                    activePlate
                    ? activePlate.map((item, index) => (
                        <DraxView
                            key={item.id}
                            payload={item}
                            style={styles.items_content}
                            onDragExit={({dragged: {payload}}) => {
                                // removeItems(payload)
                                console.log("Dragged item exited in drop");
                            }}
                        >
                            <Image
                                key={index}
                                source={foodItems.find(food => food.id === item?.id)?.icon}
                                style={styles.plate}
                                resizeMode="contain"
                            />
                        </DraxView>
                    ))
                    : <Image
                        source={require('src/assets/images/meal-planner/plate-empty.png')}
                        style={styles.plate}
                        resizeMode="contain"
                    />
                }
            </View>
            <View style={styles.right_container}>
                {
                    activeDrink
                    ? <Image
                        source={foodItems.find(food => food.id === activeDrink?.id)?.icon}
                        style={styles.glass}
                        resizeMode="contain"
                    />
                     // <Text>{activeDrink.icon}</Text>
                    : <Image
                        source={require('src/assets/images/meal-planner/glass-empty.png')}
                        style={styles.glass}
                        resizeMode="contain"
                    />
                }
                {
                    activeOther
                    ? <Image 
                        source={foodItems.find(food => food.id === activeOther?.id)?.icon}
                        style={styles.apple}
                        resizeMode="contain"
                    />  // <Text>{activeOther.icon}</Text>
                    : <Image
                        source={require('src/assets/images/meal-planner/apple-empty.png')}
                        style={styles.apple}
                        resizeMode="contain"
                    />
                }
            </View>
        </View>
    )
}

const styles = StyleSheet.create({

    container: {
        flex: 1,
        flexDirection: 'row',
        alignItems: 'center',
        backgroundColor: '#EBEBEB',
        backgroundColor: colorPalette.CORNSILK,
        // borderWidth: 3,
        margin: 10,
        borderRadius: 10,
    },

    left_container: {
        flex: 3.5,
        alignItems: 'center',
    },

    right_container: {
        flex: 1.5,
        flexDirection: 'column',
        alignItems: 'center',
        justifyContent: 'flex-start',
    },

    plate: {
        flex: 1,
        // width: '100%', // for tomt fat
        width: 100, // for fylt fat
        height: 100,
        resizeMode: 'contain',
    },

    glass: {
        flex: 0.4,
        width: '90%'
    },

    apple: {
        flex: 0.3,
        width: '90%'
    },
    
    items_content: {
        flex: 1,
        alignItems: "center",
        margin: 4,
        // padding: 60,
        borderRadius: 10,
        // borderWidth: 1,
        // backgroundColor: "#ffffff", // white
    },
})

export default MealDropzone;