import React, { useState, Fragment } from 'react'
import {
  ScrollView,
  Text,
  StyleSheet,
  Pressable,
} from 'react-native'
import { useSelector, useDispatch } from 'react-redux';
import { createDay, createPlan } from 'src/global/reducers/meal/meal.slice.js';

import metrics from 'src/global/constants/metrics.js';
import fonts from 'src/assets/fonts/fonts.js';
import * as colorPalette from 'src/global/constants/colorPalette.js';

const Planview = () => {
  const dispatch = useDispatch();

  // Get days of the week
  const mealState = useSelector(state => state.meal);
  // const days = mealState.plans[0].days;
  const dayNames = ['Mandag', 'Tirsdag', 'Onsdag', 'Torsdag', 'Fredag', 'Lørdag', 'Søndag'];

  function testPrint() {
    // console.log(days[0]);
    console.log(mealState.plans[0].id);
  } 

  const isEndofWeek = (week) => {
    return week.length === 7;
  }

  const newDay = (lastPlan) => {
    const payload = {
      planId: lastPlan.id,
    };
    if (isEndofWeek(lastPlan.days)) {
      payload.planId = lastPlan.id + 1;
      dispatch(createPlan(payload));
    }
    dispatch(createDay(payload));
  }

  return (
    <ScrollView style={styles.planView}>
      {
        mealState.plans.map((plan, planIndex) => {
          return (
            <Fragment key={planIndex}>
              <Text style={styles.week_header} >Uke</Text>
                {plan.days.map((day, dayIndex) => {
                  return (
                    <Pressable 
                      style={styles.days_container} 
                      key={dayIndex} 
                      onPress={testPrint}
                    >
                      <Text style={styles.text}>{dayNames[dayIndex]}</Text>
                    </Pressable>
                  )
                })}
            </Fragment>
          )
        })
      }
      <Pressable 
        style={styles.days_container}
        onPress={() => newDay(mealState.plans[mealState.plans.length - 1])}
      >
        <Text style={styles.text}>Ny dag</Text>
      </Pressable>
    </ScrollView>
  )
}

const styles = StyleSheet.create({
  planView: {
    backgroundColor: colorPalette.ATOMIC_TANGERINE,
    flex: 1,
    // height: '100%', // gjør denne noe på ios?

    // her brukes width til å definere top og bottom
    // det gir mer mening for meg å bruke metrics.height her
    // men i andre komopnenter fra adfectus bruker de metrics.width
    // til å definere de
    // derfor har jeg valgt å bruke metrics.width
    marginRight: metrics.width / 50,
    marginTop: metrics.width / 50,
    borderTopLeftRadius: metrics.width / 75,
    borderTopRightRadius: metrics.width / 75,
  },

  week_header: {
    flex: 1,
    textAlign: 'center',
    fontSize: fonts.size.font16
  },

  days_container: {
    flex: 1,
    flexDirection: 'column',
    top: 5,
    margin: 5,
    marginLeft: 10,
    marginRight: 10,
    padding: 10,
    borderRadius: 5,
    backgroundColor: colorPalette.DEEP_PEACH,
    // this makes borderradius visible, check react-native docs
    overflow: 'hidden',
  },

  text: {
    flex: 1,
    fontSize: fonts.size.font16,
    fontFamily: "MyriadPro",
  }
})

export default Planview;