import React, {
  useEffect,
  useRef,
  useState,
} from 'react';
import {
  Animated,
  Dimensions,
  Easing,
  ScrollView,
  StyleSheet,
  TouchableOpacity,
} from 'react-native';
import {
  DraxProvider,
  DraxView
} from 'react-native-drax';
import {
  useDispatch,
  useSelector,
} from 'react-redux';
import AsyncStorage from '@react-native-async-storage/async-storage';
import { Audio } from 'expo-av';

import { Sounds } from 'src/assets/sounds/sounds';

import { GestureHandlerRootView } from 'react-native-gesture-handler';

import SvgBathingSuitWHanger from 'src/assets/objects/dynamic/BathingSuitWHanger';
import SvgBeanie from 'src/assets/objects/dynamic/Beanie';
import SvgBooks from 'src/assets/objects/dynamic/Books';
import SvgBoots from 'src/assets/objects/dynamic/Boots';
import SvgCat from 'src/assets/objects/dynamic/Cat';
import SvgCoffeCan from 'src/assets/objects/dynamic/CoffeCan';
import SvgDetergent from 'src/assets/objects/dynamic/Detergent';
import SvgHoodieHanger from 'src/assets/objects/dynamic/HoodieHanger';
import SvgIPad from 'src/assets/objects/dynamic/IPad';
import SvgMedicines from 'src/assets/objects/dynamic/Medicines';
import SvgMittens from 'src/assets/objects/dynamic/Mittens';
import SvgOutWearHanger from 'src/assets/objects/dynamic/OutWearHanger';
import SvgPackedClothing from 'src/assets/objects/dynamic/PackedClothing';
import SvgPan from 'src/assets/objects/dynamic/Pan';
import SvgPlunger from 'src/assets/objects/dynamic/Plunger';
import SvgRainCoatHanger from 'src/assets/objects/dynamic/RainCoatHanger';
import SvgServiceDog from 'src/assets/objects/dynamic/ServiceDog';
import SvgShampoo from 'src/assets/objects/dynamic/Shampoo';
import SvgShortsWHanger from 'src/assets/objects/dynamic/ShortsWHanger';
import SvgSkiGear from 'src/assets/objects/dynamic/SkiGear';
import SvgSneakers from 'src/assets/objects/dynamic/Sneakers';
import SvgTeddyBear from 'src/assets/objects/dynamic/TeddyBear';
import SvgToothBrush from 'src/assets/objects/dynamic/ToothBrush';
import SvgTopHanger from 'src/assets/objects/dynamic/TopHanger';
import SvgTowels from 'src/assets/objects/dynamic/Towels';
import SvgToyCar from 'src/assets/objects/dynamic/ToyCar';
import SvgTrainingClothesHanger from 'src/assets/objects/dynamic/TraingClothesHanger';
import SvgWinterBoots from 'src/assets/objects/dynamic/WinterBoots';
import SvgWrench from 'src/assets/objects/dynamic/Wrench';

import { packObject } from 'src/global/reducers/packing/OBJECTSLICE';
import { addToBackpack } from 'src/global/reducers/packing/packedObjects.slice';
import {
  clicked,
} from 'src/global/reducers/puzzle/puzzle.slice.js';

import HintsOverlay from './room/room.hintsOverlay';

import Avatar from 'src/global/avatar/AvatarComponent';
import AvatarPos4 from 'src/global/avatar/AvatarPos4Component';
import { selectWheelChair } from 'src/global/reducers/avatar/aidSlice';

import AlertComponent from 'src/global/components/alerts/alert.component';
import SvgSuitCase from './suitcase.svgr';
import BackButton from 'src/global/components/buttons/BackButton';
import * as colorPalette from 'src/global/constants/colorPalette';
import haptics from 'src/global/constants/haptics';

// Replace render function with getter in object list
const RenderObject = (id) => {
  switch (id) {
    case 'c0f761c351a18394': return <SvgSkiGear />;
    case '157a6034f3f657f0': return <SvgShortsWHanger />;
    case 'f577a7ed9c2d7794': return <SvgBathingSuitWHanger />;
    case 'c6dc5751c805e8ed': return <SvgBeanie />;
    case '8c02efe24210e03e': return <SvgBooks />;
    case '46e85c421b77d776': return <SvgBoots />;
    case 'e46415e84e0b1f35': return <SvgCat />;
    case '51688c9d2c1e4ab0': return <SvgCoffeCan />;
    case '05882647cf455bd3': return <SvgDetergent />;
    case '37b9fc63febfbceb': return <SvgRainCoatHanger />;
    case '9ce0c7e6f18bd941': return <SvgHoodieHanger />;
    case '83db4c36b2e07939': return <SvgTopHanger />;
    case '4dba0c2fe6abcde8': return <SvgIPad />;
    case 'd922a8a1cc569821': return <SvgMedicines />;
    case 'caacd36afafc6fa6': return <SvgMittens />;
    case '1fa5d969d3719704': return <SvgOutWearHanger />;
    case 'b431978ae45e7136': return <SvgPackedClothing />;
    case '2c350dd7372dbae2': return <SvgPan />;
    case '32a7439b47b5a4f6': return <SvgPlunger />;
    case '444cf25df972cb33': return <SvgServiceDog />;
    case '3c1e589f7304d654': return <SvgShampoo />;
    case 'ed06708c158d82ca': return <SvgSneakers />;
    case '71f0bc0dae3fff55': return <SvgTeddyBear />;
    case '5b4d7ef51be3f559': return <SvgToothBrush />;
    case '85b6cf37df90d858': return <SvgTowels />;
    case 'b25b2fc1c102f9fe': return <SvgToyCar />;
    case 'f9013475ea8dd269': return <SvgTrainingClothesHanger />;
    case '38bdb0d0e158cc1b': return <SvgWinterBoots />;
    case '3dace1eb66da2fba': return <SvgWrench />;
    default: break;
  }
}

const RoomComponent = ({ navigation }) => {
  const { objects } = useSelector(state => state.allObjects);
  const dispatch = useDispatch();

  const isWheelChair = useSelector(selectWheelChair);

  const [loadingComplete, setLoadingComplete] = useState(false);
  const [hintsOverlay, setHintsOverlay] = useState(false);
  const [hintsOverlayHide, setHintsOverlayHide] = useState(false);

  const viewportHeight = Dimensions.get('window').height;
  const viewportWidth = Dimensions.get('window').width;
  const [canvasWidth, setCanvasWidth] = useState((viewportHeight * 2) * 1.43928036);
  const [canvasHeight, setCanvasHeight] = useState(viewportHeight * 2);

  const roomWidthAnimation = useRef(new Animated.Value(0)).current;
  const roomHeightAnimation = useRef(new Animated.Value(0)).current;
  const elementsOpacityAnimation = useRef(new Animated.Value(0)).current;
  const backpackOpacityAnimation = useRef(new Animated.Value(0)).current;

  const [yPos, setYPos] = useState(0);
  const [xPos, setXPos] = useState(0);

  const [backpackYPos, setBackpackYPos] = useState(15);
  const [backpackXPos, setBackpackXPos] = useState(0);

  const [alert, setAlert] = useState(null);

  const closeAlert = () => {
    setAlert(null);
  }

  const [currentSound, setCurrentSound] = useState()

  const SoundPlayer = (name, sound) => {
    if (currentSound == null) {
      console.log("Sound is undefined");
    } else {
      currentSound.sound.unloadAsync().catch(() => { });
    }

    console.log("Playing: " + name);
    Audio.Sound.createAsync(
      sound,
      { shouldPlay: true }
    ).then((res) => {
      setCurrentSound(res);
      res.sound.setOnPlaybackStatusUpdate((status) => {

        if (!status.didJustFinish) return;
        console.log('Unloading ' + name);

        res.sound.unloadAsync().catch(() => { });
      });
    }).catch((error) => { });
  }

  useEffect(() => {
    initElements();
    progressCheck();
    setTimeout(() => {
      Animated.sequence([
        Animated.parallel([
          Animated.timing(roomWidthAnimation, {
            toValue: 1,
            duration: 1000,
            easing: Easing.bezier(0.175, 0.885, 0.32, 1.15),
            useNativeDriver: false,
          }),
          Animated.timing(roomHeightAnimation, {
            toValue: 1,
            duration: 1000,
            easing: Easing.bezier(0.175, 0.885, 0.32, 1.15),
            useNativeDriver: false,
          }),
        ]),
        Animated.timing(elementsOpacityAnimation, {
          toValue: 100,
          duration: 750,
          useNativeDriver: true,
        }),
        Animated.timing(backpackOpacityAnimation, {
          toValue: 100,
          duration: 750,
          useNativeDriver: true,
        }),
      ]).start(() => {
        setTimeout(() => setHintsOverlay(true), 1000);
      });
    }, 1500);
  }, []);

  const initElements = async () => {
    const hintsOverlayCompleted = await AsyncStorage.getItem('@hints_overlay');
    if (hintsOverlayCompleted) {
      setHintsOverlayHide(true);
    }
    setYPos(viewportHeight + 35);
    setLoadingComplete(true);
  }

  const addItemToBackpack = (item) => {
    if (item.features.addible) {
      SoundPlayer("successSound", successSound);
      dispatch(packObject(item.id));
      dispatch(addToBackpack(item));
    } else {
      SoundPlayer("errorSound", errorSound);
      // Custom alert
      setAlert({
        type: 'error',
        title: item.info.name,
        description: `Du kan ikke ta med deg ${item.info.name}`,
        sound: item.sound,
        display: true,
      });
    }
    progressCheck(item);
  }

  const progressCheck = async (item) => {
    let packingCompleted = await AsyncStorage.getItem('@packing_completed');

    let packedItems = [];

    if (item && item.features.required) {
      let index = packedItems.indexOf(item.id);
      if (index === -1) {
        packedItems.push(item);
      }
    }

    for (let object of objects) {
      if (object.features.required && object.features.packed) {
        let index = packedItems.indexOf(object.id);
        if (index === -1) {
          packedItems.push(object);
        }
      }
    }

    if (packedItems.length === 14 && !packingCompleted) {
      console.log(`All required items have been packed!`);
      SoundPlayer("packingCompleteSound", packingCompleteSound);
      setAlert({
        type: 'success',
        title: 'Så flink du er!',
        description: 'Nå har du pakket alt du trenger.',
        sound: voice.packing_complete,
        previousSound: packingCompleteSound,
        display: true,
      });
      await AsyncStorage.setItem('@packing_completed', 'completed');
      dispatch(clicked('PuzzleFour'));
    }
  }

  const onYScroll = (event) => {
    setYPos(viewportHeight - event.nativeEvent.contentOffset.y + 35);
    setBackpackYPos(event.nativeEvent.contentOffset.y + 15);
  }

  const onXScroll = (event) => {
    setXPos(event.nativeEvent.contentOffset.x + 5);
    setBackpackXPos(event.nativeEvent.contentOffset.x + 5);
  }

  const leaveRoom = () => {
    haptics.buttonHaptics();
    SoundPlayer('navBwdSound', navBwdSound);
    navigation.popToTop();
  }

  // Sounds
  const voice = Sounds.female.hanna;

  const navFwdSound = Sounds.navigation_forward;
  const navBwdSound = Sounds.navigation_forward;
  const successSound = Sounds.success;
  const dropSound = Sounds.drop;
  const errorSound = Sounds.error;
  const packingCompleteSound = voice.packing_complete;

  return (
    <>
      {/* <SafeAreaView style={{ flex: 1 }}> */}
      {/* <View style={{ flex: 1 }}>  */}
      <GestureHandlerRootView style={{ flex: 1 }}>

        <ScrollView style={{ flex: 1 }}
          onScroll={(event) => onXScroll(event)}
          scrollEventThrottle={1}
          bounces={false}
          horizontal={true}
          nestedScrollEnabled
        >
          <ScrollView style={{ flex: 1 }}
            onScroll={(event) => onYScroll(event)}
            nestedScrollEnabled
            scrollEventThrottle={1}
            bounces={false}
            contentContainerStyle={{ height: loadingComplete ? canvasHeight : viewportHeight }}
          >
            <DraxProvider>
              <Animated.View style={{
                width: roomWidthAnimation.interpolate({
                  inputRange: [0, 1],
                  outputRange: [viewportWidth, canvasWidth]
                }),
                height: roomHeightAnimation.interpolate({
                  inputRange: [0, 1],
                  outputRange: [viewportHeight, canvasHeight]
                }),
              }}
              >
                <Animated.Image source={require('./bedroom_lg.png')}
                  style={{
                    width: roomWidthAnimation.interpolate({
                      inputRange: [0, 1],
                      outputRange: [viewportWidth, ((viewportHeight * 2) * 1.43928036)]
                    }),
                    height: roomHeightAnimation.interpolate({
                      inputRange: [0, 1],
                      outputRange: [viewportHeight, (viewportHeight * 2)]
                    }),
                  }}
                />

                <Animated.View style={{
                  position: 'absolute',
                  top: isWheelChair ? '48%' : '45%',
                  left: isWheelChair ? '66%' : '67%',
                  width: viewportWidth / 2,
                  height: 1,
                  opacity: elementsOpacityAnimation.interpolate({
                    inputRange: [0, 10, 20, 30, 40, 50, 60, 70, 80, 90, 100],
                    outputRange: [0.0000000001, 0.05, 0.10, 0.15, 0.20, 0.25, 0.30, 0.40, 0.60, 0.80, 1],
                  }),
                }}>
                  {
                    isWheelChair
                      ? <AvatarPos4 mood={5} wheelChair={true} />
                      : <Avatar mood={5} />
                  }
                </Animated.View>

                <>
                  {
                    loadingComplete
                      ? objects.map((item) => {
                        return (
                          !item.features.packed && item.features.display
                            ? <DraxView payload={item}
                              key={item.id}
                              onDragStart={() => { }}
                              onDragEnd={() => SoundPlayer('dropSound', dropSound)}
                              draggingStyle={{ opacity: 0 }}
                              dragReleasedStyle={{ opacity: 0 }}
                              style={{
                                position: 'absolute',
                                left: item.styles.position.left,
                                top: item.styles.position.top,
                                width: (viewportHeight / 10) * item.styles.scale,
                                height: (viewportHeight / 10) * item.styles.scale,
                                opacity: elementsOpacityAnimation.interpolate({
                                  inputRange: [0, 10, 20, 30, 40, 50, 60, 70, 80, 90, 100],
                                  outputRange: [0.0000000001, 0.05, 0.10, 0.15, 0.20, 0.25, 0.30, 0.40, 0.60, 0.80, 1],
                                }),
                              }}
                            >
                              {RenderObject(item.id)}
                            </DraxView>
                            : null
                        )
                      }
                      )
                      : null
                  }
                </>

                {/* BACKPACK */}
                {
                  loadingComplete
                    ? <DraxView onReceiveDragDrop={({ dragged: { payload } }) => addItemToBackpack(payload)}
                      style={{
                        width: viewportHeight / 3,
                        height: viewportHeight / 3 + 3,
                        position: 'absolute',
                        bottom: yPos,
                        left: xPos,
                        opacity: backpackOpacityAnimation.interpolate({
                          inputRange: [0, 20, 40, 60, 80, 100],
                          outputRange: [0.0000000001, 1, 0.0000000001, 1, 0.0000000001, 1],
                        }),
                      }}
                    >
                      <TouchableOpacity onPress={() => {
                        SoundPlayer('navFwdSound', navFwdSound);
                        navigation.navigate('backpack');
                      }}
                      >
                        {/* <Image source={require('./backpack_demo.png')}
                                                    style={{
                                                        width: viewportHeight / 3,
                                                        height: viewportHeight / 3 + 3,
                                                    }}
                                                /> */}
                        <SvgSuitCase />
                      </TouchableOpacity>
                    </DraxView>
                    : null
                }

                {/* Replace with AnimatedPressable */}
                <Animated.View style={{
                  position: 'absolute',
                  top: backpackYPos + 10,
                  left: backpackXPos + 10,
                  width: 145,
                  height: 85,
                  opacity: backpackOpacityAnimation.interpolate({
                    inputRange: [0, 10, 20, 30, 40, 50, 60, 70, 80, 90, 100],
                    outputRange: [0.0000000001, 0.05, 0.10, 0.15, 0.20, 0.25, 0.30, 0.40, 0.60, 0.80, 1],
                  }),
                }}>

                </Animated.View>

              </Animated.View>
            </DraxProvider>
          </ScrollView>
          <BackButton buttonColor={colorPalette.SALMON_PINK} onPress={() => leaveRoom()} />

        </ScrollView>


      </GestureHandlerRootView>
      {/* </View> */}
      {/* </SafeAreaView> */}
      {
        hintsOverlay && !hintsOverlayHide
          ? <HintsOverlay viewportWidth={viewportWidth}
            viewportHeight={viewportHeight}
            setHintsOverlay={setHintsOverlay}
          />
          : null
      }
      {
        alert && alert.display
          ? <AlertComponent type={alert.type}
            title={alert.title}
            description={alert.description}
            sound={alert.sound}
            previousSound={alert.previousSound}
            closeAlert={closeAlert}
          />
          : null
      }
    </>
  );
}

const styles = StyleSheet.create({
  backButton: {
    position: 'absolute',
    top: 10,
    left: 10,
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    backgroundColor: '#ff92a1',
    borderRadius: 12,
    padding: 6,
    paddingRight: 14,
  },
  backButtonText: {
    fontSize: 22,
    fontWeight: 'bold',
    fontFamily: "MyriadPro",
    color: "#000"
  },
});

export default RoomComponent;
