import React, {
    useEffect,
    useRef,
    useState,
} from 'react';
import {
    Animated,
    Text,
    TouchableOpacity,
    View,
} from 'react-native';
import { Ionicons } from '@expo/vector-icons';
import AsyncStorage from '@react-native-async-storage/async-storage';

function HintsOverlay({ viewportWidth, viewportHeight, setHintsOverlay }) {
    const overlayBackgroundColor = useRef(new Animated.Value(0)).current;

    const [showContent, setShowContent] = useState(false);

    useEffect(() => {
        Animated.timing(overlayBackgroundColor, {
            toValue: 1,
            duration: 500,
            useNativeDriver: false,
        }).start(() => setShowContent(true));
    }, []);

    const pressHandler = async () => {
        await AsyncStorage.setItem('@hints_overlay', 'completed');
        setHintsOverlay(false);
    }

    return (
        <Animated.View style={{
                  position: 'absolute',
                  top: 0,
                  left: 0,
                  width: viewportWidth,
                  height: viewportHeight,
                  backgroundColor: overlayBackgroundColor.interpolate({
                      inputRange: [0, 1],
                      outputRange: ['hsla(0, 0%, 0%, 0)', 'hsla(0, 0%, 0%, .5)']
                  }),
              }}
        >
            {
                showContent
                    ? <View style={{
                                flex: 1,
                                paddingVertical: 70,
                                paddingHorizontal: 50,
                            }}
                    >
                        <View style={{
                                  width: '100%',
                                  alignItems: 'center',
                              }}
                        >
                            <HintArrows icon='ios-chevron-up' />
                        </View>
                        <View style={{
                                  width: '100%',
                                  flex: 1,
                                  flexDirection: 'row',
                                  alignItems: 'center',
                                  justifyContent: 'space-between',
                              }}
                        >
                            <HintArrows icon='ios-chevron-back' />
                            <HintContent pressHandler={pressHandler} />
                            <HintArrows icon='ios-chevron-forward' />
                        </View>
                        <View style={{
                                  width: '100%',
                                  alignItems: 'center',
                              }}
                        >
                            <HintArrows icon='ios-chevron-down' />
                        </View>
                    </View>
                    : null
            }
        </Animated.View>
    );
}

function HintContent({ pressHandler }) {
    return (
        <View>
            <Text style={{fontSize: 30,  color: '#fff'}}>Beveg deg rundt i rommet</Text>
            <Text style={{color: '#fff', fontSize: 16, marginVertical: 15, }}>
                Dra rommet opp, ned, til høyre og venstre for å se mer av soverommet.
            </Text>
            <TouchableOpacity style={{
                                backgroundColor: 'hsl(0, 0%, 100%)',
                                padding: 12,
                                alignItems: 'center'
                            }}
                            onPress={async () => pressHandler()}
            >
                <Text>Lukk</Text>
            </TouchableOpacity>
        </View>
    );
}

function HintArrows({ icon, top, left }) {
    const arrowScale = useRef(new Animated.Value(0)).current;

    useEffect(() => {
        Animated.timing(arrowScale, {
            toValue: 100,
            duration: 5000,
            useNativeDriver: false,
        }).start();
    }, []);

    return (
        <Animated.View style={{
                           transform: [{
                               scale: arrowScale.interpolate({
                                   inputRange: [0, 10, 20, 30, 40, 50, 60, 70, 80, 90, 100],
                                   outputRange: [1, 2.5, 2, 1.5, 2.5, 2, 1.5, 2.5, 2, 1.5, 1],
                               }),
                           }]
                       }}
        >
            <Ionicons name={icon} size={60} color='hsl(0, 0%, 100%)' />
        </Animated.View>
    );
}

export default HintsOverlay;