import React from 'react';
import {
  Pressable,
} from 'react-native';

import { Dimensions } from 'react-native';
import {
  useSelector,
} from 'react-redux';

import haptics from 'src/global/constants/haptics';

import SvgPuzzleOne from "src/assets/puzzle/pieces/puzzle-one.svgr.js";
import SvgPuzzleTwo from "src/assets/puzzle/pieces/puzzle-two.svgr.js";
import SvgPuzzleThree from "src/assets/puzzle/pieces/puzzle-three.svgr.js";
import SvgPuzzleFour from "src/assets/puzzle/pieces/puzzle-four.svgr.js";
import SvgPuzzleFive from "src/assets/puzzle/pieces/puzzle-five.svgr.js";
import SvgPuzzleSix from "src/assets/puzzle/pieces/puzzle-six.svgr.js";

const window = Dimensions.get('window');
// const ratio = window.width / 540;

const renderPuzzlePiece = (puzzlePiece) => {
  switch (puzzlePiece.name) {
    case 'PuzzleOne':
      return <SvgPuzzleOne
        style={
          puzzlePiece.state.disabled
            ? puzzlePiece.style.disabled // disabled style
            : puzzlePiece.state.locked
              ? puzzlePiece.style.locked // locked style
              : puzzlePiece.state.clicked
                ? puzzlePiece.style.clicked // clicked style
                : puzzlePiece.style.unclicked // unclicked style
        }
      />;

    case 'PuzzleTwo':
      return <SvgPuzzleTwo
        style={
          puzzlePiece.state.disabled
            ? puzzlePiece.style.disabled // disabled style
            : puzzlePiece.state.locked
              ? puzzlePiece.style.locked // locked style
              : puzzlePiece.state.clicked
                ? puzzlePiece.style.clicked // clicked style
                : puzzlePiece.style.unclicked // unclicked style
        }
      />;

    case 'PuzzleThree':
      return <SvgPuzzleThree
        style={
          puzzlePiece.state.disabled
            ? puzzlePiece.style.disabled // disabled style
            : puzzlePiece.state.locked
              ? puzzlePiece.style.locked // locked style
              : puzzlePiece.state.clicked
                ? puzzlePiece.style.clicked // clicked style
                : puzzlePiece.style.unclicked // unclicked style
        }
      />;

    case 'PuzzleFour':
      return <SvgPuzzleFour
        style={
          puzzlePiece.state.disabled
            ? puzzlePiece.style.disabled // disabled style
            : puzzlePiece.state.locked
              ? puzzlePiece.style.locked // locked style
              : puzzlePiece.state.clicked
                ? puzzlePiece.style.clicked // clicked style
                : puzzlePiece.style.unclicked // unclicked style
        }
      />;

    case 'PuzzleFive':
      return <SvgPuzzleFive
        style={
          puzzlePiece.state.disabled
            ? puzzlePiece.style.disabled // disabled style
            : puzzlePiece.state.locked
              ? puzzlePiece.style.locked // locked style
              : puzzlePiece.state.clicked
                ? puzzlePiece.style.clicked // clicked style
                : puzzlePiece.style.unclicked // unclicked style
        }
      />;

    case 'PuzzleSix':
      return <SvgPuzzleSix
        style={
          puzzlePiece.state.disabled
            ? puzzlePiece.style.disabled // disabled style
            : puzzlePiece.state.locked
              ? puzzlePiece.style.locked // locked style
              : puzzlePiece.state.clicked
                ? puzzlePiece.style.clicked // clicked style
                : puzzlePiece.style.unclicked // unclicked style
        }
      />;

    default:
      console.log('Puzzle piece not found');
      break;
  }
}

const puzzlePieceWidth = (type) => {
  switch (type) {
    case 'narrow':
      return window.width / 4;

    case 'wide':
      return window.width / 4 * 0.8;

    default:
      console.error('Unknow puzzle piece width, use: wide or narrow');
      break;
  }
}

const puzzlePieceHeight = (type, ratio) => {
  switch (type) {
    case 'tall':
      return ratio * 540 / 4 * 0.8;

    case 'medium':
      return ratio * 540 / 4;

    case 'short':
      return ratio * 431 / 4;

    default:
      console.error('Uknown puzzle piece height, use: tall or short');
      break;
  }
}

const PuzzlePieceComponent = ({ navigation, puzzlePiece }) => {

  const { howTo } = useSelector((state) => state.howTo);
  const puzzlePieceRatio = window.width / puzzlePiece.style.placement.ratio;

  const clickHandler = () => {
    haptics.buttonHaptics();
    for (let item of howTo) {
      if (item.name === puzzlePiece.route) {
        item.completed === true
          ? navigation.navigate(puzzlePiece.route)
          : navigation.navigate('HowTo', {
            data: item
          });
      }
    }
  }

  return (
    <Pressable
      onPress={() => clickHandler()}
      style={{
        width: puzzlePieceWidth(puzzlePiece.style.placement.width),
        height: puzzlePieceHeight(puzzlePiece.style.placement.height, puzzlePieceRatio),
        marginTop: puzzlePiece.style.placement.top
          ? window.width * puzzlePiece.style.placement.top
          : 0,
        left: puzzlePiece.style.placement.left
          ? window.width * puzzlePiece.style.placement.left
          : null,
        right: puzzlePiece.style.placement.right
          ? window.width * puzzlePiece.style.placement.right
          : null,
      }}>
      {renderPuzzlePiece(puzzlePiece)}
    </Pressable>
  );

}
export default PuzzlePieceComponent;
