import React from 'react';
import {
  ImageBackground,
  StyleSheet,
  View,
} from 'react-native';

import { useSelector } from 'react-redux';

import Lion from 'src/assets/images/LionSitting.js';
import background1 from 'src/assets/images/backgrounds/BackgroundPuzzle.jpg';
import PuzzlePieceComponent from './puzzle-piece/puzzle-piece.component';

function PuzzleMain({ navigation }) {

  const { puzzle } = useSelector(state => state.puzzle);

  return (
    <View style={styles.container}>
      <ImageBackground source={background1} style={styles.background}>

        <View style={styles.puzzle_group}>
          {
            puzzle.map((puzzlePiece) => {
              return (
                <PuzzlePieceComponent
                  key={puzzlePiece.name}
                  puzzlePiece={puzzlePiece}
                  navigation={navigation}
                />
              );
            })
          }
        </View>

        <Lion style={styles.pet} />

      </ImageBackground>
    </View>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
  },
  background: {
    flex: 1,
    justifyContent: "center",
  },
  pet: {
    position: 'absolute',
    height: '32%',
    width: '32%',
    zIndex: 2,
    left: -36,
    bottom: '0%',
    alignSelf: 'flex-start',
  },

  puzzle_group: {
    width: '80%',
    alignSelf: 'center',
    padding: 0,
    flexDirection: 'row',
    flexWrap: 'wrap',
    alignItems: 'flex-start',
    justifyContent: 'center',
  },
})

export default PuzzleMain;
