import React, {
    useEffect,
    useRef,
    useState,
} from 'react'
import {
    Animated,
    Keyboard,
    ImageBackground,
    Pressable,
    SafeAreaView,
    StyleSheet,
    View,
    Text,
    TextInput,
    KeyboardAvoidingView,
    TouchableWithoutFeedback,
    Dimensions,
    PixelRatio,
    ScrollView,
    Button,
    ActivityIndicator
} from 'react-native';

import AsyncStorage from '@react-native-async-storage/async-storage';

import background from 'src/assets/images/backgrounds/BackgroundPuzzle.jpg';

import { Audio } from 'expo-av';
import { Sounds } from 'src/assets/sounds/sounds';

import {checkPatientNr} from 'src/global/services/UserService'

import AlertComponent from 'src/global/components/alerts/alert.component';
import NetworkState from 'src/global/components/alerts/network.state';
import * as Haptics from 'expo-haptics';
import { Sound } from 'expo-av/build/Audio';


function UserInputView({ navigation }) {
    const [pasientId, setPasientId] = useState(null);
    const [firstName, setFirstName] = useState(null);
    const [weekNumber, setWeekNumber] = useState(null);
    const [groupID, setGroupID] = useState(undefined);

    const [validFirstName, setValidFirstName] = useState(null);
    const [validPasientId, setValidPasientId] = useState(null);
    const [validWeekNumber, setValidWeekNumber] = useState(null);

    const [pasientIdErrorMsg, setPasientIdErrorMsg] = useState('');
    const [weekNumberErrorMsg, setWeekNumberErrorMsg] = useState('');

    let user_object = {
        userId: pasientId, 
        groupId: groupID,
        firstName: firstName,
        weekNumber: weekNumber
    };

    const handleUserInputs = () => {
        if (validFirstName && validPasientId  === true) {
            setCanContinue(true)
            // canContinue ? saveUser() : null
            {console.log('UserInput Accepted')}
        } else {
            {console.log('UserInput not accepted')}

        }
    }


    const handleValidFirstName = (val) => {
        if (val === null || val.length === 0) {
            {console.log('Fornavn må fylles ut!')}
            setValidFirstName(false)
        } else {
            {console.log('Valid Username')}
            setValidFirstName(true)
            handleUserInputs()
        }
    }

    const handleValidUserNumber = (val) => {

        if (val === null || val.length === 0) {
            {console.log('Pasientnummer må fylles ut!')}
            setPasientIdErrorMsg('Pasientnummer må fylles ut!')
            setValidPasientId(false)
        } else {
            //Check that pasientnumber only containts integers. 
            if(/^\d+$/.test(val) === true){
                //Check the three first numbers
                if (val.slice(0,3) === '100') {
                    {console.log("Valid Pasientnumber")}
                    setValidPasientId(true)
                    handleUserInputs()
                } else {
                    {console.log("NB: De tre første tallene er feil!")}
                    setPasientIdErrorMsg("NB: De tre første tallene er feil!")
                    setValidPasientId(false)
                }
            } else {
                {console.log()}
                setPasientIdErrorMsg("NB: Pastientnummer kan bare inneholde tall!")
                setValidPasientId(false)
            } 
        }
    }

    const AnimatedPressable = Animated.createAnimatedComponent(Pressable);

    // const [canContinue, setCanContinue] = useState(false);
    const [canContinue, setCanContinue] = useState(true);

    // const buttonAnimation = useRef(new Animated.Value(0.25)).current;
    // const animateButton = (value) => {
    //     Animated.timing(buttonAnimation, {
    //         toValue: value,
    //         duration: 250,
    //         useNativeDriver: false,
    //     }).start(() => setCanContinue(true));
    // }

    useEffect(() => {
        SoundPlayer('userinputSound', userinputSound);
    }, []);

    // Sounds
    const [currentSound, setCurrentSound] = useState()

    const SoundPlayer = (name, sound) => {
        if (currentSound == null) {
            console.log("Sound is undefined");
        } else {
            currentSound.sound.unloadAsync().catch(()=>{});
        }

        console.log("Playing: " + name);
        Audio.Sound.createAsync(
            sound,
            {shouldPlay: true}
        ).then((res)=>{
            setCurrentSound(res);
            res.sound.setOnPlaybackStatusUpdate((status)=>{
    
                if(!status.didJustFinish) return;
                console.log('Unloading ' + name);
    
                res.sound.unloadAsync().catch(()=>{});
            });
        }).catch((error)=>{});
    }

    const voice = Sounds.female.hanna;

    const navFwdSound = Sounds.navigation_forward;
    const navBwdSound = Sounds.navigation_backward;
    const userinputSound = voice.userinput;
    
    const [isLoading, setIsLoading] = useState(false);

    const saveUser = async () => {
        setIsLoading(true)
        Keyboard.dismiss();
        let user = await checkPatientNr(pasientId);
        if(user){
         setWeekNumber(user.week)
         setGroupID(user.group)
         setFirstName(user.firstName)
        }
        let isPatient = user? true: false
        console.log("PATIENT: " + isPatient)
        if (user) {
            let isFirst = true;
            let patient_object= {
                userId: pasientId, 
                groupId: user.group,
                firstName: user.firstName,
                weekNumber: user.week
        }
            console.log("USER " + user.group + " " + user.week)
            try {
                await AsyncStorage.setItem(
                    'user',
                  
                    JSON.stringify(patient_object),
                    () => {
                        AsyncStorage.getItem('user', (err, result) => {
                            console.log(result);
                            SoundPlayer('navFwdSound', navFwdSound);
                            navigation.replace('PuzzleMain');
                        })
                    }
                );

            } catch (error) {
                console.log("error retrieving data")
                setIsLoading(false);
            }
        } else {
            setAlert({
                type: 'error',
                title: 'Obs!',
                description: 'Du har oppgitt feil pasientnummer',
                sound: voice.userinput,
                display: true,
            });
            setIsLoading(false);
            handleValidFirstName(firstName);
            handleValidUserNumber(pasientId);
        }
    };

    const clickAnimation = useRef(new Animated.Value(1)).current;

    // const groupInputRef = useRef();

    const [alert, setAlert] = useState(null);

    const closeAlert = () => {
        setAlert(null);
    }

    


    return (
        // <SafeAreaView style={styles.container}>
        <View style={styles.container} >
            <ImageBackground source={background} style={styles.background}>

            <TouchableWithoutFeedback  onPress={() => Keyboard.dismiss()} >
            <KeyboardAvoidingView style= {styles.inputBoxContainer} behavior={Platform.OS === 'ios' ? "padding" : "height"}>

                <ScrollView keyboardShouldPersistTaps="handled">
                <View style={styles.inputBox}>
                
                    <View style={styles.inputContainer}>

                    {isLoading && <ActivityIndicator color={'black'}/> }

                        {/* <TextInput style={styles.inputField}
                                   placeholder={"Fornavn"}
                                   placeholderTextColor='#939598'
                                   onChangeText={value => setFirstName(value)}
                                   value={firstName}
                                   blurOnSubmit={false}
                                //    onSubmitEditing={() => groupInputRef.current.focus()}
                                //    onEndEditing={(e) => handleValidFirstName(e.nativeEvent.text)}
                        /> */}
                        {/* {validFirstName == false && <Text style={styles.errorMsg}>Fornavn må fylles ut!</Text>} */}

                        <TextInput style={styles.inputField}
                                   placeholder={"Pasientnummer"}
                                   placeholderTextColor='#939598'
                                   onChangeText={value => setPasientId(value)}
                                   value={pasientId}
                                   blurOnSubmit={false}
                                //    onSubmitEditing={() => groupInputRef.current.focus()}
                                //    onEndEditing={(e) => handleValidUserNumber(e.nativeEvent.text)}
                                   keyboardType='numeric'
                        />

                        {validPasientId == false && <Text style={styles.errorMsg}>{pasientIdErrorMsg}</Text>}  



                        {/* <AnimatedPressable onPress={() =>  canContinue ? saveUser() : null} */}
                        <AnimatedPressable onPress={() => saveUser()}                  
                                           style={[styles.button, {
                                            //    opacity: buttonAnimation
                                           }]}
                        >
                            <Text style={styles.buttonText}>
                                Lagre
                            </Text>
                        </AnimatedPressable>
                        {/* </Pressable> */}
                            
        
                      
                    </View>
                    
                </View>
                </ScrollView>
                
            </KeyboardAvoidingView>
            </TouchableWithoutFeedback>

            
                {
                    alert && alert.display
                        ? <AlertComponent type={alert.type}
                                          title={alert.title}
                                          description={alert.description}
                                          sound={alert.sound}
                                          closeAlert={closeAlert}
                        />
                        : null
                }

            </ImageBackground>

          {/*
            Check for network connection
            If no connection show error

            NB: Place at the end of a component!
          */}
          <NetworkState />
            
        {/* </SafeAreaView> */}
        </View>
    );
}



const styles = StyleSheet.create({
    container: {
        flex: 1,
        flexDirection: 'row'
    },
    background: {
        flex: 1,
        justifyContent: "center",
        width: '100%'
    },
    inputField: {
        width: '100%',
        marginVertical: '4%',
        paddingVertical: '3%',
        paddingHorizontal: '4%',
        borderRadius: 18,
        backgroundColor: '#c3f0e7',
        // fontSize: normalize(6),
        fontFamily: "MyriadPro",
    },
    inputBoxContainer: {
        flex: 1,
        flexDirection: 'row',
        justifyContent: 'center',
        alignItems: 'center',
    },
    inputBox: {
        height: 'auto',
        backgroundColor: '#7ddbc9',
        resizeMode: 'contain',
        alignSelf: 'center',
        borderRadius: 28,
        borderWidth: 4, 
        borderColor: 'white',
        width: '40%'
    },
    button: {
        marginTop: '3%',
        alignItems: 'center',
        paddingVertical: 14,
        paddingHorizontal: '7%',
        elevation: 1,
        borderRadius: 18,
        backgroundColor: '#00c1b3'
    },
    buttonText: {
        fontWeight: 'bold',
        letterSpacing: 1,
        color: '#ffffff',
        fontFamily: "MyriadPro-Semibold",
    },
    inputContainer: {
        flex: 0,
        height: 'auto',
        alignItems: 'center',
        justifyContent: 'center',
        padding: 20,
    },
    errorMsg: {
        color: 'red',
        justifyContent: 'center',
        textAlign: 'center',
        fontFamily: "MyriadPro",
    },

})

export default UserInputView;
