import React, { useEffect, useState } from 'react';
import { StyleSheet, View, Text, Pressable } from 'react-native';
import Svg from 'react-native-svg';
import { Button } from 'react-native-web';
import { WebView } from 'react-native-webview';

import { useDispatch } from 'react-redux';
import { Ionicons } from '@expo/vector-icons';
import Pet from '../../assets/images/Pet';
import {
  clicked,
} from 'src/global/reducers/puzzle/puzzle.slice.js';

import { Audio } from 'expo-av';
import { Sounds } from 'src/assets/sounds/sounds';

import BackButton from 'src/global/components/buttons/BackButton';
import * as colorPalette from 'src/global/constants/colorPalette';
import haptics from 'src/global/constants/haptics';

function VirtualTour({ navigation }) {
  useEffect(() => {
    dispatch(clicked('PuzzleSix'));
  }, []);

  const [currentSound, setCurrentSound] = useState();

  const SoundPlayer = (name, sound) => {
    if (currentSound == null) {
      console.log('Sound is undefined');
    } else {
      currentSound.sound.unloadAsync().catch(() => {});
    }

    console.log('Playing: ' + name);
    Audio.Sound.createAsync(sound, { shouldPlay: true })
      .then((res) => {
        setCurrentSound(res);
        res.sound.setOnPlaybackStatusUpdate((status) => {
          if (!status.didJustFinish) return;
          console.log('Unloading ' + name);

          res.sound.unloadAsync().catch(() => {});
        });
      })
      .catch((error) => {});
  };

  const navBwdSound = Sounds.navigation_backward;

  //const matterportSDK = require('./matterport.html')
  const dispatch = useDispatch();

  const backToMenu = () => {
    haptics.buttonHaptics();
    SoundPlayer('navBwdSound', navBwdSound);
    navigation.popToTop();
  };

  return (
    <View style={styles.container}>
      <WebView
        source={{ uri: 'https://bhss.adfectus.io' }}
        style={{ flex: 1 }}
      />

      <BackButton
        buttonColor={colorPalette.PALE_LAVENDER}
        onPress={() => backToMenu()}
      />
    </View>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#F9D1B3',
  },
});

export default VirtualTour;
